#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 583
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 330
#define ALIAS_COUNT 0
#define TOKEN_COUNT 167
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 51
#define MAX_ALIAS_SEQUENCE_LENGTH 7
#define PRODUCTION_ID_COUNT 125

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_module = 2,
  anon_sym_version = 3,
  anon_sym_is = 4,
  anon_sym_end = 5,
  anon_sym_import = 6,
  anon_sym_LBRACK = 7,
  anon_sym_RBRACK = 8,
  anon_sym_from = 9,
  anon_sym_COLON_COLON = 10,
  anon_sym_COLON_COLON2 = 11,
  anon_sym_as = 12,
  anon_sym_COLON = 13,
  anon_sym_AT = 14,
  anon_sym_EQ = 15,
  anon_sym_assert = 16,
  sym_controlled_language_tag = 17,
  anon_sym_LPAREN = 18,
  anon_sym_RPAREN = 19,
  anon_sym_COMMA = 20,
  sym_reserved_self = 21,
  anon_sym_with = 22,
  anon_sym_def = 23,
  anon_sym_LBRACE = 24,
  anon_sym_RBRACE = 25,
  sym_quoted_string = 26,
  sym_language_tag = 27,
  anon_sym_LT = 28,
  aux_sym_iri_token1 = 29,
  anon_sym_GT = 30,
  anon_sym_POUND_LBRACK = 31,
  sym_hex_byte = 32,
  sym_double = 33,
  sym_decimal = 34,
  sym_integer = 35,
  sym_rational = 36,
  sym_unsigned = 37,
  anon_sym_true = 38,
  anon_sym_u22a4 = 39,
  anon_sym_false = 40,
  anon_sym_u22a5 = 41,
  anon_sym_Thing = 42,
  anon_sym_Nothing = 43,
  anon_sym_real = 44,
  anon_sym_rational = 45,
  anon_sym_anyURI = 46,
  anon_sym_iri = 47,
  anon_sym_base64Binary = 48,
  anon_sym_boolean = 49,
  anon_sym_date = 50,
  anon_sym_dateTime = 51,
  anon_sym_decimal = 52,
  anon_sym_double = 53,
  anon_sym_duration = 54,
  anon_sym_float = 55,
  anon_sym_gDay = 56,
  anon_sym_gMonth = 57,
  anon_sym_gMonthDay = 58,
  anon_sym_gYearMonth = 59,
  anon_sym_gYear = 60,
  anon_sym_hexBinary = 61,
  anon_sym_binary = 62,
  anon_sym_string = 63,
  anon_sym_time = 64,
  anon_sym_dateTimeStamp = 65,
  anon_sym_dayTimeDuration = 66,
  anon_sym_yearMonthDuration = 67,
  anon_sym_integer = 68,
  anon_sym_long = 69,
  anon_sym_int = 70,
  anon_sym_short = 71,
  anon_sym_byte = 72,
  anon_sym_nonNegativeInteger = 73,
  anon_sym_positiveInteger = 74,
  anon_sym_unsignedLong = 75,
  anon_sym_unsignedInt = 76,
  anon_sym_unsigned = 77,
  anon_sym_unsignedShort = 78,
  anon_sym_unsignedByte = 79,
  anon_sym_nonPositiveInteger = 80,
  anon_sym_negativeInteger = 81,
  anon_sym_normalizedString = 82,
  anon_sym_token = 83,
  anon_sym_language = 84,
  anon_sym_without = 85,
  anon_sym_datatype = 86,
  sym_opaque = 87,
  anon_sym_length = 88,
  anon_sym_maxLength = 89,
  anon_sym_minLength = 90,
  anon_sym_fractionDigits = 91,
  anon_sym_totalDigits = 92,
  anon_sym_maxExclusive = 93,
  anon_sym_maxInclusive = 94,
  anon_sym_minExclusive = 95,
  anon_sym_minInclusive = 96,
  anon_sym_explicitTimezone = 97,
  anon_sym_required = 98,
  anon_sym_prohibited = 99,
  anon_sym_optional = 100,
  anon_sym_pattern = 101,
  sym_kw_is_fixed = 102,
  anon_sym_dimension = 103,
  anon_sym_source = 104,
  anon_sym_parent = 105,
  anon_sym_entity = 106,
  anon_sym_enum = 107,
  anon_sym_of = 108,
  anon_sym_event = 109,
  anon_sym_property = 110,
  anon_sym_rdf = 111,
  anon_sym_a = 112,
  anon_sym_type = 113,
  anon_sym_structure = 114,
  anon_sym_union = 115,
  anon_sym_class = 116,
  sym_wildcard = 117,
  anon_sym_identity = 118,
  anon_sym_ref = 119,
  sym_unknown_type = 120,
  anon_sym_ordered = 121,
  anon_sym_unordered = 122,
  anon_sym_unique = 123,
  anon_sym_nonunique = 124,
  anon_sym_DOT_DOT = 125,
  anon_sym_SLASH_EQ = 126,
  anon_sym_u2260 = 127,
  sym_op_less_than = 128,
  sym_op_greater_than = 129,
  anon_sym_LT_EQ = 130,
  anon_sym_u2264 = 131,
  anon_sym_GT_EQ = 132,
  anon_sym_u2265 = 133,
  anon_sym_not = 134,
  anon_sym_u00ac = 135,
  anon_sym_and = 136,
  anon_sym_u2227 = 137,
  anon_sym_or = 138,
  anon_sym_u2228 = 139,
  anon_sym_xor = 140,
  anon_sym_u22bb = 141,
  anon_sym_implies = 142,
  anon_sym_EQ_EQ_GT = 143,
  anon_sym_u21d2 = 144,
  anon_sym_iff = 145,
  anon_sym_LT_EQ_EQ_GT = 146,
  anon_sym_u21d4 = 147,
  anon_sym_forall = 148,
  anon_sym_u2200 = 149,
  anon_sym_exists = 150,
  anon_sym_u2203 = 151,
  anon_sym_in = 152,
  anon_sym_u2208 = 153,
  sym_set_op_builder = 154,
  anon_sym_u00b7 = 155,
  anon_sym_DOT = 156,
  anon_sym_COLON_EQ = 157,
  anon_sym_u2254 = 158,
  anon_sym_u2192 = 159,
  anon_sym_DASH_GT = 160,
  anon_sym_u2190 = 161,
  anon_sym_LT_DASH = 162,
  anon_sym_PLUS = 163,
  anon_sym_u2295 = 164,
  anon_sym_u2205 = 165,
  sym_line_comment = 166,
  sym_module = 167,
  sym__module_locations = 168,
  sym_module_body = 169,
  sym_import_statement = 170,
  sym_from_clause = 171,
  sym_module_path_root_only = 172,
  sym_module_path_absolute = 173,
  sym_module_path_relative = 174,
  sym__import = 175,
  sym__rename_import = 176,
  sym_member_import = 177,
  sym_module_import = 178,
  sym_qualified_identifier = 179,
  sym_identifier_reference = 180,
  sym_annotation = 181,
  sym_annotation_property = 182,
  sym_constraint = 183,
  sym_annotation_only_body = 184,
  sym_informal_constraint = 185,
  sym_formal_constraint = 186,
  sym_constraint_sentence = 187,
  sym_simple_sentence = 188,
  sym_atomic_sentence = 189,
  sym__actual_arguments = 190,
  sym_equation = 191,
  sym_inequation = 192,
  sym_boolean_sentence = 193,
  sym_unary_boolean_sentence = 194,
  sym_binary_boolean_sentence = 195,
  sym__logical_connective = 196,
  sym_quantified_sentence = 197,
  sym_quantified_variable_binding = 198,
  sym_quantified_variable = 199,
  sym_variable = 200,
  sym_term = 201,
  sym_functional_term = 202,
  sym_function_composition = 203,
  sym_predicate_value = 204,
  sym_sequence_of_predicate_values = 205,
  sym_constraint_environment = 206,
  sym_function_def = 207,
  sym_function_signature = 208,
  sym_function_parameter = 209,
  sym__function_type = 210,
  sym_function_type_reference = 211,
  sym_function_body = 212,
  sym_sequence_builder = 213,
  sym_sequence_builder_body = 214,
  sym_value = 215,
  sym_simple_value = 216,
  sym_string = 217,
  sym_iri = 218,
  sym_binary = 219,
  sym_boolean = 220,
  sym_boolean_truth = 221,
  sym_boolean_falsity = 222,
  sym_value_constructor = 223,
  sym_mapping_value = 224,
  sym_sequence_of_values = 225,
  sym__sequence_value_constraints = 226,
  sym_builtin_simple_type = 227,
  sym__owl_builtin_types = 228,
  sym__builtin_primitive_datatypes = 229,
  sym__derived_date_datetypes = 230,
  sym__derived_numeric_datatypes = 231,
  sym__derived_string_datatypes = 232,
  sym_definition = 233,
  sym_from_definition_clause = 234,
  sym_from_definition_with = 235,
  sym_from_definition_without = 236,
  sym__wildcard_or_identifier_or_sequence = 237,
  sym__identifier_or_sequence = 238,
  sym_data_type_def = 239,
  sym__datatype_base = 240,
  sym_datatype_def_restriction = 241,
  sym__restriction_facet = 242,
  sym_length_restriction_facet = 243,
  sym_digit_restriction_facet = 244,
  sym_value_restriction_facet = 245,
  sym_restriction_value = 246,
  sym_tz_restriction_facet = 247,
  sym_tz_restriction_value = 248,
  sym_pattern_restriction_facet = 249,
  sym_dimension_def = 250,
  sym_dimension_body = 251,
  sym_source_entity = 252,
  sym_dimension_parent = 253,
  sym_entity_def = 254,
  sym_entity_body = 255,
  sym_enum_def = 256,
  sym_enum_body = 257,
  sym_event_def = 258,
  sym_event_body = 259,
  sym_property_def = 260,
  sym_rdf_def = 261,
  sym_rdf_types = 262,
  sym_structure_def = 263,
  sym_structure_body = 264,
  sym_union_def = 265,
  sym_union_body = 266,
  sym_type_class_def = 267,
  sym_type_parameter = 268,
  sym_type_parameter_restriction = 269,
  sym_type_class_body = 270,
  sym_method_def = 271,
  sym_entity_identity = 272,
  sym_member = 273,
  sym_member_def = 274,
  sym_property_ref = 275,
  sym__type_expression_to = 276,
  sym_type_reference = 277,
  sym_mapping_type = 278,
  sym_cardinality_expression = 279,
  sym_cardinality_reference_expression = 280,
  sym__cardinality_inner = 281,
  sym_sequence_ordering = 282,
  sym_sequence_uniqueness = 283,
  sym_cardinality_range = 284,
  sym_value_variant = 285,
  sym_type_variant = 286,
  sym_op_inequality = 287,
  sym_op_less_than_or_equal = 288,
  sym_op_greater_than_or_equal = 289,
  sym_logical_op_negation = 290,
  sym_logical_op_conjunction = 291,
  sym_logical_op_disjunction = 292,
  sym_logical_op_exclusive_disjunction = 293,
  sym_logical_op_implication = 294,
  sym_logical_op_biconditional = 295,
  sym_logical_quantifier_universal = 296,
  sym_logical_quantifier_existential = 297,
  sym_set_op_membership = 298,
  sym__function_op_composition = 299,
  sym__function_op_by_definition = 300,
  sym__type_op_has_type = 301,
  sym__type_op_type_restriction = 302,
  sym_type_op_combiner = 303,
  sym__value_empty_sequence = 304,
  aux_sym_module_body_repeat1 = 305,
  aux_sym_module_body_repeat2 = 306,
  aux_sym_module_body_repeat3 = 307,
  aux_sym_import_statement_repeat1 = 308,
  aux_sym_module_path_absolute_repeat1 = 309,
  aux_sym__actual_arguments_repeat1 = 310,
  aux_sym_function_composition_repeat1 = 311,
  aux_sym_sequence_of_predicate_values_repeat1 = 312,
  aux_sym_constraint_environment_repeat1 = 313,
  aux_sym_function_signature_repeat1 = 314,
  aux_sym_sequence_builder_repeat1 = 315,
  aux_sym_binary_repeat1 = 316,
  aux_sym_sequence_of_values_repeat1 = 317,
  aux_sym__wildcard_or_identifier_or_sequence_repeat1 = 318,
  aux_sym_datatype_def_restriction_repeat1 = 319,
  aux_sym_pattern_restriction_facet_repeat1 = 320,
  aux_sym_dimension_body_repeat1 = 321,
  aux_sym_dimension_body_repeat2 = 322,
  aux_sym_enum_body_repeat1 = 323,
  aux_sym_rdf_types_repeat1 = 324,
  aux_sym_union_body_repeat1 = 325,
  aux_sym_type_class_def_repeat1 = 326,
  aux_sym_type_parameter_repeat1 = 327,
  aux_sym_type_parameter_restriction_repeat1 = 328,
  aux_sym_type_class_body_repeat1 = 329,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_module] = "module",
  [anon_sym_version] = "version",
  [anon_sym_is] = "is",
  [anon_sym_end] = "end",
  [anon_sym_import] = "import",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_from] = "from",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_COLON_COLON2] = "::",
  [anon_sym_as] = "as",
  [anon_sym_COLON] = ":",
  [anon_sym_AT] = "@",
  [anon_sym_EQ] = "=",
  [anon_sym_assert] = "assert",
  [sym_controlled_language_tag] = "controlled_language_tag",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_COMMA] = ",",
  [sym_reserved_self] = "reserved_self",
  [anon_sym_with] = "with",
  [anon_sym_def] = "def",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [sym_quoted_string] = "quoted_string",
  [sym_language_tag] = "language_tag",
  [anon_sym_LT] = "<",
  [aux_sym_iri_token1] = "iri_token1",
  [anon_sym_GT] = ">",
  [anon_sym_POUND_LBRACK] = "#[",
  [sym_hex_byte] = "hex_byte",
  [sym_double] = "double",
  [sym_decimal] = "decimal",
  [sym_integer] = "integer",
  [sym_rational] = "rational",
  [sym_unsigned] = "unsigned",
  [anon_sym_true] = "true",
  [anon_sym_u22a4] = "\u22a4",
  [anon_sym_false] = "false",
  [anon_sym_u22a5] = "\u22a5",
  [anon_sym_Thing] = "Thing",
  [anon_sym_Nothing] = "Nothing",
  [anon_sym_real] = "real",
  [anon_sym_rational] = "rational",
  [anon_sym_anyURI] = "anyURI",
  [anon_sym_iri] = "iri",
  [anon_sym_base64Binary] = "base64Binary",
  [anon_sym_boolean] = "boolean",
  [anon_sym_date] = "date",
  [anon_sym_dateTime] = "dateTime",
  [anon_sym_decimal] = "decimal",
  [anon_sym_double] = "double",
  [anon_sym_duration] = "duration",
  [anon_sym_float] = "float",
  [anon_sym_gDay] = "gDay",
  [anon_sym_gMonth] = "gMonth",
  [anon_sym_gMonthDay] = "gMonthDay",
  [anon_sym_gYearMonth] = "gYearMonth",
  [anon_sym_gYear] = "gYear",
  [anon_sym_hexBinary] = "hexBinary",
  [anon_sym_binary] = "binary",
  [anon_sym_string] = "string",
  [anon_sym_time] = "time",
  [anon_sym_dateTimeStamp] = "dateTimeStamp",
  [anon_sym_dayTimeDuration] = "dayTimeDuration",
  [anon_sym_yearMonthDuration] = "yearMonthDuration",
  [anon_sym_integer] = "integer",
  [anon_sym_long] = "long",
  [anon_sym_int] = "int",
  [anon_sym_short] = "short",
  [anon_sym_byte] = "byte",
  [anon_sym_nonNegativeInteger] = "nonNegativeInteger",
  [anon_sym_positiveInteger] = "positiveInteger",
  [anon_sym_unsignedLong] = "unsignedLong",
  [anon_sym_unsignedInt] = "unsignedInt",
  [anon_sym_unsigned] = "unsigned",
  [anon_sym_unsignedShort] = "unsignedShort",
  [anon_sym_unsignedByte] = "unsignedByte",
  [anon_sym_nonPositiveInteger] = "nonPositiveInteger",
  [anon_sym_negativeInteger] = "negativeInteger",
  [anon_sym_normalizedString] = "normalizedString",
  [anon_sym_token] = "token",
  [anon_sym_language] = "language",
  [anon_sym_without] = "without",
  [anon_sym_datatype] = "datatype",
  [sym_opaque] = "opaque",
  [anon_sym_length] = "length",
  [anon_sym_maxLength] = "maxLength",
  [anon_sym_minLength] = "minLength",
  [anon_sym_fractionDigits] = "fractionDigits",
  [anon_sym_totalDigits] = "totalDigits",
  [anon_sym_maxExclusive] = "maxExclusive",
  [anon_sym_maxInclusive] = "maxInclusive",
  [anon_sym_minExclusive] = "minExclusive",
  [anon_sym_minInclusive] = "minInclusive",
  [anon_sym_explicitTimezone] = "explicitTimezone",
  [anon_sym_required] = "required",
  [anon_sym_prohibited] = "prohibited",
  [anon_sym_optional] = "optional",
  [anon_sym_pattern] = "pattern",
  [sym_kw_is_fixed] = "kw_is_fixed",
  [anon_sym_dimension] = "dimension",
  [anon_sym_source] = "source",
  [anon_sym_parent] = "parent",
  [anon_sym_entity] = "entity",
  [anon_sym_enum] = "enum",
  [anon_sym_of] = "of",
  [anon_sym_event] = "event",
  [anon_sym_property] = "property",
  [anon_sym_rdf] = "rdf",
  [anon_sym_a] = "a",
  [anon_sym_type] = "type",
  [anon_sym_structure] = "structure",
  [anon_sym_union] = "union",
  [anon_sym_class] = "class",
  [sym_wildcard] = "wildcard",
  [anon_sym_identity] = "identity",
  [anon_sym_ref] = "ref",
  [sym_unknown_type] = "unknown_type",
  [anon_sym_ordered] = "ordered",
  [anon_sym_unordered] = "unordered",
  [anon_sym_unique] = "unique",
  [anon_sym_nonunique] = "nonunique",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_u2260] = "\u2260",
  [sym_op_less_than] = "op_less_than",
  [sym_op_greater_than] = "op_greater_than",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_u2264] = "\u2264",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_u2265] = "\u2265",
  [anon_sym_not] = "not",
  [anon_sym_u00ac] = "\u00ac",
  [anon_sym_and] = "and",
  [anon_sym_u2227] = "\u2227",
  [anon_sym_or] = "or",
  [anon_sym_u2228] = "\u2228",
  [anon_sym_xor] = "xor",
  [anon_sym_u22bb] = "\u22bb",
  [anon_sym_implies] = "implies",
  [anon_sym_EQ_EQ_GT] = "==>",
  [anon_sym_u21d2] = "\u21d2",
  [anon_sym_iff] = "iff",
  [anon_sym_LT_EQ_EQ_GT] = "<==>",
  [anon_sym_u21d4] = "\u21d4",
  [anon_sym_forall] = "forall",
  [anon_sym_u2200] = "\u2200",
  [anon_sym_exists] = "exists",
  [anon_sym_u2203] = "\u2203",
  [anon_sym_in] = "in",
  [anon_sym_u2208] = "\u2208",
  [sym_set_op_builder] = "set_op_builder",
  [anon_sym_u00b7] = "\u00b7",
  [anon_sym_DOT] = ".",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_u2254] = "\u2254",
  [anon_sym_u2192] = "\u2192",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_u2190] = "\u2190",
  [anon_sym_LT_DASH] = "<-",
  [anon_sym_PLUS] = "+",
  [anon_sym_u2295] = "\u2295",
  [anon_sym_u2205] = "\u2205",
  [sym_line_comment] = "line_comment",
  [sym_module] = "module",
  [sym__module_locations] = "_module_locations",
  [sym_module_body] = "module_body",
  [sym_import_statement] = "import_statement",
  [sym_from_clause] = "from_clause",
  [sym_module_path_root_only] = "module_path_root_only",
  [sym_module_path_absolute] = "module_path_absolute",
  [sym_module_path_relative] = "module_path_relative",
  [sym__import] = "_import",
  [sym__rename_import] = "_rename_import",
  [sym_member_import] = "member_import",
  [sym_module_import] = "module_import",
  [sym_qualified_identifier] = "qualified_identifier",
  [sym_identifier_reference] = "identifier_reference",
  [sym_annotation] = "annotation",
  [sym_annotation_property] = "annotation_property",
  [sym_constraint] = "constraint",
  [sym_annotation_only_body] = "annotation_only_body",
  [sym_informal_constraint] = "informal_constraint",
  [sym_formal_constraint] = "formal_constraint",
  [sym_constraint_sentence] = "constraint_sentence",
  [sym_simple_sentence] = "simple_sentence",
  [sym_atomic_sentence] = "atomic_sentence",
  [sym__actual_arguments] = "_actual_arguments",
  [sym_equation] = "equation",
  [sym_inequation] = "inequation",
  [sym_boolean_sentence] = "boolean_sentence",
  [sym_unary_boolean_sentence] = "unary_boolean_sentence",
  [sym_binary_boolean_sentence] = "binary_boolean_sentence",
  [sym__logical_connective] = "_logical_connective",
  [sym_quantified_sentence] = "quantified_sentence",
  [sym_quantified_variable_binding] = "quantified_variable_binding",
  [sym_quantified_variable] = "quantified_variable",
  [sym_variable] = "variable",
  [sym_term] = "term",
  [sym_functional_term] = "functional_term",
  [sym_function_composition] = "function_composition",
  [sym_predicate_value] = "predicate_value",
  [sym_sequence_of_predicate_values] = "sequence_of_predicate_values",
  [sym_constraint_environment] = "constraint_environment",
  [sym_function_def] = "function_def",
  [sym_function_signature] = "function_signature",
  [sym_function_parameter] = "function_parameter",
  [sym__function_type] = "_function_type",
  [sym_function_type_reference] = "function_type_reference",
  [sym_function_body] = "function_body",
  [sym_sequence_builder] = "sequence_builder",
  [sym_sequence_builder_body] = "sequence_builder_body",
  [sym_value] = "value",
  [sym_simple_value] = "simple_value",
  [sym_string] = "string",
  [sym_iri] = "iri",
  [sym_binary] = "binary",
  [sym_boolean] = "boolean",
  [sym_boolean_truth] = "boolean_truth",
  [sym_boolean_falsity] = "boolean_falsity",
  [sym_value_constructor] = "value_constructor",
  [sym_mapping_value] = "mapping_value",
  [sym_sequence_of_values] = "sequence_of_values",
  [sym__sequence_value_constraints] = "_sequence_value_constraints",
  [sym_builtin_simple_type] = "builtin_simple_type",
  [sym__owl_builtin_types] = "_owl_builtin_types",
  [sym__builtin_primitive_datatypes] = "_builtin_primitive_datatypes",
  [sym__derived_date_datetypes] = "_derived_date_datetypes",
  [sym__derived_numeric_datatypes] = "_derived_numeric_datatypes",
  [sym__derived_string_datatypes] = "_derived_string_datatypes",
  [sym_definition] = "definition",
  [sym_from_definition_clause] = "from_definition_clause",
  [sym_from_definition_with] = "from_definition_with",
  [sym_from_definition_without] = "from_definition_without",
  [sym__wildcard_or_identifier_or_sequence] = "_wildcard_or_identifier_or_sequence",
  [sym__identifier_or_sequence] = "_identifier_or_sequence",
  [sym_data_type_def] = "data_type_def",
  [sym__datatype_base] = "_datatype_base",
  [sym_datatype_def_restriction] = "datatype_def_restriction",
  [sym__restriction_facet] = "_restriction_facet",
  [sym_length_restriction_facet] = "length_restriction_facet",
  [sym_digit_restriction_facet] = "digit_restriction_facet",
  [sym_value_restriction_facet] = "value_restriction_facet",
  [sym_restriction_value] = "restriction_value",
  [sym_tz_restriction_facet] = "tz_restriction_facet",
  [sym_tz_restriction_value] = "tz_restriction_value",
  [sym_pattern_restriction_facet] = "pattern_restriction_facet",
  [sym_dimension_def] = "dimension_def",
  [sym_dimension_body] = "dimension_body",
  [sym_source_entity] = "source_entity",
  [sym_dimension_parent] = "dimension_parent",
  [sym_entity_def] = "entity_def",
  [sym_entity_body] = "entity_body",
  [sym_enum_def] = "enum_def",
  [sym_enum_body] = "enum_body",
  [sym_event_def] = "event_def",
  [sym_event_body] = "event_body",
  [sym_property_def] = "property_def",
  [sym_rdf_def] = "rdf_def",
  [sym_rdf_types] = "rdf_types",
  [sym_structure_def] = "structure_def",
  [sym_structure_body] = "structure_body",
  [sym_union_def] = "union_def",
  [sym_union_body] = "union_body",
  [sym_type_class_def] = "type_class_def",
  [sym_type_parameter] = "type_parameter",
  [sym_type_parameter_restriction] = "type_parameter_restriction",
  [sym_type_class_body] = "type_class_body",
  [sym_method_def] = "method_def",
  [sym_entity_identity] = "entity_identity",
  [sym_member] = "member",
  [sym_member_def] = "member_def",
  [sym_property_ref] = "property_ref",
  [sym__type_expression_to] = "_type_expression_to",
  [sym_type_reference] = "type_reference",
  [sym_mapping_type] = "mapping_type",
  [sym_cardinality_expression] = "cardinality_expression",
  [sym_cardinality_reference_expression] = "cardinality_reference_expression",
  [sym__cardinality_inner] = "_cardinality_inner",
  [sym_sequence_ordering] = "sequence_ordering",
  [sym_sequence_uniqueness] = "sequence_uniqueness",
  [sym_cardinality_range] = "cardinality_range",
  [sym_value_variant] = "value_variant",
  [sym_type_variant] = "type_variant",
  [sym_op_inequality] = "op_inequality",
  [sym_op_less_than_or_equal] = "op_less_than_or_equal",
  [sym_op_greater_than_or_equal] = "op_greater_than_or_equal",
  [sym_logical_op_negation] = "logical_op_negation",
  [sym_logical_op_conjunction] = "logical_op_conjunction",
  [sym_logical_op_disjunction] = "logical_op_disjunction",
  [sym_logical_op_exclusive_disjunction] = "logical_op_exclusive_disjunction",
  [sym_logical_op_implication] = "logical_op_implication",
  [sym_logical_op_biconditional] = "logical_op_biconditional",
  [sym_logical_quantifier_universal] = "logical_quantifier_universal",
  [sym_logical_quantifier_existential] = "logical_quantifier_existential",
  [sym_set_op_membership] = "set_op_membership",
  [sym__function_op_composition] = "_function_op_composition",
  [sym__function_op_by_definition] = "_function_op_by_definition",
  [sym__type_op_has_type] = "_type_op_has_type",
  [sym__type_op_type_restriction] = "_type_op_type_restriction",
  [sym_type_op_combiner] = "type_op_combiner",
  [sym__value_empty_sequence] = "_value_empty_sequence",
  [aux_sym_module_body_repeat1] = "module_body_repeat1",
  [aux_sym_module_body_repeat2] = "module_body_repeat2",
  [aux_sym_module_body_repeat3] = "module_body_repeat3",
  [aux_sym_import_statement_repeat1] = "import_statement_repeat1",
  [aux_sym_module_path_absolute_repeat1] = "module_path_absolute_repeat1",
  [aux_sym__actual_arguments_repeat1] = "_actual_arguments_repeat1",
  [aux_sym_function_composition_repeat1] = "function_composition_repeat1",
  [aux_sym_sequence_of_predicate_values_repeat1] = "sequence_of_predicate_values_repeat1",
  [aux_sym_constraint_environment_repeat1] = "constraint_environment_repeat1",
  [aux_sym_function_signature_repeat1] = "function_signature_repeat1",
  [aux_sym_sequence_builder_repeat1] = "sequence_builder_repeat1",
  [aux_sym_binary_repeat1] = "binary_repeat1",
  [aux_sym_sequence_of_values_repeat1] = "sequence_of_values_repeat1",
  [aux_sym__wildcard_or_identifier_or_sequence_repeat1] = "_wildcard_or_identifier_or_sequence_repeat1",
  [aux_sym_datatype_def_restriction_repeat1] = "datatype_def_restriction_repeat1",
  [aux_sym_pattern_restriction_facet_repeat1] = "pattern_restriction_facet_repeat1",
  [aux_sym_dimension_body_repeat1] = "dimension_body_repeat1",
  [aux_sym_dimension_body_repeat2] = "dimension_body_repeat2",
  [aux_sym_enum_body_repeat1] = "enum_body_repeat1",
  [aux_sym_rdf_types_repeat1] = "rdf_types_repeat1",
  [aux_sym_union_body_repeat1] = "union_body_repeat1",
  [aux_sym_type_class_def_repeat1] = "type_class_def_repeat1",
  [aux_sym_type_parameter_repeat1] = "type_parameter_repeat1",
  [aux_sym_type_parameter_restriction_repeat1] = "type_parameter_restriction_repeat1",
  [aux_sym_type_class_body_repeat1] = "type_class_body_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_module] = anon_sym_module,
  [anon_sym_version] = anon_sym_version,
  [anon_sym_is] = anon_sym_is,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_from] = anon_sym_from,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_COLON_COLON2] = anon_sym_COLON_COLON,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_assert] = anon_sym_assert,
  [sym_controlled_language_tag] = sym_controlled_language_tag,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [sym_reserved_self] = sym_reserved_self,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_def] = anon_sym_def,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [sym_quoted_string] = sym_quoted_string,
  [sym_language_tag] = sym_language_tag,
  [anon_sym_LT] = anon_sym_LT,
  [aux_sym_iri_token1] = aux_sym_iri_token1,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_POUND_LBRACK] = anon_sym_POUND_LBRACK,
  [sym_hex_byte] = sym_hex_byte,
  [sym_double] = sym_double,
  [sym_decimal] = sym_decimal,
  [sym_integer] = sym_integer,
  [sym_rational] = sym_rational,
  [sym_unsigned] = sym_unsigned,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_u22a4] = anon_sym_u22a4,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_u22a5] = anon_sym_u22a5,
  [anon_sym_Thing] = anon_sym_Thing,
  [anon_sym_Nothing] = anon_sym_Nothing,
  [anon_sym_real] = anon_sym_real,
  [anon_sym_rational] = anon_sym_rational,
  [anon_sym_anyURI] = anon_sym_anyURI,
  [anon_sym_iri] = anon_sym_iri,
  [anon_sym_base64Binary] = anon_sym_base64Binary,
  [anon_sym_boolean] = anon_sym_boolean,
  [anon_sym_date] = anon_sym_date,
  [anon_sym_dateTime] = anon_sym_dateTime,
  [anon_sym_decimal] = anon_sym_decimal,
  [anon_sym_double] = anon_sym_double,
  [anon_sym_duration] = anon_sym_duration,
  [anon_sym_float] = anon_sym_float,
  [anon_sym_gDay] = anon_sym_gDay,
  [anon_sym_gMonth] = anon_sym_gMonth,
  [anon_sym_gMonthDay] = anon_sym_gMonthDay,
  [anon_sym_gYearMonth] = anon_sym_gYearMonth,
  [anon_sym_gYear] = anon_sym_gYear,
  [anon_sym_hexBinary] = anon_sym_hexBinary,
  [anon_sym_binary] = anon_sym_binary,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_time] = anon_sym_time,
  [anon_sym_dateTimeStamp] = anon_sym_dateTimeStamp,
  [anon_sym_dayTimeDuration] = anon_sym_dayTimeDuration,
  [anon_sym_yearMonthDuration] = anon_sym_yearMonthDuration,
  [anon_sym_integer] = anon_sym_integer,
  [anon_sym_long] = anon_sym_long,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_short] = anon_sym_short,
  [anon_sym_byte] = anon_sym_byte,
  [anon_sym_nonNegativeInteger] = anon_sym_nonNegativeInteger,
  [anon_sym_positiveInteger] = anon_sym_positiveInteger,
  [anon_sym_unsignedLong] = anon_sym_unsignedLong,
  [anon_sym_unsignedInt] = anon_sym_unsignedInt,
  [anon_sym_unsigned] = anon_sym_unsigned,
  [anon_sym_unsignedShort] = anon_sym_unsignedShort,
  [anon_sym_unsignedByte] = anon_sym_unsignedByte,
  [anon_sym_nonPositiveInteger] = anon_sym_nonPositiveInteger,
  [anon_sym_negativeInteger] = anon_sym_negativeInteger,
  [anon_sym_normalizedString] = anon_sym_normalizedString,
  [anon_sym_token] = anon_sym_token,
  [anon_sym_language] = anon_sym_language,
  [anon_sym_without] = anon_sym_without,
  [anon_sym_datatype] = anon_sym_datatype,
  [sym_opaque] = sym_opaque,
  [anon_sym_length] = anon_sym_length,
  [anon_sym_maxLength] = anon_sym_maxLength,
  [anon_sym_minLength] = anon_sym_minLength,
  [anon_sym_fractionDigits] = anon_sym_fractionDigits,
  [anon_sym_totalDigits] = anon_sym_totalDigits,
  [anon_sym_maxExclusive] = anon_sym_maxExclusive,
  [anon_sym_maxInclusive] = anon_sym_maxInclusive,
  [anon_sym_minExclusive] = anon_sym_minExclusive,
  [anon_sym_minInclusive] = anon_sym_minInclusive,
  [anon_sym_explicitTimezone] = anon_sym_explicitTimezone,
  [anon_sym_required] = anon_sym_required,
  [anon_sym_prohibited] = anon_sym_prohibited,
  [anon_sym_optional] = anon_sym_optional,
  [anon_sym_pattern] = anon_sym_pattern,
  [sym_kw_is_fixed] = sym_kw_is_fixed,
  [anon_sym_dimension] = anon_sym_dimension,
  [anon_sym_source] = anon_sym_source,
  [anon_sym_parent] = anon_sym_parent,
  [anon_sym_entity] = anon_sym_entity,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_of] = anon_sym_of,
  [anon_sym_event] = anon_sym_event,
  [anon_sym_property] = anon_sym_property,
  [anon_sym_rdf] = anon_sym_rdf,
  [anon_sym_a] = anon_sym_a,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_structure] = anon_sym_structure,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_class] = anon_sym_class,
  [sym_wildcard] = sym_wildcard,
  [anon_sym_identity] = anon_sym_identity,
  [anon_sym_ref] = anon_sym_ref,
  [sym_unknown_type] = sym_unknown_type,
  [anon_sym_ordered] = anon_sym_ordered,
  [anon_sym_unordered] = anon_sym_unordered,
  [anon_sym_unique] = anon_sym_unique,
  [anon_sym_nonunique] = anon_sym_nonunique,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_u2260] = anon_sym_u2260,
  [sym_op_less_than] = sym_op_less_than,
  [sym_op_greater_than] = sym_op_greater_than,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_u2264] = anon_sym_u2264,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_u2265] = anon_sym_u2265,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_u00ac] = anon_sym_u00ac,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_u2227] = anon_sym_u2227,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_u2228] = anon_sym_u2228,
  [anon_sym_xor] = anon_sym_xor,
  [anon_sym_u22bb] = anon_sym_u22bb,
  [anon_sym_implies] = anon_sym_implies,
  [anon_sym_EQ_EQ_GT] = anon_sym_EQ_EQ_GT,
  [anon_sym_u21d2] = anon_sym_u21d2,
  [anon_sym_iff] = anon_sym_iff,
  [anon_sym_LT_EQ_EQ_GT] = anon_sym_LT_EQ_EQ_GT,
  [anon_sym_u21d4] = anon_sym_u21d4,
  [anon_sym_forall] = anon_sym_forall,
  [anon_sym_u2200] = anon_sym_u2200,
  [anon_sym_exists] = anon_sym_exists,
  [anon_sym_u2203] = anon_sym_u2203,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_u2208] = anon_sym_u2208,
  [sym_set_op_builder] = sym_set_op_builder,
  [anon_sym_u00b7] = anon_sym_u00b7,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_u2254] = anon_sym_u2254,
  [anon_sym_u2192] = anon_sym_u2192,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_u2190] = anon_sym_u2190,
  [anon_sym_LT_DASH] = anon_sym_LT_DASH,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_u2295] = anon_sym_u2295,
  [anon_sym_u2205] = anon_sym_u2205,
  [sym_line_comment] = sym_line_comment,
  [sym_module] = sym_module,
  [sym__module_locations] = sym__module_locations,
  [sym_module_body] = sym_module_body,
  [sym_import_statement] = sym_import_statement,
  [sym_from_clause] = sym_from_clause,
  [sym_module_path_root_only] = sym_module_path_root_only,
  [sym_module_path_absolute] = sym_module_path_absolute,
  [sym_module_path_relative] = sym_module_path_relative,
  [sym__import] = sym__import,
  [sym__rename_import] = sym__rename_import,
  [sym_member_import] = sym_member_import,
  [sym_module_import] = sym_module_import,
  [sym_qualified_identifier] = sym_qualified_identifier,
  [sym_identifier_reference] = sym_identifier_reference,
  [sym_annotation] = sym_annotation,
  [sym_annotation_property] = sym_annotation_property,
  [sym_constraint] = sym_constraint,
  [sym_annotation_only_body] = sym_annotation_only_body,
  [sym_informal_constraint] = sym_informal_constraint,
  [sym_formal_constraint] = sym_formal_constraint,
  [sym_constraint_sentence] = sym_constraint_sentence,
  [sym_simple_sentence] = sym_simple_sentence,
  [sym_atomic_sentence] = sym_atomic_sentence,
  [sym__actual_arguments] = sym__actual_arguments,
  [sym_equation] = sym_equation,
  [sym_inequation] = sym_inequation,
  [sym_boolean_sentence] = sym_boolean_sentence,
  [sym_unary_boolean_sentence] = sym_unary_boolean_sentence,
  [sym_binary_boolean_sentence] = sym_binary_boolean_sentence,
  [sym__logical_connective] = sym__logical_connective,
  [sym_quantified_sentence] = sym_quantified_sentence,
  [sym_quantified_variable_binding] = sym_quantified_variable_binding,
  [sym_quantified_variable] = sym_quantified_variable,
  [sym_variable] = sym_variable,
  [sym_term] = sym_term,
  [sym_functional_term] = sym_functional_term,
  [sym_function_composition] = sym_function_composition,
  [sym_predicate_value] = sym_predicate_value,
  [sym_sequence_of_predicate_values] = sym_sequence_of_predicate_values,
  [sym_constraint_environment] = sym_constraint_environment,
  [sym_function_def] = sym_function_def,
  [sym_function_signature] = sym_function_signature,
  [sym_function_parameter] = sym_function_parameter,
  [sym__function_type] = sym__function_type,
  [sym_function_type_reference] = sym_function_type_reference,
  [sym_function_body] = sym_function_body,
  [sym_sequence_builder] = sym_sequence_builder,
  [sym_sequence_builder_body] = sym_sequence_builder_body,
  [sym_value] = sym_value,
  [sym_simple_value] = sym_simple_value,
  [sym_string] = sym_string,
  [sym_iri] = sym_iri,
  [sym_binary] = sym_binary,
  [sym_boolean] = sym_boolean,
  [sym_boolean_truth] = sym_boolean_truth,
  [sym_boolean_falsity] = sym_boolean_falsity,
  [sym_value_constructor] = sym_value_constructor,
  [sym_mapping_value] = sym_mapping_value,
  [sym_sequence_of_values] = sym_sequence_of_values,
  [sym__sequence_value_constraints] = sym__sequence_value_constraints,
  [sym_builtin_simple_type] = sym_builtin_simple_type,
  [sym__owl_builtin_types] = sym__owl_builtin_types,
  [sym__builtin_primitive_datatypes] = sym__builtin_primitive_datatypes,
  [sym__derived_date_datetypes] = sym__derived_date_datetypes,
  [sym__derived_numeric_datatypes] = sym__derived_numeric_datatypes,
  [sym__derived_string_datatypes] = sym__derived_string_datatypes,
  [sym_definition] = sym_definition,
  [sym_from_definition_clause] = sym_from_definition_clause,
  [sym_from_definition_with] = sym_from_definition_with,
  [sym_from_definition_without] = sym_from_definition_without,
  [sym__wildcard_or_identifier_or_sequence] = sym__wildcard_or_identifier_or_sequence,
  [sym__identifier_or_sequence] = sym__identifier_or_sequence,
  [sym_data_type_def] = sym_data_type_def,
  [sym__datatype_base] = sym__datatype_base,
  [sym_datatype_def_restriction] = sym_datatype_def_restriction,
  [sym__restriction_facet] = sym__restriction_facet,
  [sym_length_restriction_facet] = sym_length_restriction_facet,
  [sym_digit_restriction_facet] = sym_digit_restriction_facet,
  [sym_value_restriction_facet] = sym_value_restriction_facet,
  [sym_restriction_value] = sym_restriction_value,
  [sym_tz_restriction_facet] = sym_tz_restriction_facet,
  [sym_tz_restriction_value] = sym_tz_restriction_value,
  [sym_pattern_restriction_facet] = sym_pattern_restriction_facet,
  [sym_dimension_def] = sym_dimension_def,
  [sym_dimension_body] = sym_dimension_body,
  [sym_source_entity] = sym_source_entity,
  [sym_dimension_parent] = sym_dimension_parent,
  [sym_entity_def] = sym_entity_def,
  [sym_entity_body] = sym_entity_body,
  [sym_enum_def] = sym_enum_def,
  [sym_enum_body] = sym_enum_body,
  [sym_event_def] = sym_event_def,
  [sym_event_body] = sym_event_body,
  [sym_property_def] = sym_property_def,
  [sym_rdf_def] = sym_rdf_def,
  [sym_rdf_types] = sym_rdf_types,
  [sym_structure_def] = sym_structure_def,
  [sym_structure_body] = sym_structure_body,
  [sym_union_def] = sym_union_def,
  [sym_union_body] = sym_union_body,
  [sym_type_class_def] = sym_type_class_def,
  [sym_type_parameter] = sym_type_parameter,
  [sym_type_parameter_restriction] = sym_type_parameter_restriction,
  [sym_type_class_body] = sym_type_class_body,
  [sym_method_def] = sym_method_def,
  [sym_entity_identity] = sym_entity_identity,
  [sym_member] = sym_member,
  [sym_member_def] = sym_member_def,
  [sym_property_ref] = sym_property_ref,
  [sym__type_expression_to] = sym__type_expression_to,
  [sym_type_reference] = sym_type_reference,
  [sym_mapping_type] = sym_mapping_type,
  [sym_cardinality_expression] = sym_cardinality_expression,
  [sym_cardinality_reference_expression] = sym_cardinality_reference_expression,
  [sym__cardinality_inner] = sym__cardinality_inner,
  [sym_sequence_ordering] = sym_sequence_ordering,
  [sym_sequence_uniqueness] = sym_sequence_uniqueness,
  [sym_cardinality_range] = sym_cardinality_range,
  [sym_value_variant] = sym_value_variant,
  [sym_type_variant] = sym_type_variant,
  [sym_op_inequality] = sym_op_inequality,
  [sym_op_less_than_or_equal] = sym_op_less_than_or_equal,
  [sym_op_greater_than_or_equal] = sym_op_greater_than_or_equal,
  [sym_logical_op_negation] = sym_logical_op_negation,
  [sym_logical_op_conjunction] = sym_logical_op_conjunction,
  [sym_logical_op_disjunction] = sym_logical_op_disjunction,
  [sym_logical_op_exclusive_disjunction] = sym_logical_op_exclusive_disjunction,
  [sym_logical_op_implication] = sym_logical_op_implication,
  [sym_logical_op_biconditional] = sym_logical_op_biconditional,
  [sym_logical_quantifier_universal] = sym_logical_quantifier_universal,
  [sym_logical_quantifier_existential] = sym_logical_quantifier_existential,
  [sym_set_op_membership] = sym_set_op_membership,
  [sym__function_op_composition] = sym__function_op_composition,
  [sym__function_op_by_definition] = sym__function_op_by_definition,
  [sym__type_op_has_type] = sym__type_op_has_type,
  [sym__type_op_type_restriction] = sym__type_op_type_restriction,
  [sym_type_op_combiner] = sym_type_op_combiner,
  [sym__value_empty_sequence] = sym__value_empty_sequence,
  [aux_sym_module_body_repeat1] = aux_sym_module_body_repeat1,
  [aux_sym_module_body_repeat2] = aux_sym_module_body_repeat2,
  [aux_sym_module_body_repeat3] = aux_sym_module_body_repeat3,
  [aux_sym_import_statement_repeat1] = aux_sym_import_statement_repeat1,
  [aux_sym_module_path_absolute_repeat1] = aux_sym_module_path_absolute_repeat1,
  [aux_sym__actual_arguments_repeat1] = aux_sym__actual_arguments_repeat1,
  [aux_sym_function_composition_repeat1] = aux_sym_function_composition_repeat1,
  [aux_sym_sequence_of_predicate_values_repeat1] = aux_sym_sequence_of_predicate_values_repeat1,
  [aux_sym_constraint_environment_repeat1] = aux_sym_constraint_environment_repeat1,
  [aux_sym_function_signature_repeat1] = aux_sym_function_signature_repeat1,
  [aux_sym_sequence_builder_repeat1] = aux_sym_sequence_builder_repeat1,
  [aux_sym_binary_repeat1] = aux_sym_binary_repeat1,
  [aux_sym_sequence_of_values_repeat1] = aux_sym_sequence_of_values_repeat1,
  [aux_sym__wildcard_or_identifier_or_sequence_repeat1] = aux_sym__wildcard_or_identifier_or_sequence_repeat1,
  [aux_sym_datatype_def_restriction_repeat1] = aux_sym_datatype_def_restriction_repeat1,
  [aux_sym_pattern_restriction_facet_repeat1] = aux_sym_pattern_restriction_facet_repeat1,
  [aux_sym_dimension_body_repeat1] = aux_sym_dimension_body_repeat1,
  [aux_sym_dimension_body_repeat2] = aux_sym_dimension_body_repeat2,
  [aux_sym_enum_body_repeat1] = aux_sym_enum_body_repeat1,
  [aux_sym_rdf_types_repeat1] = aux_sym_rdf_types_repeat1,
  [aux_sym_union_body_repeat1] = aux_sym_union_body_repeat1,
  [aux_sym_type_class_def_repeat1] = aux_sym_type_class_def_repeat1,
  [aux_sym_type_parameter_repeat1] = aux_sym_type_parameter_repeat1,
  [aux_sym_type_parameter_restriction_repeat1] = aux_sym_type_parameter_restriction_repeat1,
  [aux_sym_type_class_body_repeat1] = aux_sym_type_class_body_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_version] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_is] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_from] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [sym_controlled_language_tag] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [sym_reserved_self] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_def] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [sym_quoted_string] = {
    .visible = true,
    .named = true,
  },
  [sym_language_tag] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_iri_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUND_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [sym_hex_byte] = {
    .visible = true,
    .named = true,
  },
  [sym_double] = {
    .visible = true,
    .named = true,
  },
  [sym_decimal] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_rational] = {
    .visible = true,
    .named = true,
  },
  [sym_unsigned] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u22a4] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u22a5] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Thing] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Nothing] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_real] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rational] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_anyURI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_iri] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_base64Binary] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_boolean] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_date] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dateTime] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_decimal] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_double] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_duration] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_float] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gDay] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gMonth] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gMonthDay] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gYearMonth] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_gYear] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_hexBinary] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_binary] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_time] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dateTimeStamp] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dayTimeDuration] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_yearMonthDuration] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_integer] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_long] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_short] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_byte] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nonNegativeInteger] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_positiveInteger] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsignedLong] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsignedInt] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsigned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsignedShort] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsignedByte] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nonPositiveInteger] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_negativeInteger] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_normalizedString] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_token] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_language] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_without] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_datatype] = {
    .visible = true,
    .named = false,
  },
  [sym_opaque] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_length] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_maxLength] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_minLength] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fractionDigits] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_totalDigits] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_maxExclusive] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_maxInclusive] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_minExclusive] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_minInclusive] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_explicitTimezone] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_required] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_prohibited] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_optional] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pattern] = {
    .visible = true,
    .named = false,
  },
  [sym_kw_is_fixed] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_dimension] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_source] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_parent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_entity] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_of] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_event] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_property] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rdf] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_a] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_structure] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [sym_wildcard] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_identity] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ref] = {
    .visible = true,
    .named = false,
  },
  [sym_unknown_type] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_ordered] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unordered] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unique] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nonunique] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2260] = {
    .visible = true,
    .named = false,
  },
  [sym_op_less_than] = {
    .visible = true,
    .named = true,
  },
  [sym_op_greater_than] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2264] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2265] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u00ac] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2227] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2228] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u22bb] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implies] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u21d2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_iff] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u21d4] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_forall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2200] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exists] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2203] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2208] = {
    .visible = true,
    .named = false,
  },
  [sym_set_op_builder] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_u00b7] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2254] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2192] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2190] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2295] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2205] = {
    .visible = true,
    .named = false,
  },
  [sym_line_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_module] = {
    .visible = true,
    .named = true,
  },
  [sym__module_locations] = {
    .visible = false,
    .named = true,
  },
  [sym_module_body] = {
    .visible = true,
    .named = true,
  },
  [sym_import_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_from_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_module_path_root_only] = {
    .visible = true,
    .named = true,
  },
  [sym_module_path_absolute] = {
    .visible = true,
    .named = true,
  },
  [sym_module_path_relative] = {
    .visible = true,
    .named = true,
  },
  [sym__import] = {
    .visible = false,
    .named = true,
  },
  [sym__rename_import] = {
    .visible = false,
    .named = true,
  },
  [sym_member_import] = {
    .visible = true,
    .named = true,
  },
  [sym_module_import] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_annotation_property] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_annotation_only_body] = {
    .visible = true,
    .named = true,
  },
  [sym_informal_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_formal_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_sentence] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_sentence] = {
    .visible = true,
    .named = true,
  },
  [sym_atomic_sentence] = {
    .visible = true,
    .named = true,
  },
  [sym__actual_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_equation] = {
    .visible = true,
    .named = true,
  },
  [sym_inequation] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_sentence] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_boolean_sentence] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_boolean_sentence] = {
    .visible = true,
    .named = true,
  },
  [sym__logical_connective] = {
    .visible = false,
    .named = true,
  },
  [sym_quantified_sentence] = {
    .visible = true,
    .named = true,
  },
  [sym_quantified_variable_binding] = {
    .visible = true,
    .named = true,
  },
  [sym_quantified_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_term] = {
    .visible = true,
    .named = true,
  },
  [sym_functional_term] = {
    .visible = true,
    .named = true,
  },
  [sym_function_composition] = {
    .visible = true,
    .named = true,
  },
  [sym_predicate_value] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_of_predicate_values] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_environment] = {
    .visible = true,
    .named = true,
  },
  [sym_function_def] = {
    .visible = true,
    .named = true,
  },
  [sym_function_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_function_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__function_type] = {
    .visible = false,
    .named = true,
  },
  [sym_function_type_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_function_body] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_builder] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_builder_body] = {
    .visible = true,
    .named = true,
  },
  [sym_value] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_value] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_iri] = {
    .visible = true,
    .named = true,
  },
  [sym_binary] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_truth] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_falsity] = {
    .visible = true,
    .named = true,
  },
  [sym_value_constructor] = {
    .visible = true,
    .named = true,
  },
  [sym_mapping_value] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_of_values] = {
    .visible = true,
    .named = true,
  },
  [sym__sequence_value_constraints] = {
    .visible = false,
    .named = true,
  },
  [sym_builtin_simple_type] = {
    .visible = true,
    .named = true,
  },
  [sym__owl_builtin_types] = {
    .visible = false,
    .named = true,
  },
  [sym__builtin_primitive_datatypes] = {
    .visible = false,
    .named = true,
  },
  [sym__derived_date_datetypes] = {
    .visible = false,
    .named = true,
  },
  [sym__derived_numeric_datatypes] = {
    .visible = false,
    .named = true,
  },
  [sym__derived_string_datatypes] = {
    .visible = false,
    .named = true,
  },
  [sym_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_from_definition_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_from_definition_with] = {
    .visible = true,
    .named = true,
  },
  [sym_from_definition_without] = {
    .visible = true,
    .named = true,
  },
  [sym__wildcard_or_identifier_or_sequence] = {
    .visible = false,
    .named = true,
  },
  [sym__identifier_or_sequence] = {
    .visible = false,
    .named = true,
  },
  [sym_data_type_def] = {
    .visible = true,
    .named = true,
  },
  [sym__datatype_base] = {
    .visible = false,
    .named = true,
  },
  [sym_datatype_def_restriction] = {
    .visible = true,
    .named = true,
  },
  [sym__restriction_facet] = {
    .visible = false,
    .named = true,
  },
  [sym_length_restriction_facet] = {
    .visible = true,
    .named = true,
  },
  [sym_digit_restriction_facet] = {
    .visible = true,
    .named = true,
  },
  [sym_value_restriction_facet] = {
    .visible = true,
    .named = true,
  },
  [sym_restriction_value] = {
    .visible = true,
    .named = true,
  },
  [sym_tz_restriction_facet] = {
    .visible = true,
    .named = true,
  },
  [sym_tz_restriction_value] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern_restriction_facet] = {
    .visible = true,
    .named = true,
  },
  [sym_dimension_def] = {
    .visible = true,
    .named = true,
  },
  [sym_dimension_body] = {
    .visible = true,
    .named = true,
  },
  [sym_source_entity] = {
    .visible = true,
    .named = true,
  },
  [sym_dimension_parent] = {
    .visible = true,
    .named = true,
  },
  [sym_entity_def] = {
    .visible = true,
    .named = true,
  },
  [sym_entity_body] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_def] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_body] = {
    .visible = true,
    .named = true,
  },
  [sym_event_def] = {
    .visible = true,
    .named = true,
  },
  [sym_event_body] = {
    .visible = true,
    .named = true,
  },
  [sym_property_def] = {
    .visible = true,
    .named = true,
  },
  [sym_rdf_def] = {
    .visible = true,
    .named = true,
  },
  [sym_rdf_types] = {
    .visible = true,
    .named = true,
  },
  [sym_structure_def] = {
    .visible = true,
    .named = true,
  },
  [sym_structure_body] = {
    .visible = true,
    .named = true,
  },
  [sym_union_def] = {
    .visible = true,
    .named = true,
  },
  [sym_union_body] = {
    .visible = true,
    .named = true,
  },
  [sym_type_class_def] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_restriction] = {
    .visible = true,
    .named = true,
  },
  [sym_type_class_body] = {
    .visible = true,
    .named = true,
  },
  [sym_method_def] = {
    .visible = true,
    .named = true,
  },
  [sym_entity_identity] = {
    .visible = true,
    .named = true,
  },
  [sym_member] = {
    .visible = true,
    .named = true,
  },
  [sym_member_def] = {
    .visible = true,
    .named = true,
  },
  [sym_property_ref] = {
    .visible = true,
    .named = true,
  },
  [sym__type_expression_to] = {
    .visible = false,
    .named = true,
  },
  [sym_type_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_mapping_type] = {
    .visible = true,
    .named = true,
  },
  [sym_cardinality_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_cardinality_reference_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__cardinality_inner] = {
    .visible = false,
    .named = true,
  },
  [sym_sequence_ordering] = {
    .visible = true,
    .named = true,
  },
  [sym_sequence_uniqueness] = {
    .visible = true,
    .named = true,
  },
  [sym_cardinality_range] = {
    .visible = true,
    .named = true,
  },
  [sym_value_variant] = {
    .visible = true,
    .named = true,
  },
  [sym_type_variant] = {
    .visible = true,
    .named = true,
  },
  [sym_op_inequality] = {
    .visible = true,
    .named = true,
  },
  [sym_op_less_than_or_equal] = {
    .visible = true,
    .named = true,
  },
  [sym_op_greater_than_or_equal] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_op_negation] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_op_conjunction] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_op_disjunction] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_op_exclusive_disjunction] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_op_implication] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_op_biconditional] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_quantifier_universal] = {
    .visible = true,
    .named = true,
  },
  [sym_logical_quantifier_existential] = {
    .visible = true,
    .named = true,
  },
  [sym_set_op_membership] = {
    .visible = true,
    .named = true,
  },
  [sym__function_op_composition] = {
    .visible = false,
    .named = true,
  },
  [sym__function_op_by_definition] = {
    .visible = false,
    .named = true,
  },
  [sym__type_op_has_type] = {
    .visible = false,
    .named = true,
  },
  [sym__type_op_type_restriction] = {
    .visible = false,
    .named = true,
  },
  [sym_type_op_combiner] = {
    .visible = true,
    .named = true,
  },
  [sym__value_empty_sequence] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_module_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_body_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_body_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_import_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_module_path_absolute_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__actual_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_composition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sequence_of_predicate_values_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constraint_environment_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_signature_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sequence_builder_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_binary_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sequence_of_values_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__wildcard_or_identifier_or_sequence_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_datatype_def_restriction_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pattern_restriction_facet_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dimension_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dimension_body_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_rdf_types_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_union_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_class_def_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameter_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameter_restriction_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_class_body_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_argument = 1,
  field_base = 2,
  field_binding = 3,
  field_body = 4,
  field_byte = 5,
  field_cardinality = 6,
  field_class = 7,
  field_domain = 8,
  field_element = 9,
  field_empty = 10,
  field_entity = 11,
  field_environment = 12,
  field_facet = 13,
  field_from = 14,
  field_function = 15,
  field_identity = 16,
  field_is_fixed = 17,
  field_language = 18,
  field_lhs = 19,
  field_max = 20,
  field_member = 21,
  field_method = 22,
  field_min = 23,
  field_module = 24,
  field_name = 25,
  field_opaque = 26,
  field_operator = 27,
  field_ordering = 28,
  field_parameter = 29,
  field_parent = 30,
  field_predicate = 31,
  field_property = 32,
  field_quantifier = 33,
  field_range = 34,
  field_relation = 35,
  field_rename = 36,
  field_restriction = 37,
  field_rhs = 38,
  field_segment = 39,
  field_signature = 40,
  field_source = 41,
  field_subject = 42,
  field_target = 43,
  field_type = 44,
  field_types = 45,
  field_uniqueness = 46,
  field_value = 47,
  field_variable = 48,
  field_version_info = 49,
  field_version_uri = 50,
  field_wildcard = 51,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_argument] = "argument",
  [field_base] = "base",
  [field_binding] = "binding",
  [field_body] = "body",
  [field_byte] = "byte",
  [field_cardinality] = "cardinality",
  [field_class] = "class",
  [field_domain] = "domain",
  [field_element] = "element",
  [field_empty] = "empty",
  [field_entity] = "entity",
  [field_environment] = "environment",
  [field_facet] = "facet",
  [field_from] = "from",
  [field_function] = "function",
  [field_identity] = "identity",
  [field_is_fixed] = "is_fixed",
  [field_language] = "language",
  [field_lhs] = "lhs",
  [field_max] = "max",
  [field_member] = "member",
  [field_method] = "method",
  [field_min] = "min",
  [field_module] = "module",
  [field_name] = "name",
  [field_opaque] = "opaque",
  [field_operator] = "operator",
  [field_ordering] = "ordering",
  [field_parameter] = "parameter",
  [field_parent] = "parent",
  [field_predicate] = "predicate",
  [field_property] = "property",
  [field_quantifier] = "quantifier",
  [field_range] = "range",
  [field_relation] = "relation",
  [field_rename] = "rename",
  [field_restriction] = "restriction",
  [field_rhs] = "rhs",
  [field_segment] = "segment",
  [field_signature] = "signature",
  [field_source] = "source",
  [field_subject] = "subject",
  [field_target] = "target",
  [field_type] = "type",
  [field_types] = "types",
  [field_uniqueness] = "uniqueness",
  [field_value] = "value",
  [field_variable] = "variable",
  [field_version_info] = "version_info",
  [field_version_uri] = "version_uri",
  [field_wildcard] = "wildcard",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 2},
  [2] = {.index = 2, .length = 1},
  [3] = {.index = 3, .length = 5},
  [4] = {.index = 8, .length = 1},
  [5] = {.index = 9, .length = 1},
  [6] = {.index = 10, .length = 1},
  [7] = {.index = 11, .length = 1},
  [8] = {.index = 12, .length = 2},
  [9] = {.index = 14, .length = 2},
  [10] = {.index = 16, .length = 2},
  [11] = {.index = 18, .length = 1},
  [12] = {.index = 19, .length = 2},
  [13] = {.index = 21, .length = 2},
  [14] = {.index = 23, .length = 3},
  [15] = {.index = 26, .length = 2},
  [16] = {.index = 28, .length = 3},
  [17] = {.index = 31, .length = 1},
  [18] = {.index = 32, .length = 2},
  [19] = {.index = 34, .length = 3},
  [20] = {.index = 37, .length = 2},
  [21] = {.index = 39, .length = 2},
  [22] = {.index = 41, .length = 2},
  [23] = {.index = 43, .length = 1},
  [24] = {.index = 44, .length = 1},
  [25] = {.index = 45, .length = 2},
  [26] = {.index = 47, .length = 3},
  [27] = {.index = 50, .length = 4},
  [28] = {.index = 54, .length = 1},
  [29] = {.index = 55, .length = 1},
  [30] = {.index = 56, .length = 3},
  [31] = {.index = 59, .length = 1},
  [32] = {.index = 60, .length = 1},
  [33] = {.index = 61, .length = 1},
  [34] = {.index = 62, .length = 1},
  [35] = {.index = 63, .length = 1},
  [36] = {.index = 64, .length = 1},
  [37] = {.index = 65, .length = 3},
  [38] = {.index = 68, .length = 2},
  [39] = {.index = 70, .length = 1},
  [40] = {.index = 71, .length = 1},
  [41] = {.index = 72, .length = 2},
  [42] = {.index = 74, .length = 2},
  [43] = {.index = 76, .length = 2},
  [44] = {.index = 78, .length = 2},
  [45] = {.index = 80, .length = 2},
  [46] = {.index = 82, .length = 2},
  [47] = {.index = 84, .length = 3},
  [48] = {.index = 87, .length = 3},
  [49] = {.index = 90, .length = 3},
  [50] = {.index = 93, .length = 1},
  [51] = {.index = 94, .length = 1},
  [52] = {.index = 95, .length = 1},
  [53] = {.index = 96, .length = 2},
  [54] = {.index = 98, .length = 1},
  [55] = {.index = 99, .length = 2},
  [56] = {.index = 101, .length = 1},
  [57] = {.index = 102, .length = 1},
  [58] = {.index = 103, .length = 1},
  [59] = {.index = 104, .length = 2},
  [60] = {.index = 106, .length = 2},
  [61] = {.index = 108, .length = 2},
  [62] = {.index = 110, .length = 1},
  [63] = {.index = 111, .length = 2},
  [64] = {.index = 113, .length = 1},
  [65] = {.index = 114, .length = 1},
  [66] = {.index = 115, .length = 1},
  [67] = {.index = 116, .length = 2},
  [68] = {.index = 118, .length = 2},
  [69] = {.index = 120, .length = 2},
  [70] = {.index = 122, .length = 2},
  [71] = {.index = 124, .length = 2},
  [72] = {.index = 126, .length = 3},
  [73] = {.index = 129, .length = 2},
  [74] = {.index = 131, .length = 2},
  [75] = {.index = 133, .length = 1},
  [76] = {.index = 134, .length = 3},
  [77] = {.index = 137, .length = 3},
  [78] = {.index = 140, .length = 2},
  [79] = {.index = 142, .length = 4},
  [80] = {.index = 146, .length = 4},
  [81] = {.index = 150, .length = 4},
  [82] = {.index = 154, .length = 1},
  [83] = {.index = 155, .length = 1},
  [84] = {.index = 156, .length = 1},
  [85] = {.index = 157, .length = 2},
  [86] = {.index = 159, .length = 1},
  [87] = {.index = 160, .length = 2},
  [88] = {.index = 162, .length = 2},
  [89] = {.index = 164, .length = 1},
  [90] = {.index = 165, .length = 2},
  [91] = {.index = 167, .length = 2},
  [92] = {.index = 169, .length = 1},
  [93] = {.index = 170, .length = 1},
  [94] = {.index = 171, .length = 3},
  [95] = {.index = 174, .length = 3},
  [96] = {.index = 177, .length = 2},
  [97] = {.index = 179, .length = 2},
  [98] = {.index = 181, .length = 3},
  [99] = {.index = 184, .length = 2},
  [100] = {.index = 186, .length = 1},
  [101] = {.index = 187, .length = 2},
  [102] = {.index = 189, .length = 2},
  [103] = {.index = 191, .length = 5},
  [104] = {.index = 196, .length = 2},
  [105] = {.index = 198, .length = 1},
  [106] = {.index = 199, .length = 3},
  [107] = {.index = 202, .length = 3},
  [108] = {.index = 205, .length = 3},
  [109] = {.index = 208, .length = 2},
  [110] = {.index = 210, .length = 4},
  [111] = {.index = 214, .length = 2},
  [112] = {.index = 216, .length = 2},
  [113] = {.index = 218, .length = 1},
  [114] = {.index = 219, .length = 2},
  [115] = {.index = 221, .length = 2},
  [116] = {.index = 223, .length = 2},
  [117] = {.index = 225, .length = 4},
  [118] = {.index = 229, .length = 4},
  [119] = {.index = 233, .length = 3},
  [120] = {.index = 236, .length = 2},
  [121] = {.index = 238, .length = 3},
  [122] = {.index = 241, .length = 2},
  [123] = {.index = 243, .length = 3},
  [124] = {.index = 246, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_body, 2},
    {field_name, 1},
  [2] =
    {field_base, 0},
  [3] =
    {field_base, 2, .inherited = true},
    {field_body, 3},
    {field_name, 1},
    {field_version_info, 2, .inherited = true},
    {field_version_uri, 2, .inherited = true},
  [8] =
    {field_name, 0},
  [9] =
    {field_segment, 0},
  [10] =
    {field_name, 1},
  [11] =
    {field_member, 1},
  [12] =
    {field_base, 0},
    {field_version_uri, 2},
  [14] =
    {field_name, 0},
    {field_rename, 1, .inherited = true},
  [16] =
    {field_name, 0},
    {field_version_uri, 1},
  [18] =
    {field_segment, 1},
  [19] =
    {field_segment, 0},
    {field_segment, 1, .inherited = true},
  [21] =
    {field_from, 2},
    {field_name, 1},
  [23] =
    {field_cardinality, 1, .inherited = true},
    {field_name, 0},
    {field_target, 1, .inherited = true},
  [26] =
    {field_name, 1},
    {field_types, 2},
  [28] =
    {field_base, 0},
    {field_version_info, 2},
    {field_version_uri, 3},
  [31] =
    {field_rename, 1},
  [32] =
    {field_member, 2},
    {field_module, 0},
  [34] =
    {field_name, 0},
    {field_rename, 2, .inherited = true},
    {field_version_uri, 1},
  [37] =
    {field_segment, 1},
    {field_segment, 2, .inherited = true},
  [39] =
    {field_segment, 0, .inherited = true},
    {field_segment, 1, .inherited = true},
  [41] =
    {field_name, 1},
    {field_value, 3},
  [43] =
    {field_empty, 0},
  [44] =
    {field_value, 1},
  [45] =
    {field_base, 3},
    {field_name, 1},
  [47] =
    {field_body, 3},
    {field_from, 2},
    {field_name, 1},
  [50] =
    {field_body, 2},
    {field_cardinality, 1, .inherited = true},
    {field_name, 0},
    {field_target, 1, .inherited = true},
  [54] =
    {field_target, 1},
  [55] =
    {field_type, 1},
  [56] =
    {field_body, 3},
    {field_name, 1},
    {field_types, 2},
  [59] =
    {field_signature, 0},
  [60] =
    {field_method, 0},
  [61] =
    {field_parameter, 0},
  [62] =
    {field_element, 0},
  [63] =
    {field_language, 1},
  [64] =
    {field_byte, 0},
  [65] =
    {field_empty, 1},
    {field_ordering, 0, .inherited = true},
    {field_uniqueness, 0, .inherited = true},
  [68] =
    {field_name, 1, .inherited = true},
    {field_subject, 0},
  [70] =
    {field_variable, 0},
  [71] =
    {field_body, 1},
  [72] =
    {field_argument, 1, .inherited = true},
    {field_predicate, 0},
  [74] =
    {field_argument, 1, .inherited = true},
    {field_function, 0},
  [76] =
    {field_operator, 0},
    {field_rhs, 1},
  [78] =
    {field_binding, 1},
    {field_quantifier, 0},
  [80] =
    {field_language, 2},
    {field_value, 1},
  [82] =
    {field_body, 1},
    {field_signature, 0},
  [84] =
    {field_base, 4},
    {field_name, 1},
    {field_opaque, 3},
  [87] =
    {field_base, 3},
    {field_body, 4},
    {field_name, 1},
  [90] =
    {field_base, 3},
    {field_name, 1},
    {field_restriction, 4},
  [93] =
    {field_entity, 1},
  [94] =
    {field_identity, 1},
  [95] =
    {field_from, 1},
  [96] =
    {field_body, 1},
    {field_name, 0},
  [98] =
    {field_min, 0},
  [99] =
    {field_cardinality, 1},
    {field_target, 2},
  [101] =
    {field_type, 0},
  [102] =
    {field_property, 1},
  [103] =
    {field_method, 1, .inherited = true},
  [104] =
    {field_method, 0, .inherited = true},
    {field_method, 1, .inherited = true},
  [106] =
    {field_name, 1},
    {field_parameter, 3, .inherited = true},
  [108] =
    {field_parameter, 0, .inherited = true},
    {field_parameter, 1, .inherited = true},
  [110] =
    {field_element, 1, .inherited = true},
  [111] =
    {field_element, 0, .inherited = true},
    {field_element, 1, .inherited = true},
  [113] =
    {field_ordering, 1},
  [114] =
    {field_uniqueness, 1},
  [115] =
    {field_byte, 1, .inherited = true},
  [116] =
    {field_byte, 0, .inherited = true},
    {field_byte, 1, .inherited = true},
  [118] =
    {field_domain, 0},
    {field_range, 2},
  [120] =
    {field_ordering, 0, .inherited = true},
    {field_uniqueness, 0, .inherited = true},
  [122] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [124] =
    {field_variable, 0, .inherited = true},
    {field_variable, 1, .inherited = true},
  [126] =
    {field_lhs, 0},
    {field_operator, 1},
    {field_rhs, 2},
  [129] =
    {field_binding, 0},
    {field_body, 2},
  [131] =
    {field_lhs, 0},
    {field_rhs, 2},
  [133] =
    {field_argument, 0},
  [134] =
    {field_lhs, 0},
    {field_relation, 1},
    {field_rhs, 2},
  [137] =
    {field_cardinality, 2, .inherited = true},
    {field_name, 1},
    {field_target, 2, .inherited = true},
  [140] =
    {field_body, 2},
    {field_environment, 0},
  [142] =
    {field_base, 4},
    {field_body, 5},
    {field_name, 1},
    {field_opaque, 3},
  [146] =
    {field_base, 4},
    {field_name, 1},
    {field_opaque, 3},
    {field_restriction, 5},
  [150] =
    {field_base, 3},
    {field_body, 5},
    {field_name, 1},
    {field_restriction, 4},
  [154] =
    {field_identity, 2},
  [155] =
    {field_member, 0},
  [156] =
    {field_wildcard, 0},
  [157] =
    {field_member, 1, .inherited = true},
    {field_wildcard, 1, .inherited = true},
  [159] =
    {field_member, 1, .inherited = true},
  [160] =
    {field_min, 0},
    {field_range, 1},
  [162] =
    {field_min, 1, .inherited = true},
    {field_range, 1, .inherited = true},
  [164] =
    {field_type, 2, .inherited = true},
  [165] =
    {field_type, 0, .inherited = true},
    {field_type, 1, .inherited = true},
  [167] =
    {field_name, 0},
    {field_rename, 2},
  [169] =
    {field_method, 2, .inherited = true},
  [170] =
    {field_class, 0},
  [171] =
    {field_from, 5},
    {field_name, 1},
    {field_parameter, 3, .inherited = true},
  [174] =
    {field_body, 5},
    {field_name, 1},
    {field_parameter, 3, .inherited = true},
  [177] =
    {field_ordering, 1},
    {field_uniqueness, 2},
  [179] =
    {field_name, 0},
    {field_value, 2},
  [181] =
    {field_element, 2, .inherited = true},
    {field_ordering, 0, .inherited = true},
    {field_uniqueness, 0, .inherited = true},
  [184] =
    {field_name, 0},
    {field_range, 2},
  [186] =
    {field_argument, 1, .inherited = true},
  [187] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [189] =
    {field_source, 2},
    {field_variable, 0},
  [191] =
    {field_base, 4},
    {field_body, 6},
    {field_name, 1},
    {field_opaque, 3},
    {field_restriction, 5},
  [196] =
    {field_entity, 1},
    {field_member, 3, .inherited = true},
  [198] =
    {field_max, 1},
  [199] =
    {field_min, 2, .inherited = true},
    {field_ordering, 1},
    {field_range, 2, .inherited = true},
  [202] =
    {field_min, 2, .inherited = true},
    {field_range, 2, .inherited = true},
    {field_uniqueness, 1},
  [205] =
    {field_body, 3},
    {field_name, 0},
    {field_rename, 2},
  [208] =
    {field_cardinality, 0},
    {field_class, 1},
  [210] =
    {field_body, 6},
    {field_from, 5},
    {field_name, 1},
    {field_parameter, 3, .inherited = true},
  [214] =
    {field_body, 3},
    {field_variable, 1, .inherited = true},
  [216] =
    {field_facet, 0},
    {field_value, 2},
  [218] =
    {field_value, 2},
  [219] =
    {field_name, 1},
    {field_parent, 3},
  [221] =
    {field_member, 0, .inherited = true},
    {field_member, 1, .inherited = true},
  [223] =
    {field_domain, 1},
    {field_range, 3},
  [225] =
    {field_min, 3, .inherited = true},
    {field_ordering, 1},
    {field_range, 3, .inherited = true},
    {field_uniqueness, 2},
  [229] =
    {field_cardinality, 5, .inherited = true},
    {field_name, 1},
    {field_parameter, 3, .inherited = true},
    {field_target, 5, .inherited = true},
  [233] =
    {field_facet, 0},
    {field_is_fixed, 2},
    {field_value, 3},
  [236] =
    {field_is_fixed, 2},
    {field_value, 3},
  [238] =
    {field_body, 4},
    {field_name, 1},
    {field_parent, 3},
  [241] =
    {field_argument, 2, .inherited = true},
    {field_class, 0},
  [243] =
    {field_value, 2},
    {field_value, 3},
    {field_value, 4},
  [246] =
    {field_argument, 3, .inherited = true},
    {field_cardinality, 0},
    {field_class, 1},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 19,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 22,
  [29] = 26,
  [30] = 20,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 48,
  [50] = 47,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 65,
  [72] = 66,
  [73] = 70,
  [74] = 68,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 79,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 5,
  [100] = 100,
  [101] = 2,
  [102] = 102,
  [103] = 103,
  [104] = 96,
  [105] = 96,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 67,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 3,
  [116] = 116,
  [117] = 6,
  [118] = 75,
  [119] = 77,
  [120] = 120,
  [121] = 78,
  [122] = 76,
  [123] = 123,
  [124] = 124,
  [125] = 10,
  [126] = 126,
  [127] = 12,
  [128] = 8,
  [129] = 9,
  [130] = 7,
  [131] = 11,
  [132] = 14,
  [133] = 133,
  [134] = 134,
  [135] = 82,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 138,
  [140] = 136,
  [141] = 134,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 88,
  [148] = 95,
  [149] = 93,
  [150] = 94,
  [151] = 87,
  [152] = 86,
  [153] = 91,
  [154] = 143,
  [155] = 155,
  [156] = 156,
  [157] = 45,
  [158] = 158,
  [159] = 89,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 85,
  [166] = 166,
  [167] = 160,
  [168] = 90,
  [169] = 169,
  [170] = 92,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 197,
  [198] = 198,
  [199] = 199,
  [200] = 199,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 204,
  [205] = 205,
  [206] = 206,
  [207] = 207,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 224,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 248,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 271,
  [272] = 272,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 281,
  [282] = 282,
  [283] = 283,
  [284] = 284,
  [285] = 285,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 327,
  [329] = 326,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 45,
  [336] = 336,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 351,
  [352] = 146,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 364,
  [365] = 365,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 372,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 387,
  [388] = 388,
  [389] = 389,
  [390] = 390,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 394,
  [395] = 395,
  [396] = 396,
  [397] = 397,
  [398] = 398,
  [399] = 399,
  [400] = 400,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 405,
  [406] = 406,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 412,
  [413] = 401,
  [414] = 414,
  [415] = 415,
  [416] = 416,
  [417] = 417,
  [418] = 418,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 422,
  [423] = 423,
  [424] = 190,
  [425] = 425,
  [426] = 194,
  [427] = 427,
  [428] = 428,
  [429] = 429,
  [430] = 430,
  [431] = 431,
  [432] = 432,
  [433] = 433,
  [434] = 434,
  [435] = 435,
  [436] = 436,
  [437] = 437,
  [438] = 438,
  [439] = 439,
  [440] = 440,
  [441] = 441,
  [442] = 442,
  [443] = 443,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 452,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 451,
  [458] = 458,
  [459] = 459,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 449,
  [470] = 455,
  [471] = 471,
  [472] = 471,
  [473] = 473,
  [474] = 474,
  [475] = 475,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 481,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 486,
  [487] = 487,
  [488] = 488,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 492,
  [493] = 493,
  [494] = 494,
  [495] = 495,
  [496] = 496,
  [497] = 497,
  [498] = 498,
  [499] = 499,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 503,
  [504] = 504,
  [505] = 505,
  [506] = 506,
  [507] = 507,
  [508] = 508,
  [509] = 509,
  [510] = 510,
  [511] = 511,
  [512] = 512,
  [513] = 513,
  [514] = 514,
  [515] = 515,
  [516] = 516,
  [517] = 517,
  [518] = 518,
  [519] = 519,
  [520] = 520,
  [521] = 521,
  [522] = 522,
  [523] = 523,
  [524] = 524,
  [525] = 525,
  [526] = 526,
  [527] = 527,
  [528] = 528,
  [529] = 529,
  [530] = 530,
  [531] = 531,
  [532] = 532,
  [533] = 533,
  [534] = 534,
  [535] = 535,
  [536] = 536,
  [537] = 537,
  [538] = 538,
  [539] = 539,
  [540] = 540,
  [541] = 541,
  [542] = 542,
  [543] = 543,
  [544] = 544,
  [545] = 545,
  [546] = 546,
  [547] = 547,
  [548] = 548,
  [549] = 549,
  [550] = 550,
  [551] = 551,
  [552] = 552,
  [553] = 553,
  [554] = 549,
  [555] = 555,
  [556] = 556,
  [557] = 557,
  [558] = 558,
  [559] = 559,
  [560] = 560,
  [561] = 561,
  [562] = 562,
  [563] = 553,
  [564] = 564,
  [565] = 565,
  [566] = 566,
  [567] = 555,
  [568] = 568,
  [569] = 569,
  [570] = 570,
  [571] = 571,
  [572] = 572,
  [573] = 573,
  [574] = 551,
  [575] = 544,
  [576] = 576,
  [577] = 562,
  [578] = 578,
  [579] = 579,
  [580] = 580,
  [581] = 581,
  [582] = 582,
};

static TSCharacterRange sym_identifier_character_set_1[] = {
  {'A', 'Z'}, {'a', 'z'}, {0xb5, 0xb5}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x1ba}, {0x1bc, 0x1bf}, {0x1c4, 0x1c4},
  {0x1c6, 0x1c7}, {0x1c9, 0x1ca}, {0x1cc, 0x1f1}, {0x1f3, 0x293}, {0x295, 0x2af}, {0x370, 0x373}, {0x376, 0x377}, {0x37b, 0x37d},
  {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481}, {0x48a, 0x52f},
  {0x531, 0x556}, {0x560, 0x588}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fd, 0x10ff}, {0x13a0, 0x13f5},
  {0x13f8, 0x13fd}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1d00, 0x1d2b}, {0x1d6b, 0x1d77}, {0x1d79, 0x1d9a}, {0x1e00, 0x1f15},
  {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d},
  {0x1f80, 0x1f87}, {0x1f90, 0x1f97}, {0x1fa0, 0x1fa7}, {0x1fb0, 0x1fb4}, {0x1fb6, 0x1fbb}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcb},
  {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffb}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113},
  {0x2115, 0x2115}, {0x2119, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x212d}, {0x212f, 0x2134}, {0x2139, 0x2139},
  {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2183, 0x2184}, {0x2c00, 0x2c7b}, {0x2c7e, 0x2ce4}, {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3},
  {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0xa640, 0xa66d}, {0xa680, 0xa69b}, {0xa722, 0xa76f}, {0xa771, 0xa787}, {0xa78b, 0xa78e},
  {0xa790, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f5, 0xa7f6}, {0xa7fa, 0xa7fa}, {0xab30, 0xab5a}, {0xab60, 0xab68},
  {0xab70, 0xabbf}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0x10400, 0x1044f}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb},
  {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc},
};

static TSCharacterRange sym_identifier_character_set_2[] = {
  {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xb5, 0xb5}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x1ba},
  {0x1bc, 0x1bf}, {0x1c4, 0x1c4}, {0x1c6, 0x1c7}, {0x1c9, 0x1ca}, {0x1cc, 0x1f1}, {0x1f3, 0x293}, {0x295, 0x2af}, {0x370, 0x373},
  {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5},
  {0x3f7, 0x481}, {0x48a, 0x52f}, {0x531, 0x556}, {0x560, 0x588}, {0x660, 0x669}, {0x6f0, 0x6f9}, {0x7c0, 0x7c9}, {0x966, 0x96f},
  {0x9e6, 0x9ef}, {0xa66, 0xa6f}, {0xae6, 0xaef}, {0xb66, 0xb6f}, {0xbe6, 0xbef}, {0xc66, 0xc6f}, {0xce6, 0xcef}, {0xd66, 0xd6f},
  {0xde6, 0xdef}, {0xe50, 0xe59}, {0xed0, 0xed9}, {0xf20, 0xf29}, {0x1040, 0x1049}, {0x1090, 0x1099}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7},
  {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fd, 0x10ff}, {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x17e0, 0x17e9}, {0x1810, 0x1819}, {0x1946, 0x194f},
  {0x19d0, 0x19d9}, {0x1a80, 0x1a89}, {0x1a90, 0x1a99}, {0x1b50, 0x1b59}, {0x1bb0, 0x1bb9}, {0x1c40, 0x1c49}, {0x1c50, 0x1c59}, {0x1c80, 0x1c88},
  {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1d00, 0x1d2b}, {0x1d6b, 0x1d77}, {0x1d79, 0x1d9a}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45},
  {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1f87}, {0x1f90, 0x1f97},
  {0x1fa0, 0x1fa7}, {0x1fb0, 0x1fb4}, {0x1fb6, 0x1fbb}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcb}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb},
  {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffb}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2119, 0x211d},
  {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x212d}, {0x212f, 0x2134}, {0x2139, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149},
  {0x214e, 0x214e}, {0x2183, 0x2184}, {0x2c00, 0x2c7b}, {0x2c7e, 0x2ce4}, {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27},
  {0x2d2d, 0x2d2d}, {0xa620, 0xa629}, {0xa640, 0xa66d}, {0xa680, 0xa69b}, {0xa722, 0xa76f}, {0xa771, 0xa787}, {0xa78b, 0xa78e}, {0xa790, 0xa7ca},
  {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f5, 0xa7f6}, {0xa7fa, 0xa7fa}, {0xa8d0, 0xa8d9}, {0xa900, 0xa909}, {0xa9d0, 0xa9d9},
  {0xa9f0, 0xa9f9}, {0xaa50, 0xaa59}, {0xab30, 0xab5a}, {0xab60, 0xab68}, {0xab70, 0xabbf}, {0xabf0, 0xabf9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17},
  {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0x10400, 0x1044f}, {0x104a0, 0x104a9}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10570, 0x1057a},
  {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(71);
      ADVANCE_MAP(
        '"', 5,
        '#', 29,
        '(', 96,
        ')', 97,
        '+', 171,
        ',', 98,
        '-', 14,
        '.', 164,
        '/', 23,
        '0', 132,
        ':', 79,
        ';', 183,
        '<', 143,
        '=', 84,
        '>', 145,
        '@', 82,
        '[', 72,
        '\\', 16,
        ']', 73,
        '_', 139,
        '{', 99,
        '|', 161,
        '}', 100,
        0xac, 150,
        0xb7, 162,
        0x2190, 169,
        0x2192, 167,
        0x21d2, 155,
        0x21d4, 157,
        0x2200, 158,
        0x2203, 159,
        0x2205, 173,
        0x2208, 160,
        0x2227, 151,
        0x2228, 152,
        0x2254, 166,
        0x2260, 142,
        0x2264, 147,
        0x2265, 149,
        0x2295, 172,
        0x22a4, 137,
        0x22a5, 138,
        0x22bb, 153,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(70);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(131);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(76);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '"', 5,
        '#', 29,
        '(', 96,
        ')', 97,
        '+', 15,
        '-', 14,
        '.', 163,
        '0', 129,
        ':', 78,
        ';', 183,
        '<', 117,
        '>', 121,
        '@', 81,
        '[', 72,
        '\\', 16,
        ']', 73,
        '{', 99,
        '}', 100,
        0xac, 150,
        0xb7, 162,
        0x2192, 167,
        0x2200, 158,
        0x2203, 159,
        0x2205, 173,
        0x22a4, 137,
        0x22a5, 138,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(130);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '"', 5,
        '#', 29,
        '(', 96,
        ')', 97,
        '+', 15,
        '-', 14,
        '0', 129,
        ':', 19,
        ';', 183,
        '<', 117,
        '@', 66,
        '[', 72,
        '\\', 16,
        ']', 73,
        '{', 99,
        0x2192, 167,
        0x2205, 173,
        0x22a4, 137,
        0x22a5, 138,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(130);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '"', 5,
        '#', 29,
        '(', 96,
        ')', 97,
        '+', 15,
        '-', 14,
        '0', 129,
        ';', 183,
        '<', 117,
        '@', 81,
        '[', 72,
        '\\', 16,
        ']', 73,
        '{', 99,
        '}', 100,
        0xac, 150,
        0x2192, 167,
        0x2200, 158,
        0x2203, 159,
        0x2205, 173,
        0x22a4, 137,
        0x22a5, 138,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(130);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '"', 5,
        '#', 29,
        '(', 96,
        ')', 97,
        '+', 15,
        '-', 14,
        '0', 129,
        ';', 183,
        '<', 117,
        '[', 72,
        '\\', 16,
        ']', 73,
        '{', 99,
        0x2192, 167,
        0x2205, 173,
        0x22a4, 137,
        0x22a5, 138,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(130);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 5:
      if (lookahead == '"') ADVANCE(101);
      if (lookahead == '\\') ADVANCE(31);
      if (lookahead > 0x08 &&
          (lookahead < 0x0b || 0x1f < lookahead) &&
          lookahead != 0x7f) ADVANCE(5);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '(', 96,
        ')', 97,
        '+', 171,
        ',', 98,
        '-', 25,
        '.', 163,
        '/', 23,
        '0', 135,
        ':', 80,
        ';', 183,
        '<', 144,
        '=', 84,
        '>', 145,
        '@', 81,
        '[', 72,
        ']', 73,
        '_', 139,
        '{', 99,
        '|', 161,
        '}', 100,
        0xb7, 162,
        0x2192, 167,
        0x21d2, 155,
        0x21d4, 157,
        0x2200, 158,
        0x2203, 159,
        0x2208, 160,
        0x2227, 151,
        0x2228, 152,
        0x2254, 166,
        0x2260, 142,
        0x2264, 147,
        0x2265, 149,
        0x2295, 172,
        0x22bb, 153,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(136);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '(', 96,
        ')', 97,
        '+', 171,
        ',', 98,
        '-', 25,
        '/', 23,
        '0', 135,
        ':', 24,
        ';', 183,
        '<', 144,
        '=', 84,
        '>', 145,
        '@', 81,
        '[', 72,
        ']', 73,
        '_', 139,
        '{', 99,
        '|', 161,
        '}', 100,
        0x2192, 167,
        0x21d2, 155,
        0x21d4, 157,
        0x2200, 158,
        0x2203, 159,
        0x2208, 160,
        0x2227, 151,
        0x2228, 152,
        0x2254, 166,
        0x2260, 142,
        0x2264, 147,
        0x2265, 149,
        0x2295, 172,
        0x22bb, 153,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(136);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '(', 96,
        ')', 97,
        ',', 98,
        '-', 25,
        '.', 13,
        '/', 23,
        ':', 20,
        ';', 183,
        '<', 144,
        '=', 84,
        '>', 145,
        '@', 81,
        '}', 100,
        0x2192, 167,
        0x21d2, 155,
        0x21d4, 157,
        0x2227, 151,
        0x2228, 152,
        0x2260, 142,
        0x2264, 147,
        0x2265, 149,
        0x22bb, 153,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '(', 96,
        ')', 97,
        ',', 98,
        '-', 25,
        '.', 13,
        '/', 23,
        ':', 20,
        ';', 183,
        '<', 144,
        '=', 84,
        '>', 145,
        '@', 83,
        '}', 100,
        0x2192, 167,
        0x21d2, 155,
        0x21d4, 157,
        0x2227, 151,
        0x2228, 152,
        0x2260, 142,
        0x2264, 147,
        0x2265, 149,
        0x22bb, 153,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 10:
      if (lookahead == ')') ADVANCE(97);
      if (lookahead == ';') ADVANCE(183);
      if (lookahead == '<') ADVANCE(12);
      if (lookahead == '@') ADVANCE(82);
      if (lookahead == 0x2190) ADVANCE(169);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 11:
      if (lookahead == ')') ADVANCE(97);
      if (lookahead == ';') ADVANCE(183);
      if (lookahead == '<') ADVANCE(12);
      if (lookahead == '@') ADVANCE(81);
      if (lookahead == 0x2190) ADVANCE(169);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 12:
      if (lookahead == '-') ADVANCE(170);
      END_STATE();
    case 13:
      if (lookahead == '.') ADVANCE(140);
      END_STATE();
    case 14:
      if (lookahead == '0') ADVANCE(129);
      if (lookahead == '>') ADVANCE(168);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(130);
      END_STATE();
    case 15:
      if (lookahead == '0') ADVANCE(129);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(130);
      END_STATE();
    case 16:
      if (lookahead == '0') ADVANCE(128);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(133);
      END_STATE();
    case 17:
      if (lookahead == '0') ADVANCE(125);
      if (lookahead == '+' ||
          lookahead == '-' ||
          lookahead == '\\') ADVANCE(18);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(126);
      END_STATE();
    case 18:
      if (lookahead == '0') ADVANCE(125);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(126);
      END_STATE();
    case 19:
      if (lookahead == ':') ADVANCE(75);
      END_STATE();
    case 20:
      if (lookahead == ':') ADVANCE(74);
      END_STATE();
    case 21:
      if (lookahead == ':') ADVANCE(74);
      if (lookahead == '=') ADVANCE(165);
      END_STATE();
    case 22:
      if (lookahead == ';') ADVANCE(183);
      if (lookahead == ']') ADVANCE(73);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(47);
      END_STATE();
    case 23:
      if (lookahead == '=') ADVANCE(141);
      END_STATE();
    case 24:
      if (lookahead == '=') ADVANCE(165);
      END_STATE();
    case 25:
      if (lookahead == '>') ADVANCE(168);
      END_STATE();
    case 26:
      if (lookahead == '>') ADVANCE(154);
      END_STATE();
    case 27:
      if (lookahead == '>') ADVANCE(156);
      END_STATE();
    case 28:
      if (lookahead == 'U') ADVANCE(57);
      if (lookahead == 'u') ADVANCE(53);
      END_STATE();
    case 29:
      if (lookahead == '[') ADVANCE(122);
      END_STATE();
    case 30:
      if (lookahead == '_') ADVANCE(30);
      if (set_contains(sym_identifier_character_set_2, 151, lookahead)) ADVANCE(77);
      END_STATE();
    case 31:
      ADVANCE_MAP(
        'u', 32,
        '"', 5,
        '/', 5,
        '\\', 5,
        'a', 5,
        'b', 5,
        'e', 5,
        'f', 5,
        'n', 5,
        'r', 5,
        't', 5,
        'v', 5,
      );
      END_STATE();
    case 32:
      if (lookahead == '{') ADVANCE(50);
      END_STATE();
    case 33:
      if (lookahead == '}') ADVANCE(5);
      END_STATE();
    case 34:
      if (lookahead == '}') ADVANCE(5);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(33);
      END_STATE();
    case 35:
      if (lookahead == '}') ADVANCE(5);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(34);
      END_STATE();
    case 36:
      if (lookahead == '}') ADVANCE(5);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(35);
      END_STATE();
    case 37:
      if (lookahead == '}') ADVANCE(5);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(36);
      END_STATE();
    case 38:
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(134);
      END_STATE();
    case 39:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(127);
      END_STATE();
    case 40:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(102);
      END_STATE();
    case 41:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(46);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(59);
      END_STATE();
    case 42:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(46);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(60);
      END_STATE();
    case 43:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(46);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(61);
      END_STATE();
    case 44:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(46);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(62);
      END_STATE();
    case 45:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(46);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(63);
      END_STATE();
    case 46:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(40);
      END_STATE();
    case 47:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(123);
      END_STATE();
    case 48:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(37);
      END_STATE();
    case 49:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(119);
      END_STATE();
    case 50:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(48);
      END_STATE();
    case 51:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(49);
      END_STATE();
    case 52:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(51);
      END_STATE();
    case 53:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(52);
      END_STATE();
    case 54:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(53);
      END_STATE();
    case 55:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(54);
      END_STATE();
    case 56:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(55);
      END_STATE();
    case 57:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(56);
      END_STATE();
    case 58:
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(69);
      END_STATE();
    case 59:
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(114);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(68);
      END_STATE();
    case 60:
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(102);
      END_STATE();
    case 61:
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(102);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(68);
      END_STATE();
    case 62:
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(115);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(68);
      END_STATE();
    case 63:
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(116);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(68);
      END_STATE();
    case 64:
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(87);
      END_STATE();
    case 65:
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(108);
      END_STATE();
    case 66:
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(65);
      END_STATE();
    case 67:
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(110);
      END_STATE();
    case 68:
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(67);
      END_STATE();
    case 69:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(95);
      END_STATE();
    case 70:
      if (eof) ADVANCE(71);
      ADVANCE_MAP(
        '"', 5,
        '#', 29,
        '(', 96,
        ')', 97,
        '+', 171,
        ',', 98,
        '-', 14,
        '.', 13,
        '/', 23,
        '0', 132,
        ':', 21,
        ';', 183,
        '<', 143,
        '=', 84,
        '>', 145,
        '@', 81,
        '[', 72,
        '\\', 16,
        ']', 73,
        '_', 139,
        '{', 99,
        '|', 161,
        '}', 100,
        0xac, 150,
        0x2190, 169,
        0x2192, 167,
        0x21d2, 155,
        0x21d4, 157,
        0x2200, 158,
        0x2203, 159,
        0x2205, 173,
        0x2208, 160,
        0x2227, 151,
        0x2228, 152,
        0x2254, 166,
        0x2260, 142,
        0x2264, 147,
        0x2265, 149,
        0x2295, 172,
        0x22a4, 137,
        0x22a5, 138,
        0x22bb, 153,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(70);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(131);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(76);
      if (set_contains(sym_identifier_character_set_1, 112, lookahead)) ADVANCE(77);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_COLON_COLON2);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(30);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(77);
      if (set_contains(sym_identifier_character_set_2, 151, lookahead)) ADVANCE(77);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '_') ADVANCE(30);
      if (set_contains(sym_identifier_character_set_2, 151, lookahead)) ADVANCE(77);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(75);
      if (lookahead == '=') ADVANCE(165);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '=') ADVANCE(165);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_AT);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(64);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_AT);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(65);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(26);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      if (lookahead == '-') ADVANCE(58);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      if (lookahead == '-') ADVANCE(58);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(86);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(85);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(88);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(89);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(90);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(91);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(92);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(93);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(sym_controlled_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(94);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(sym_quoted_string);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(sym_language_tag);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(41);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(41);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(109);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(41);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(104);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(41);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(105);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(41);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(106);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(41);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(107);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(41);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(103);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(42);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(43);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(44);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(sym_language_tag);
      if (lookahead == '-') ADVANCE(45);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(sym_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(113);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(sym_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(111);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(sym_language_tag);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(112);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(aux_sym_iri_token1);
      if (lookahead == ';') ADVANCE(120);
      if (lookahead == '\\') ADVANCE(28);
      if (lookahead > ' ' &&
          lookahead != '"' &&
          lookahead != ';' &&
          lookahead != '<' &&
          lookahead != '>' &&
          lookahead != '^' &&
          lookahead != '`' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(119);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(aux_sym_iri_token1);
      if (lookahead == '\\') ADVANCE(28);
      if (lookahead > ' ' &&
          lookahead != '"' &&
          lookahead != '<' &&
          lookahead != '>' &&
          lookahead != '^' &&
          lookahead != '`' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(119);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(aux_sym_iri_token1);
      if (lookahead == '\\') ADVANCE(174);
      if ((!eof && lookahead <= '\t') ||
          (0x0b <= lookahead && lookahead <= ' ') ||
          lookahead == '"' ||
          lookahead == '<' ||
          lookahead == '>' ||
          lookahead == '^' ||
          lookahead == '`' ||
          ('{' <= lookahead && lookahead <= '}')) ADVANCE(183);
      if (lookahead > ' ') ADVANCE(120);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_POUND_LBRACK);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(sym_hex_byte);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(sym_hex_byte);
      if (lookahead == '.') ADVANCE(39);
      if (lookahead == '/') ADVANCE(38);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(130);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(sym_double);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(sym_double);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(126);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(sym_decimal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(17);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(127);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(39);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(39);
      if (lookahead == '/') ADVANCE(38);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(39);
      if (lookahead == '/') ADVANCE(38);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(130);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(39);
      if (lookahead == '/') ADVANCE(38);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(124);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(123);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(39);
      if (lookahead == '/') ADVANCE(38);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(123);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(39);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(133);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(sym_rational);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(134);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(sym_unsigned);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(sym_unsigned);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(136);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_u22a4);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_u22a5);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(sym_wildcard);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_u2260);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(sym_op_less_than);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(sym_op_less_than);
      if (lookahead == '=') ADVANCE(146);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(sym_op_greater_than);
      if (lookahead == '=') ADVANCE(148);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      if (lookahead == '=') ADVANCE(27);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_u2264);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_u2265);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_u00ac);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_u2227);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_u2228);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_u22bb);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_EQ_EQ_GT);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_u21d2);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_LT_EQ_EQ_GT);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_u21d4);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_u2200);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_u2203);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_u2208);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(sym_set_op_builder);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_u00b7);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(140);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_u2254);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_u2192);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_u2190);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_u2295);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_u2205);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead == 'U') ADVANCE(182);
      if (lookahead == 'u') ADVANCE(178);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(183);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_line_comment);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(120);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(183);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_line_comment);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(175);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(183);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(sym_line_comment);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(176);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(183);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym_line_comment);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(177);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(183);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(sym_line_comment);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(178);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(183);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(sym_line_comment);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(179);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(183);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(sym_line_comment);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(180);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(183);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(sym_line_comment);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(181);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(183);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(183);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'N', 1,
        'T', 2,
        'a', 3,
        'b', 4,
        'c', 5,
        'd', 6,
        'e', 7,
        'f', 8,
        'g', 9,
        'h', 10,
        'i', 11,
        'l', 12,
        'm', 13,
        'n', 14,
        'o', 15,
        'p', 16,
        'r', 17,
        's', 18,
        't', 19,
        'u', 20,
        'v', 21,
        'w', 22,
        'x', 23,
        'y', 24,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'o') ADVANCE(25);
      END_STATE();
    case 2:
      if (lookahead == 'h') ADVANCE(26);
      END_STATE();
    case 3:
      ACCEPT_TOKEN(anon_sym_a);
      if (lookahead == 'n') ADVANCE(27);
      if (lookahead == 's') ADVANCE(28);
      END_STATE();
    case 4:
      if (lookahead == 'a') ADVANCE(29);
      if (lookahead == 'i') ADVANCE(30);
      if (lookahead == 'o') ADVANCE(31);
      if (lookahead == 'y') ADVANCE(32);
      END_STATE();
    case 5:
      if (lookahead == 'l') ADVANCE(33);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(34);
      if (lookahead == 'e') ADVANCE(35);
      if (lookahead == 'i') ADVANCE(36);
      if (lookahead == 'o') ADVANCE(37);
      if (lookahead == 'u') ADVANCE(38);
      END_STATE();
    case 7:
      if (lookahead == 'n') ADVANCE(39);
      if (lookahead == 'v') ADVANCE(40);
      if (lookahead == 'x') ADVANCE(41);
      END_STATE();
    case 8:
      if (lookahead == 'a') ADVANCE(42);
      if (lookahead == 'i') ADVANCE(43);
      if (lookahead == 'l') ADVANCE(44);
      if (lookahead == 'o') ADVANCE(45);
      if (lookahead == 'r') ADVANCE(46);
      END_STATE();
    case 9:
      if (lookahead == 'D') ADVANCE(47);
      if (lookahead == 'M') ADVANCE(48);
      if (lookahead == 'Y') ADVANCE(49);
      END_STATE();
    case 10:
      if (lookahead == 'e') ADVANCE(50);
      END_STATE();
    case 11:
      if (lookahead == 'd') ADVANCE(51);
      if (lookahead == 'f') ADVANCE(52);
      if (lookahead == 'm') ADVANCE(53);
      if (lookahead == 'n') ADVANCE(54);
      if (lookahead == 'r') ADVANCE(55);
      if (lookahead == 's') ADVANCE(56);
      END_STATE();
    case 12:
      if (lookahead == 'a') ADVANCE(57);
      if (lookahead == 'e') ADVANCE(58);
      if (lookahead == 'o') ADVANCE(59);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(60);
      if (lookahead == 'i') ADVANCE(61);
      if (lookahead == 'o') ADVANCE(62);
      END_STATE();
    case 14:
      if (lookahead == 'e') ADVANCE(63);
      if (lookahead == 'o') ADVANCE(64);
      END_STATE();
    case 15:
      if (lookahead == 'f') ADVANCE(65);
      if (lookahead == 'p') ADVANCE(66);
      if (lookahead == 'r') ADVANCE(67);
      END_STATE();
    case 16:
      if (lookahead == 'a') ADVANCE(68);
      if (lookahead == 'o') ADVANCE(69);
      if (lookahead == 'r') ADVANCE(70);
      END_STATE();
    case 17:
      if (lookahead == 'a') ADVANCE(71);
      if (lookahead == 'd') ADVANCE(72);
      if (lookahead == 'e') ADVANCE(73);
      END_STATE();
    case 18:
      if (lookahead == 'e') ADVANCE(74);
      if (lookahead == 'h') ADVANCE(75);
      if (lookahead == 'o') ADVANCE(76);
      if (lookahead == 't') ADVANCE(77);
      END_STATE();
    case 19:
      if (lookahead == 'i') ADVANCE(78);
      if (lookahead == 'o') ADVANCE(79);
      if (lookahead == 'r') ADVANCE(80);
      if (lookahead == 'y') ADVANCE(81);
      END_STATE();
    case 20:
      if (lookahead == 'n') ADVANCE(82);
      END_STATE();
    case 21:
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 22:
      if (lookahead == 'i') ADVANCE(84);
      END_STATE();
    case 23:
      if (lookahead == 'o') ADVANCE(85);
      END_STATE();
    case 24:
      if (lookahead == 'e') ADVANCE(86);
      END_STATE();
    case 25:
      if (lookahead == 't') ADVANCE(87);
      END_STATE();
    case 26:
      if (lookahead == 'i') ADVANCE(88);
      END_STATE();
    case 27:
      if (lookahead == 'd') ADVANCE(89);
      if (lookahead == 'y') ADVANCE(90);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 's') ADVANCE(91);
      END_STATE();
    case 29:
      if (lookahead == 's') ADVANCE(92);
      END_STATE();
    case 30:
      if (lookahead == 'n') ADVANCE(93);
      END_STATE();
    case 31:
      if (lookahead == 'o') ADVANCE(94);
      END_STATE();
    case 32:
      if (lookahead == 't') ADVANCE(95);
      END_STATE();
    case 33:
      if (lookahead == 'a') ADVANCE(96);
      END_STATE();
    case 34:
      if (lookahead == 't') ADVANCE(97);
      if (lookahead == 'y') ADVANCE(98);
      END_STATE();
    case 35:
      if (lookahead == 'c') ADVANCE(99);
      if (lookahead == 'f') ADVANCE(100);
      END_STATE();
    case 36:
      if (lookahead == 'm') ADVANCE(101);
      END_STATE();
    case 37:
      if (lookahead == 'u') ADVANCE(102);
      END_STATE();
    case 38:
      if (lookahead == 'r') ADVANCE(103);
      END_STATE();
    case 39:
      if (lookahead == 'd') ADVANCE(104);
      if (lookahead == 't') ADVANCE(105);
      if (lookahead == 'u') ADVANCE(106);
      END_STATE();
    case 40:
      if (lookahead == 'e') ADVANCE(107);
      END_STATE();
    case 41:
      if (lookahead == 'i') ADVANCE(108);
      if (lookahead == 'p') ADVANCE(109);
      END_STATE();
    case 42:
      if (lookahead == 'l') ADVANCE(110);
      END_STATE();
    case 43:
      if (lookahead == 'x') ADVANCE(111);
      END_STATE();
    case 44:
      if (lookahead == 'o') ADVANCE(112);
      END_STATE();
    case 45:
      if (lookahead == 'r') ADVANCE(113);
      END_STATE();
    case 46:
      if (lookahead == 'a') ADVANCE(114);
      if (lookahead == 'o') ADVANCE(115);
      END_STATE();
    case 47:
      if (lookahead == 'a') ADVANCE(116);
      END_STATE();
    case 48:
      if (lookahead == 'o') ADVANCE(117);
      END_STATE();
    case 49:
      if (lookahead == 'e') ADVANCE(118);
      END_STATE();
    case 50:
      if (lookahead == 'x') ADVANCE(119);
      END_STATE();
    case 51:
      if (lookahead == 'e') ADVANCE(120);
      END_STATE();
    case 52:
      if (lookahead == 'f') ADVANCE(121);
      END_STATE();
    case 53:
      if (lookahead == 'p') ADVANCE(122);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 't') ADVANCE(123);
      END_STATE();
    case 55:
      if (lookahead == 'i') ADVANCE(124);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_is);
      END_STATE();
    case 57:
      if (lookahead == 'n') ADVANCE(125);
      END_STATE();
    case 58:
      if (lookahead == 'n') ADVANCE(126);
      END_STATE();
    case 59:
      if (lookahead == 'n') ADVANCE(127);
      END_STATE();
    case 60:
      if (lookahead == 'x') ADVANCE(128);
      END_STATE();
    case 61:
      if (lookahead == 'n') ADVANCE(129);
      END_STATE();
    case 62:
      if (lookahead == 'd') ADVANCE(130);
      END_STATE();
    case 63:
      if (lookahead == 'g') ADVANCE(131);
      END_STATE();
    case 64:
      if (lookahead == 'n') ADVANCE(132);
      if (lookahead == 'r') ADVANCE(133);
      if (lookahead == 't') ADVANCE(134);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_of);
      END_STATE();
    case 66:
      if (lookahead == 'a') ADVANCE(135);
      if (lookahead == 't') ADVANCE(136);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_or);
      if (lookahead == 'd') ADVANCE(137);
      END_STATE();
    case 68:
      if (lookahead == 'r') ADVANCE(138);
      if (lookahead == 't') ADVANCE(139);
      END_STATE();
    case 69:
      if (lookahead == 's') ADVANCE(140);
      END_STATE();
    case 70:
      if (lookahead == 'o') ADVANCE(141);
      END_STATE();
    case 71:
      if (lookahead == 't') ADVANCE(142);
      END_STATE();
    case 72:
      if (lookahead == 'f') ADVANCE(143);
      END_STATE();
    case 73:
      if (lookahead == 'a') ADVANCE(144);
      if (lookahead == 'f') ADVANCE(145);
      if (lookahead == 'q') ADVANCE(146);
      END_STATE();
    case 74:
      if (lookahead == 'l') ADVANCE(147);
      END_STATE();
    case 75:
      if (lookahead == 'o') ADVANCE(148);
      END_STATE();
    case 76:
      if (lookahead == 'u') ADVANCE(149);
      END_STATE();
    case 77:
      if (lookahead == 'r') ADVANCE(150);
      END_STATE();
    case 78:
      if (lookahead == 'm') ADVANCE(151);
      END_STATE();
    case 79:
      if (lookahead == 'k') ADVANCE(152);
      if (lookahead == 't') ADVANCE(153);
      END_STATE();
    case 80:
      if (lookahead == 'u') ADVANCE(154);
      END_STATE();
    case 81:
      if (lookahead == 'p') ADVANCE(155);
      END_STATE();
    case 82:
      if (lookahead == 'i') ADVANCE(156);
      if (lookahead == 'k') ADVANCE(157);
      if (lookahead == 'o') ADVANCE(158);
      if (lookahead == 's') ADVANCE(159);
      END_STATE();
    case 83:
      if (lookahead == 'r') ADVANCE(160);
      END_STATE();
    case 84:
      if (lookahead == 't') ADVANCE(161);
      END_STATE();
    case 85:
      if (lookahead == 'r') ADVANCE(162);
      END_STATE();
    case 86:
      if (lookahead == 'a') ADVANCE(163);
      END_STATE();
    case 87:
      if (lookahead == 'h') ADVANCE(164);
      END_STATE();
    case 88:
      if (lookahead == 'n') ADVANCE(165);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 90:
      if (lookahead == 'U') ADVANCE(166);
      END_STATE();
    case 91:
      if (lookahead == 'e') ADVANCE(167);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(168);
      END_STATE();
    case 93:
      if (lookahead == 'a') ADVANCE(169);
      END_STATE();
    case 94:
      if (lookahead == 'l') ADVANCE(170);
      END_STATE();
    case 95:
      if (lookahead == 'e') ADVANCE(171);
      END_STATE();
    case 96:
      if (lookahead == 's') ADVANCE(172);
      END_STATE();
    case 97:
      if (lookahead == 'a') ADVANCE(173);
      if (lookahead == 'e') ADVANCE(174);
      END_STATE();
    case 98:
      if (lookahead == 'T') ADVANCE(175);
      END_STATE();
    case 99:
      if (lookahead == 'i') ADVANCE(176);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_def);
      END_STATE();
    case 101:
      if (lookahead == 'e') ADVANCE(177);
      END_STATE();
    case 102:
      if (lookahead == 'b') ADVANCE(178);
      END_STATE();
    case 103:
      if (lookahead == 'a') ADVANCE(179);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_end);
      END_STATE();
    case 105:
      if (lookahead == 'i') ADVANCE(180);
      END_STATE();
    case 106:
      if (lookahead == 'm') ADVANCE(181);
      END_STATE();
    case 107:
      if (lookahead == 'n') ADVANCE(182);
      END_STATE();
    case 108:
      if (lookahead == 's') ADVANCE(183);
      END_STATE();
    case 109:
      if (lookahead == 'l') ADVANCE(184);
      END_STATE();
    case 110:
      if (lookahead == 's') ADVANCE(185);
      END_STATE();
    case 111:
      if (lookahead == 'e') ADVANCE(186);
      END_STATE();
    case 112:
      if (lookahead == 'a') ADVANCE(187);
      END_STATE();
    case 113:
      if (lookahead == 'a') ADVANCE(188);
      END_STATE();
    case 114:
      if (lookahead == 'c') ADVANCE(189);
      END_STATE();
    case 115:
      if (lookahead == 'm') ADVANCE(190);
      END_STATE();
    case 116:
      if (lookahead == 'y') ADVANCE(191);
      END_STATE();
    case 117:
      if (lookahead == 'n') ADVANCE(192);
      END_STATE();
    case 118:
      if (lookahead == 'a') ADVANCE(193);
      END_STATE();
    case 119:
      if (lookahead == 'B') ADVANCE(194);
      END_STATE();
    case 120:
      if (lookahead == 'n') ADVANCE(195);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_iff);
      END_STATE();
    case 122:
      if (lookahead == 'l') ADVANCE(196);
      if (lookahead == 'o') ADVANCE(197);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == 'e') ADVANCE(198);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_iri);
      END_STATE();
    case 125:
      if (lookahead == 'g') ADVANCE(199);
      END_STATE();
    case 126:
      if (lookahead == 'g') ADVANCE(200);
      END_STATE();
    case 127:
      if (lookahead == 'g') ADVANCE(201);
      END_STATE();
    case 128:
      if (lookahead == 'E') ADVANCE(202);
      if (lookahead == 'I') ADVANCE(203);
      if (lookahead == 'L') ADVANCE(204);
      END_STATE();
    case 129:
      if (lookahead == 'E') ADVANCE(205);
      if (lookahead == 'I') ADVANCE(206);
      if (lookahead == 'L') ADVANCE(207);
      END_STATE();
    case 130:
      if (lookahead == 'u') ADVANCE(208);
      END_STATE();
    case 131:
      if (lookahead == 'a') ADVANCE(209);
      END_STATE();
    case 132:
      if (lookahead == 'N') ADVANCE(210);
      if (lookahead == 'P') ADVANCE(211);
      if (lookahead == 'u') ADVANCE(212);
      END_STATE();
    case 133:
      if (lookahead == 'm') ADVANCE(213);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_not);
      END_STATE();
    case 135:
      if (lookahead == 'q') ADVANCE(214);
      END_STATE();
    case 136:
      if (lookahead == 'i') ADVANCE(215);
      END_STATE();
    case 137:
      if (lookahead == 'e') ADVANCE(216);
      END_STATE();
    case 138:
      if (lookahead == 'e') ADVANCE(217);
      END_STATE();
    case 139:
      if (lookahead == 't') ADVANCE(218);
      END_STATE();
    case 140:
      if (lookahead == 'i') ADVANCE(219);
      END_STATE();
    case 141:
      if (lookahead == 'h') ADVANCE(220);
      if (lookahead == 'p') ADVANCE(221);
      END_STATE();
    case 142:
      if (lookahead == 'i') ADVANCE(222);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_rdf);
      END_STATE();
    case 144:
      if (lookahead == 'l') ADVANCE(223);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_ref);
      END_STATE();
    case 146:
      if (lookahead == 'u') ADVANCE(224);
      END_STATE();
    case 147:
      if (lookahead == 'f') ADVANCE(225);
      END_STATE();
    case 148:
      if (lookahead == 'r') ADVANCE(226);
      END_STATE();
    case 149:
      if (lookahead == 'r') ADVANCE(227);
      END_STATE();
    case 150:
      if (lookahead == 'i') ADVANCE(228);
      if (lookahead == 'u') ADVANCE(229);
      END_STATE();
    case 151:
      if (lookahead == 'e') ADVANCE(230);
      END_STATE();
    case 152:
      if (lookahead == 'e') ADVANCE(231);
      END_STATE();
    case 153:
      if (lookahead == 'a') ADVANCE(232);
      END_STATE();
    case 154:
      if (lookahead == 'e') ADVANCE(233);
      END_STATE();
    case 155:
      if (lookahead == 'e') ADVANCE(234);
      END_STATE();
    case 156:
      if (lookahead == 'o') ADVANCE(235);
      if (lookahead == 'q') ADVANCE(236);
      END_STATE();
    case 157:
      if (lookahead == 'n') ADVANCE(237);
      END_STATE();
    case 158:
      if (lookahead == 'r') ADVANCE(238);
      END_STATE();
    case 159:
      if (lookahead == 'i') ADVANCE(239);
      END_STATE();
    case 160:
      if (lookahead == 's') ADVANCE(240);
      END_STATE();
    case 161:
      if (lookahead == 'h') ADVANCE(241);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_xor);
      END_STATE();
    case 163:
      if (lookahead == 'r') ADVANCE(242);
      END_STATE();
    case 164:
      if (lookahead == 'i') ADVANCE(243);
      END_STATE();
    case 165:
      if (lookahead == 'g') ADVANCE(244);
      END_STATE();
    case 166:
      if (lookahead == 'R') ADVANCE(245);
      END_STATE();
    case 167:
      if (lookahead == 'r') ADVANCE(246);
      END_STATE();
    case 168:
      if (lookahead == '6') ADVANCE(247);
      END_STATE();
    case 169:
      if (lookahead == 'r') ADVANCE(248);
      END_STATE();
    case 170:
      if (lookahead == 'e') ADVANCE(249);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_byte);
      END_STATE();
    case 172:
      if (lookahead == 's') ADVANCE(250);
      END_STATE();
    case 173:
      if (lookahead == 't') ADVANCE(251);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_date);
      if (lookahead == 'T') ADVANCE(252);
      END_STATE();
    case 175:
      if (lookahead == 'i') ADVANCE(253);
      END_STATE();
    case 176:
      if (lookahead == 'm') ADVANCE(254);
      END_STATE();
    case 177:
      if (lookahead == 'n') ADVANCE(255);
      END_STATE();
    case 178:
      if (lookahead == 'l') ADVANCE(256);
      END_STATE();
    case 179:
      if (lookahead == 't') ADVANCE(257);
      END_STATE();
    case 180:
      if (lookahead == 't') ADVANCE(258);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 182:
      if (lookahead == 't') ADVANCE(259);
      END_STATE();
    case 183:
      if (lookahead == 't') ADVANCE(260);
      END_STATE();
    case 184:
      if (lookahead == 'i') ADVANCE(261);
      END_STATE();
    case 185:
      if (lookahead == 'e') ADVANCE(262);
      END_STATE();
    case 186:
      if (lookahead == 'd') ADVANCE(263);
      END_STATE();
    case 187:
      if (lookahead == 't') ADVANCE(264);
      END_STATE();
    case 188:
      if (lookahead == 'l') ADVANCE(265);
      END_STATE();
    case 189:
      if (lookahead == 't') ADVANCE(266);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_from);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_gDay);
      END_STATE();
    case 192:
      if (lookahead == 't') ADVANCE(267);
      END_STATE();
    case 193:
      if (lookahead == 'r') ADVANCE(268);
      END_STATE();
    case 194:
      if (lookahead == 'i') ADVANCE(269);
      END_STATE();
    case 195:
      if (lookahead == 't') ADVANCE(270);
      END_STATE();
    case 196:
      if (lookahead == 'i') ADVANCE(271);
      END_STATE();
    case 197:
      if (lookahead == 'r') ADVANCE(272);
      END_STATE();
    case 198:
      if (lookahead == 'g') ADVANCE(273);
      END_STATE();
    case 199:
      if (lookahead == 'u') ADVANCE(274);
      END_STATE();
    case 200:
      if (lookahead == 't') ADVANCE(275);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_long);
      END_STATE();
    case 202:
      if (lookahead == 'x') ADVANCE(276);
      END_STATE();
    case 203:
      if (lookahead == 'n') ADVANCE(277);
      END_STATE();
    case 204:
      if (lookahead == 'e') ADVANCE(278);
      END_STATE();
    case 205:
      if (lookahead == 'x') ADVANCE(279);
      END_STATE();
    case 206:
      if (lookahead == 'n') ADVANCE(280);
      END_STATE();
    case 207:
      if (lookahead == 'e') ADVANCE(281);
      END_STATE();
    case 208:
      if (lookahead == 'l') ADVANCE(282);
      END_STATE();
    case 209:
      if (lookahead == 't') ADVANCE(283);
      END_STATE();
    case 210:
      if (lookahead == 'e') ADVANCE(284);
      END_STATE();
    case 211:
      if (lookahead == 'o') ADVANCE(285);
      END_STATE();
    case 212:
      if (lookahead == 'n') ADVANCE(286);
      END_STATE();
    case 213:
      if (lookahead == 'a') ADVANCE(287);
      END_STATE();
    case 214:
      if (lookahead == 'u') ADVANCE(288);
      END_STATE();
    case 215:
      if (lookahead == 'o') ADVANCE(289);
      END_STATE();
    case 216:
      if (lookahead == 'r') ADVANCE(290);
      END_STATE();
    case 217:
      if (lookahead == 'n') ADVANCE(291);
      END_STATE();
    case 218:
      if (lookahead == 'e') ADVANCE(292);
      END_STATE();
    case 219:
      if (lookahead == 't') ADVANCE(293);
      END_STATE();
    case 220:
      if (lookahead == 'i') ADVANCE(294);
      END_STATE();
    case 221:
      if (lookahead == 'e') ADVANCE(295);
      END_STATE();
    case 222:
      if (lookahead == 'o') ADVANCE(296);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_real);
      END_STATE();
    case 224:
      if (lookahead == 'i') ADVANCE(297);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(sym_reserved_self);
      END_STATE();
    case 226:
      if (lookahead == 't') ADVANCE(298);
      END_STATE();
    case 227:
      if (lookahead == 'c') ADVANCE(299);
      END_STATE();
    case 228:
      if (lookahead == 'n') ADVANCE(300);
      END_STATE();
    case 229:
      if (lookahead == 'c') ADVANCE(301);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_time);
      END_STATE();
    case 231:
      if (lookahead == 'n') ADVANCE(302);
      END_STATE();
    case 232:
      if (lookahead == 'l') ADVANCE(303);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 235:
      if (lookahead == 'n') ADVANCE(304);
      END_STATE();
    case 236:
      if (lookahead == 'u') ADVANCE(305);
      END_STATE();
    case 237:
      if (lookahead == 'o') ADVANCE(306);
      END_STATE();
    case 238:
      if (lookahead == 'd') ADVANCE(307);
      END_STATE();
    case 239:
      if (lookahead == 'g') ADVANCE(308);
      END_STATE();
    case 240:
      if (lookahead == 'i') ADVANCE(309);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_with);
      if (lookahead == 'o') ADVANCE(310);
      END_STATE();
    case 242:
      if (lookahead == 'M') ADVANCE(311);
      END_STATE();
    case 243:
      if (lookahead == 'n') ADVANCE(312);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(anon_sym_Thing);
      END_STATE();
    case 245:
      if (lookahead == 'I') ADVANCE(313);
      END_STATE();
    case 246:
      if (lookahead == 't') ADVANCE(314);
      END_STATE();
    case 247:
      if (lookahead == '4') ADVANCE(315);
      END_STATE();
    case 248:
      if (lookahead == 'y') ADVANCE(316);
      END_STATE();
    case 249:
      if (lookahead == 'a') ADVANCE(317);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 251:
      if (lookahead == 'y') ADVANCE(318);
      END_STATE();
    case 252:
      if (lookahead == 'i') ADVANCE(319);
      END_STATE();
    case 253:
      if (lookahead == 'm') ADVANCE(320);
      END_STATE();
    case 254:
      if (lookahead == 'a') ADVANCE(321);
      END_STATE();
    case 255:
      if (lookahead == 's') ADVANCE(322);
      END_STATE();
    case 256:
      if (lookahead == 'e') ADVANCE(323);
      END_STATE();
    case 257:
      if (lookahead == 'i') ADVANCE(324);
      END_STATE();
    case 258:
      if (lookahead == 'y') ADVANCE(325);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_event);
      END_STATE();
    case 260:
      if (lookahead == 's') ADVANCE(326);
      END_STATE();
    case 261:
      if (lookahead == 'c') ADVANCE(327);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(sym_kw_is_fixed);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(anon_sym_float);
      END_STATE();
    case 265:
      if (lookahead == 'l') ADVANCE(328);
      END_STATE();
    case 266:
      if (lookahead == 'i') ADVANCE(329);
      END_STATE();
    case 267:
      if (lookahead == 'h') ADVANCE(330);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(anon_sym_gYear);
      if (lookahead == 'M') ADVANCE(331);
      END_STATE();
    case 269:
      if (lookahead == 'n') ADVANCE(332);
      END_STATE();
    case 270:
      if (lookahead == 'i') ADVANCE(333);
      END_STATE();
    case 271:
      if (lookahead == 'e') ADVANCE(334);
      END_STATE();
    case 272:
      if (lookahead == 't') ADVANCE(335);
      END_STATE();
    case 273:
      if (lookahead == 'e') ADVANCE(336);
      END_STATE();
    case 274:
      if (lookahead == 'a') ADVANCE(337);
      END_STATE();
    case 275:
      if (lookahead == 'h') ADVANCE(338);
      END_STATE();
    case 276:
      if (lookahead == 'c') ADVANCE(339);
      END_STATE();
    case 277:
      if (lookahead == 'c') ADVANCE(340);
      END_STATE();
    case 278:
      if (lookahead == 'n') ADVANCE(341);
      END_STATE();
    case 279:
      if (lookahead == 'c') ADVANCE(342);
      END_STATE();
    case 280:
      if (lookahead == 'c') ADVANCE(343);
      END_STATE();
    case 281:
      if (lookahead == 'n') ADVANCE(344);
      END_STATE();
    case 282:
      if (lookahead == 'e') ADVANCE(345);
      END_STATE();
    case 283:
      if (lookahead == 'i') ADVANCE(346);
      END_STATE();
    case 284:
      if (lookahead == 'g') ADVANCE(347);
      END_STATE();
    case 285:
      if (lookahead == 's') ADVANCE(348);
      END_STATE();
    case 286:
      if (lookahead == 'i') ADVANCE(349);
      END_STATE();
    case 287:
      if (lookahead == 'l') ADVANCE(350);
      END_STATE();
    case 288:
      if (lookahead == 'e') ADVANCE(351);
      END_STATE();
    case 289:
      if (lookahead == 'n') ADVANCE(352);
      END_STATE();
    case 290:
      if (lookahead == 'e') ADVANCE(353);
      END_STATE();
    case 291:
      if (lookahead == 't') ADVANCE(354);
      END_STATE();
    case 292:
      if (lookahead == 'r') ADVANCE(355);
      END_STATE();
    case 293:
      if (lookahead == 'i') ADVANCE(356);
      END_STATE();
    case 294:
      if (lookahead == 'b') ADVANCE(357);
      END_STATE();
    case 295:
      if (lookahead == 'r') ADVANCE(358);
      END_STATE();
    case 296:
      if (lookahead == 'n') ADVANCE(359);
      END_STATE();
    case 297:
      if (lookahead == 'r') ADVANCE(360);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(anon_sym_short);
      END_STATE();
    case 299:
      if (lookahead == 'e') ADVANCE(361);
      END_STATE();
    case 300:
      if (lookahead == 'g') ADVANCE(362);
      END_STATE();
    case 301:
      if (lookahead == 't') ADVANCE(363);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(anon_sym_token);
      END_STATE();
    case 303:
      if (lookahead == 'D') ADVANCE(364);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 305:
      if (lookahead == 'e') ADVANCE(365);
      END_STATE();
    case 306:
      if (lookahead == 'w') ADVANCE(366);
      END_STATE();
    case 307:
      if (lookahead == 'e') ADVANCE(367);
      END_STATE();
    case 308:
      if (lookahead == 'n') ADVANCE(368);
      END_STATE();
    case 309:
      if (lookahead == 'o') ADVANCE(369);
      END_STATE();
    case 310:
      if (lookahead == 'u') ADVANCE(370);
      END_STATE();
    case 311:
      if (lookahead == 'o') ADVANCE(371);
      END_STATE();
    case 312:
      if (lookahead == 'g') ADVANCE(372);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(anon_sym_anyURI);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(anon_sym_assert);
      END_STATE();
    case 315:
      if (lookahead == 'B') ADVANCE(373);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(anon_sym_binary);
      END_STATE();
    case 317:
      if (lookahead == 'n') ADVANCE(374);
      END_STATE();
    case 318:
      if (lookahead == 'p') ADVANCE(375);
      END_STATE();
    case 319:
      if (lookahead == 'm') ADVANCE(376);
      END_STATE();
    case 320:
      if (lookahead == 'e') ADVANCE(377);
      END_STATE();
    case 321:
      if (lookahead == 'l') ADVANCE(378);
      END_STATE();
    case 322:
      if (lookahead == 'i') ADVANCE(379);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(anon_sym_double);
      END_STATE();
    case 324:
      if (lookahead == 'o') ADVANCE(380);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(anon_sym_entity);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(anon_sym_exists);
      END_STATE();
    case 327:
      if (lookahead == 'i') ADVANCE(381);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(anon_sym_forall);
      END_STATE();
    case 329:
      if (lookahead == 'o') ADVANCE(382);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(anon_sym_gMonth);
      if (lookahead == 'D') ADVANCE(383);
      END_STATE();
    case 331:
      if (lookahead == 'o') ADVANCE(384);
      END_STATE();
    case 332:
      if (lookahead == 'a') ADVANCE(385);
      END_STATE();
    case 333:
      if (lookahead == 't') ADVANCE(386);
      END_STATE();
    case 334:
      if (lookahead == 's') ADVANCE(387);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 336:
      if (lookahead == 'r') ADVANCE(388);
      END_STATE();
    case 337:
      if (lookahead == 'g') ADVANCE(389);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(anon_sym_length);
      END_STATE();
    case 339:
      if (lookahead == 'l') ADVANCE(390);
      END_STATE();
    case 340:
      if (lookahead == 'l') ADVANCE(391);
      END_STATE();
    case 341:
      if (lookahead == 'g') ADVANCE(392);
      END_STATE();
    case 342:
      if (lookahead == 'l') ADVANCE(393);
      END_STATE();
    case 343:
      if (lookahead == 'l') ADVANCE(394);
      END_STATE();
    case 344:
      if (lookahead == 'g') ADVANCE(395);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(anon_sym_module);
      END_STATE();
    case 346:
      if (lookahead == 'v') ADVANCE(396);
      END_STATE();
    case 347:
      if (lookahead == 'a') ADVANCE(397);
      END_STATE();
    case 348:
      if (lookahead == 'i') ADVANCE(398);
      END_STATE();
    case 349:
      if (lookahead == 'q') ADVANCE(399);
      END_STATE();
    case 350:
      if (lookahead == 'i') ADVANCE(400);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(sym_opaque);
      END_STATE();
    case 352:
      if (lookahead == 'a') ADVANCE(401);
      END_STATE();
    case 353:
      if (lookahead == 'd') ADVANCE(402);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(anon_sym_parent);
      END_STATE();
    case 355:
      if (lookahead == 'n') ADVANCE(403);
      END_STATE();
    case 356:
      if (lookahead == 'v') ADVANCE(404);
      END_STATE();
    case 357:
      if (lookahead == 'i') ADVANCE(405);
      END_STATE();
    case 358:
      if (lookahead == 't') ADVANCE(406);
      END_STATE();
    case 359:
      if (lookahead == 'a') ADVANCE(407);
      END_STATE();
    case 360:
      if (lookahead == 'e') ADVANCE(408);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(anon_sym_source);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 363:
      if (lookahead == 'u') ADVANCE(409);
      END_STATE();
    case 364:
      if (lookahead == 'i') ADVANCE(410);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(anon_sym_unique);
      END_STATE();
    case 366:
      if (lookahead == 'n') ADVANCE(411);
      END_STATE();
    case 367:
      if (lookahead == 'r') ADVANCE(412);
      END_STATE();
    case 368:
      if (lookahead == 'e') ADVANCE(413);
      END_STATE();
    case 369:
      if (lookahead == 'n') ADVANCE(414);
      END_STATE();
    case 370:
      if (lookahead == 't') ADVANCE(415);
      END_STATE();
    case 371:
      if (lookahead == 'n') ADVANCE(416);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(anon_sym_Nothing);
      END_STATE();
    case 373:
      if (lookahead == 'i') ADVANCE(417);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(anon_sym_boolean);
      END_STATE();
    case 375:
      if (lookahead == 'e') ADVANCE(418);
      END_STATE();
    case 376:
      if (lookahead == 'e') ADVANCE(419);
      END_STATE();
    case 377:
      if (lookahead == 'D') ADVANCE(420);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(anon_sym_decimal);
      END_STATE();
    case 379:
      if (lookahead == 'o') ADVANCE(421);
      END_STATE();
    case 380:
      if (lookahead == 'n') ADVANCE(422);
      END_STATE();
    case 381:
      if (lookahead == 't') ADVANCE(423);
      END_STATE();
    case 382:
      if (lookahead == 'n') ADVANCE(424);
      END_STATE();
    case 383:
      if (lookahead == 'a') ADVANCE(425);
      END_STATE();
    case 384:
      if (lookahead == 'n') ADVANCE(426);
      END_STATE();
    case 385:
      if (lookahead == 'r') ADVANCE(427);
      END_STATE();
    case 386:
      if (lookahead == 'y') ADVANCE(428);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(anon_sym_implies);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(anon_sym_integer);
      END_STATE();
    case 389:
      if (lookahead == 'e') ADVANCE(429);
      END_STATE();
    case 390:
      if (lookahead == 'u') ADVANCE(430);
      END_STATE();
    case 391:
      if (lookahead == 'u') ADVANCE(431);
      END_STATE();
    case 392:
      if (lookahead == 't') ADVANCE(432);
      END_STATE();
    case 393:
      if (lookahead == 'u') ADVANCE(433);
      END_STATE();
    case 394:
      if (lookahead == 'u') ADVANCE(434);
      END_STATE();
    case 395:
      if (lookahead == 't') ADVANCE(435);
      END_STATE();
    case 396:
      if (lookahead == 'e') ADVANCE(436);
      END_STATE();
    case 397:
      if (lookahead == 't') ADVANCE(437);
      END_STATE();
    case 398:
      if (lookahead == 't') ADVANCE(438);
      END_STATE();
    case 399:
      if (lookahead == 'u') ADVANCE(439);
      END_STATE();
    case 400:
      if (lookahead == 'z') ADVANCE(440);
      END_STATE();
    case 401:
      if (lookahead == 'l') ADVANCE(441);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(anon_sym_ordered);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(anon_sym_pattern);
      END_STATE();
    case 404:
      if (lookahead == 'e') ADVANCE(442);
      END_STATE();
    case 405:
      if (lookahead == 't') ADVANCE(443);
      END_STATE();
    case 406:
      if (lookahead == 'y') ADVANCE(444);
      END_STATE();
    case 407:
      if (lookahead == 'l') ADVANCE(445);
      END_STATE();
    case 408:
      if (lookahead == 'd') ADVANCE(446);
      END_STATE();
    case 409:
      if (lookahead == 'r') ADVANCE(447);
      END_STATE();
    case 410:
      if (lookahead == 'g') ADVANCE(448);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(sym_unknown_type);
      END_STATE();
    case 412:
      if (lookahead == 'e') ADVANCE(449);
      END_STATE();
    case 413:
      if (lookahead == 'd') ADVANCE(450);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(anon_sym_version);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(anon_sym_without);
      END_STATE();
    case 416:
      if (lookahead == 't') ADVANCE(451);
      END_STATE();
    case 417:
      if (lookahead == 'n') ADVANCE(452);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(anon_sym_datatype);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(anon_sym_dateTime);
      if (lookahead == 'S') ADVANCE(453);
      END_STATE();
    case 420:
      if (lookahead == 'u') ADVANCE(454);
      END_STATE();
    case 421:
      if (lookahead == 'n') ADVANCE(455);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(anon_sym_duration);
      END_STATE();
    case 423:
      if (lookahead == 'T') ADVANCE(456);
      END_STATE();
    case 424:
      if (lookahead == 'D') ADVANCE(457);
      END_STATE();
    case 425:
      if (lookahead == 'y') ADVANCE(458);
      END_STATE();
    case 426:
      if (lookahead == 't') ADVANCE(459);
      END_STATE();
    case 427:
      if (lookahead == 'y') ADVANCE(460);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(anon_sym_identity);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(anon_sym_language);
      END_STATE();
    case 430:
      if (lookahead == 's') ADVANCE(461);
      END_STATE();
    case 431:
      if (lookahead == 's') ADVANCE(462);
      END_STATE();
    case 432:
      if (lookahead == 'h') ADVANCE(463);
      END_STATE();
    case 433:
      if (lookahead == 's') ADVANCE(464);
      END_STATE();
    case 434:
      if (lookahead == 's') ADVANCE(465);
      END_STATE();
    case 435:
      if (lookahead == 'h') ADVANCE(466);
      END_STATE();
    case 436:
      if (lookahead == 'I') ADVANCE(467);
      END_STATE();
    case 437:
      if (lookahead == 'i') ADVANCE(468);
      END_STATE();
    case 438:
      if (lookahead == 'i') ADVANCE(469);
      END_STATE();
    case 439:
      if (lookahead == 'e') ADVANCE(470);
      END_STATE();
    case 440:
      if (lookahead == 'e') ADVANCE(471);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(anon_sym_optional);
      END_STATE();
    case 442:
      if (lookahead == 'I') ADVANCE(472);
      END_STATE();
    case 443:
      if (lookahead == 'e') ADVANCE(473);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(anon_sym_property);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(anon_sym_rational);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(anon_sym_required);
      END_STATE();
    case 447:
      if (lookahead == 'e') ADVANCE(474);
      END_STATE();
    case 448:
      if (lookahead == 'i') ADVANCE(475);
      END_STATE();
    case 449:
      if (lookahead == 'd') ADVANCE(476);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(anon_sym_unsigned);
      if (lookahead == 'B') ADVANCE(477);
      if (lookahead == 'I') ADVANCE(478);
      if (lookahead == 'L') ADVANCE(479);
      if (lookahead == 'S') ADVANCE(480);
      END_STATE();
    case 451:
      if (lookahead == 'h') ADVANCE(481);
      END_STATE();
    case 452:
      if (lookahead == 'a') ADVANCE(482);
      END_STATE();
    case 453:
      if (lookahead == 't') ADVANCE(483);
      END_STATE();
    case 454:
      if (lookahead == 'r') ADVANCE(484);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(anon_sym_dimension);
      END_STATE();
    case 456:
      if (lookahead == 'i') ADVANCE(485);
      END_STATE();
    case 457:
      if (lookahead == 'i') ADVANCE(486);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(anon_sym_gMonthDay);
      END_STATE();
    case 459:
      if (lookahead == 'h') ADVANCE(487);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(anon_sym_hexBinary);
      END_STATE();
    case 461:
      if (lookahead == 'i') ADVANCE(488);
      END_STATE();
    case 462:
      if (lookahead == 'i') ADVANCE(489);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_maxLength);
      END_STATE();
    case 464:
      if (lookahead == 'i') ADVANCE(490);
      END_STATE();
    case 465:
      if (lookahead == 'i') ADVANCE(491);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_minLength);
      END_STATE();
    case 467:
      if (lookahead == 'n') ADVANCE(492);
      END_STATE();
    case 468:
      if (lookahead == 'v') ADVANCE(493);
      END_STATE();
    case 469:
      if (lookahead == 'v') ADVANCE(494);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_nonunique);
      END_STATE();
    case 471:
      if (lookahead == 'd') ADVANCE(495);
      END_STATE();
    case 472:
      if (lookahead == 'n') ADVANCE(496);
      END_STATE();
    case 473:
      if (lookahead == 'd') ADVANCE(497);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_structure);
      END_STATE();
    case 475:
      if (lookahead == 't') ADVANCE(498);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_unordered);
      END_STATE();
    case 477:
      if (lookahead == 'y') ADVANCE(499);
      END_STATE();
    case 478:
      if (lookahead == 'n') ADVANCE(500);
      END_STATE();
    case 479:
      if (lookahead == 'o') ADVANCE(501);
      END_STATE();
    case 480:
      if (lookahead == 'h') ADVANCE(502);
      END_STATE();
    case 481:
      if (lookahead == 'D') ADVANCE(503);
      END_STATE();
    case 482:
      if (lookahead == 'r') ADVANCE(504);
      END_STATE();
    case 483:
      if (lookahead == 'a') ADVANCE(505);
      END_STATE();
    case 484:
      if (lookahead == 'a') ADVANCE(506);
      END_STATE();
    case 485:
      if (lookahead == 'm') ADVANCE(507);
      END_STATE();
    case 486:
      if (lookahead == 'g') ADVANCE(508);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_gYearMonth);
      END_STATE();
    case 488:
      if (lookahead == 'v') ADVANCE(509);
      END_STATE();
    case 489:
      if (lookahead == 'v') ADVANCE(510);
      END_STATE();
    case 490:
      if (lookahead == 'v') ADVANCE(511);
      END_STATE();
    case 491:
      if (lookahead == 'v') ADVANCE(512);
      END_STATE();
    case 492:
      if (lookahead == 't') ADVANCE(513);
      END_STATE();
    case 493:
      if (lookahead == 'e') ADVANCE(514);
      END_STATE();
    case 494:
      if (lookahead == 'e') ADVANCE(515);
      END_STATE();
    case 495:
      if (lookahead == 'S') ADVANCE(516);
      END_STATE();
    case 496:
      if (lookahead == 't') ADVANCE(517);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(anon_sym_prohibited);
      END_STATE();
    case 498:
      if (lookahead == 's') ADVANCE(518);
      END_STATE();
    case 499:
      if (lookahead == 't') ADVANCE(519);
      END_STATE();
    case 500:
      if (lookahead == 't') ADVANCE(520);
      END_STATE();
    case 501:
      if (lookahead == 'n') ADVANCE(521);
      END_STATE();
    case 502:
      if (lookahead == 'o') ADVANCE(522);
      END_STATE();
    case 503:
      if (lookahead == 'u') ADVANCE(523);
      END_STATE();
    case 504:
      if (lookahead == 'y') ADVANCE(524);
      END_STATE();
    case 505:
      if (lookahead == 'm') ADVANCE(525);
      END_STATE();
    case 506:
      if (lookahead == 't') ADVANCE(526);
      END_STATE();
    case 507:
      if (lookahead == 'e') ADVANCE(527);
      END_STATE();
    case 508:
      if (lookahead == 'i') ADVANCE(528);
      END_STATE();
    case 509:
      if (lookahead == 'e') ADVANCE(529);
      END_STATE();
    case 510:
      if (lookahead == 'e') ADVANCE(530);
      END_STATE();
    case 511:
      if (lookahead == 'e') ADVANCE(531);
      END_STATE();
    case 512:
      if (lookahead == 'e') ADVANCE(532);
      END_STATE();
    case 513:
      if (lookahead == 'e') ADVANCE(533);
      END_STATE();
    case 514:
      if (lookahead == 'I') ADVANCE(534);
      END_STATE();
    case 515:
      if (lookahead == 'I') ADVANCE(535);
      END_STATE();
    case 516:
      if (lookahead == 't') ADVANCE(536);
      END_STATE();
    case 517:
      if (lookahead == 'e') ADVANCE(537);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(anon_sym_totalDigits);
      END_STATE();
    case 519:
      if (lookahead == 'e') ADVANCE(538);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_unsignedInt);
      END_STATE();
    case 521:
      if (lookahead == 'g') ADVANCE(539);
      END_STATE();
    case 522:
      if (lookahead == 'r') ADVANCE(540);
      END_STATE();
    case 523:
      if (lookahead == 'r') ADVANCE(541);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(anon_sym_base64Binary);
      END_STATE();
    case 525:
      if (lookahead == 'p') ADVANCE(542);
      END_STATE();
    case 526:
      if (lookahead == 'i') ADVANCE(543);
      END_STATE();
    case 527:
      if (lookahead == 'z') ADVANCE(544);
      END_STATE();
    case 528:
      if (lookahead == 't') ADVANCE(545);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(anon_sym_maxExclusive);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(anon_sym_maxInclusive);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym_minExclusive);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(anon_sym_minInclusive);
      END_STATE();
    case 533:
      if (lookahead == 'g') ADVANCE(546);
      END_STATE();
    case 534:
      if (lookahead == 'n') ADVANCE(547);
      END_STATE();
    case 535:
      if (lookahead == 'n') ADVANCE(548);
      END_STATE();
    case 536:
      if (lookahead == 'r') ADVANCE(549);
      END_STATE();
    case 537:
      if (lookahead == 'g') ADVANCE(550);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(anon_sym_unsignedByte);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_unsignedLong);
      END_STATE();
    case 540:
      if (lookahead == 't') ADVANCE(551);
      END_STATE();
    case 541:
      if (lookahead == 'a') ADVANCE(552);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_dateTimeStamp);
      END_STATE();
    case 543:
      if (lookahead == 'o') ADVANCE(553);
      END_STATE();
    case 544:
      if (lookahead == 'o') ADVANCE(554);
      END_STATE();
    case 545:
      if (lookahead == 's') ADVANCE(555);
      END_STATE();
    case 546:
      if (lookahead == 'e') ADVANCE(556);
      END_STATE();
    case 547:
      if (lookahead == 't') ADVANCE(557);
      END_STATE();
    case 548:
      if (lookahead == 't') ADVANCE(558);
      END_STATE();
    case 549:
      if (lookahead == 'i') ADVANCE(559);
      END_STATE();
    case 550:
      if (lookahead == 'e') ADVANCE(560);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(anon_sym_unsignedShort);
      END_STATE();
    case 552:
      if (lookahead == 't') ADVANCE(561);
      END_STATE();
    case 553:
      if (lookahead == 'n') ADVANCE(562);
      END_STATE();
    case 554:
      if (lookahead == 'n') ADVANCE(563);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(anon_sym_fractionDigits);
      END_STATE();
    case 556:
      if (lookahead == 'r') ADVANCE(564);
      END_STATE();
    case 557:
      if (lookahead == 'e') ADVANCE(565);
      END_STATE();
    case 558:
      if (lookahead == 'e') ADVANCE(566);
      END_STATE();
    case 559:
      if (lookahead == 'n') ADVANCE(567);
      END_STATE();
    case 560:
      if (lookahead == 'r') ADVANCE(568);
      END_STATE();
    case 561:
      if (lookahead == 'i') ADVANCE(569);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_dayTimeDuration);
      END_STATE();
    case 563:
      if (lookahead == 'e') ADVANCE(570);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_negativeInteger);
      END_STATE();
    case 565:
      if (lookahead == 'g') ADVANCE(571);
      END_STATE();
    case 566:
      if (lookahead == 'g') ADVANCE(572);
      END_STATE();
    case 567:
      if (lookahead == 'g') ADVANCE(573);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_positiveInteger);
      END_STATE();
    case 569:
      if (lookahead == 'o') ADVANCE(574);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_explicitTimezone);
      END_STATE();
    case 571:
      if (lookahead == 'e') ADVANCE(575);
      END_STATE();
    case 572:
      if (lookahead == 'e') ADVANCE(576);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_normalizedString);
      END_STATE();
    case 574:
      if (lookahead == 'n') ADVANCE(577);
      END_STATE();
    case 575:
      if (lookahead == 'r') ADVANCE(578);
      END_STATE();
    case 576:
      if (lookahead == 'r') ADVANCE(579);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_yearMonthDuration);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_nonNegativeInteger);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_nonPositiveInteger);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 6},
  [2] = {.lex_state = 6},
  [3] = {.lex_state = 6},
  [4] = {.lex_state = 6},
  [5] = {.lex_state = 6},
  [6] = {.lex_state = 9},
  [7] = {.lex_state = 6},
  [8] = {.lex_state = 6},
  [9] = {.lex_state = 6},
  [10] = {.lex_state = 6},
  [11] = {.lex_state = 6},
  [12] = {.lex_state = 6},
  [13] = {.lex_state = 6},
  [14] = {.lex_state = 6},
  [15] = {.lex_state = 6},
  [16] = {.lex_state = 6},
  [17] = {.lex_state = 6},
  [18] = {.lex_state = 6},
  [19] = {.lex_state = 1},
  [20] = {.lex_state = 1},
  [21] = {.lex_state = 1},
  [22] = {.lex_state = 1},
  [23] = {.lex_state = 1},
  [24] = {.lex_state = 1},
  [25] = {.lex_state = 6},
  [26] = {.lex_state = 1},
  [27] = {.lex_state = 1},
  [28] = {.lex_state = 1},
  [29] = {.lex_state = 1},
  [30] = {.lex_state = 1},
  [31] = {.lex_state = 6},
  [32] = {.lex_state = 1},
  [33] = {.lex_state = 6},
  [34] = {.lex_state = 6},
  [35] = {.lex_state = 6},
  [36] = {.lex_state = 6},
  [37] = {.lex_state = 6},
  [38] = {.lex_state = 6},
  [39] = {.lex_state = 6},
  [40] = {.lex_state = 6},
  [41] = {.lex_state = 6},
  [42] = {.lex_state = 6},
  [43] = {.lex_state = 6},
  [44] = {.lex_state = 6},
  [45] = {.lex_state = 6},
  [46] = {.lex_state = 1},
  [47] = {.lex_state = 1},
  [48] = {.lex_state = 1},
  [49] = {.lex_state = 1},
  [50] = {.lex_state = 1},
  [51] = {.lex_state = 1},
  [52] = {.lex_state = 6},
  [53] = {.lex_state = 6},
  [54] = {.lex_state = 1},
  [55] = {.lex_state = 1},
  [56] = {.lex_state = 1},
  [57] = {.lex_state = 1},
  [58] = {.lex_state = 1},
  [59] = {.lex_state = 1},
  [60] = {.lex_state = 1},
  [61] = {.lex_state = 1},
  [62] = {.lex_state = 1},
  [63] = {.lex_state = 1},
  [64] = {.lex_state = 1},
  [65] = {.lex_state = 1},
  [66] = {.lex_state = 1},
  [67] = {.lex_state = 6},
  [68] = {.lex_state = 1},
  [69] = {.lex_state = 1},
  [70] = {.lex_state = 1},
  [71] = {.lex_state = 1},
  [72] = {.lex_state = 1},
  [73] = {.lex_state = 1},
  [74] = {.lex_state = 1},
  [75] = {.lex_state = 6},
  [76] = {.lex_state = 6},
  [77] = {.lex_state = 6},
  [78] = {.lex_state = 6},
  [79] = {.lex_state = 1},
  [80] = {.lex_state = 1},
  [81] = {.lex_state = 1},
  [82] = {.lex_state = 6},
  [83] = {.lex_state = 6},
  [84] = {.lex_state = 6},
  [85] = {.lex_state = 6},
  [86] = {.lex_state = 6},
  [87] = {.lex_state = 6},
  [88] = {.lex_state = 6},
  [89] = {.lex_state = 6},
  [90] = {.lex_state = 6},
  [91] = {.lex_state = 6},
  [92] = {.lex_state = 6},
  [93] = {.lex_state = 6},
  [94] = {.lex_state = 6},
  [95] = {.lex_state = 6},
  [96] = {.lex_state = 6},
  [97] = {.lex_state = 1},
  [98] = {.lex_state = 1},
  [99] = {.lex_state = 1},
  [100] = {.lex_state = 1},
  [101] = {.lex_state = 1},
  [102] = {.lex_state = 1},
  [103] = {.lex_state = 1},
  [104] = {.lex_state = 6},
  [105] = {.lex_state = 6},
  [106] = {.lex_state = 1},
  [107] = {.lex_state = 1},
  [108] = {.lex_state = 1},
  [109] = {.lex_state = 1},
  [110] = {.lex_state = 1},
  [111] = {.lex_state = 1},
  [112] = {.lex_state = 1},
  [113] = {.lex_state = 1},
  [114] = {.lex_state = 1},
  [115] = {.lex_state = 1},
  [116] = {.lex_state = 6},
  [117] = {.lex_state = 2},
  [118] = {.lex_state = 1},
  [119] = {.lex_state = 1},
  [120] = {.lex_state = 6},
  [121] = {.lex_state = 1},
  [122] = {.lex_state = 1},
  [123] = {.lex_state = 6},
  [124] = {.lex_state = 6},
  [125] = {.lex_state = 1},
  [126] = {.lex_state = 6},
  [127] = {.lex_state = 1},
  [128] = {.lex_state = 1},
  [129] = {.lex_state = 1},
  [130] = {.lex_state = 1},
  [131] = {.lex_state = 1},
  [132] = {.lex_state = 1},
  [133] = {.lex_state = 6},
  [134] = {.lex_state = 6},
  [135] = {.lex_state = 1},
  [136] = {.lex_state = 6},
  [137] = {.lex_state = 6},
  [138] = {.lex_state = 6},
  [139] = {.lex_state = 6},
  [140] = {.lex_state = 6},
  [141] = {.lex_state = 6},
  [142] = {.lex_state = 6},
  [143] = {.lex_state = 6},
  [144] = {.lex_state = 1},
  [145] = {.lex_state = 1},
  [146] = {.lex_state = 1},
  [147] = {.lex_state = 1},
  [148] = {.lex_state = 1},
  [149] = {.lex_state = 1},
  [150] = {.lex_state = 1},
  [151] = {.lex_state = 1},
  [152] = {.lex_state = 1},
  [153] = {.lex_state = 1},
  [154] = {.lex_state = 1},
  [155] = {.lex_state = 10},
  [156] = {.lex_state = 6},
  [157] = {.lex_state = 1},
  [158] = {.lex_state = 6},
  [159] = {.lex_state = 1},
  [160] = {.lex_state = 6},
  [161] = {.lex_state = 6},
  [162] = {.lex_state = 6},
  [163] = {.lex_state = 6},
  [164] = {.lex_state = 6},
  [165] = {.lex_state = 1},
  [166] = {.lex_state = 6},
  [167] = {.lex_state = 1},
  [168] = {.lex_state = 1},
  [169] = {.lex_state = 1},
  [170] = {.lex_state = 1},
  [171] = {.lex_state = 6},
  [172] = {.lex_state = 6},
  [173] = {.lex_state = 6},
  [174] = {.lex_state = 6},
  [175] = {.lex_state = 6},
  [176] = {.lex_state = 6},
  [177] = {.lex_state = 6},
  [178] = {.lex_state = 6},
  [179] = {.lex_state = 1},
  [180] = {.lex_state = 6},
  [181] = {.lex_state = 6},
  [182] = {.lex_state = 6},
  [183] = {.lex_state = 1},
  [184] = {.lex_state = 1},
  [185] = {.lex_state = 6},
  [186] = {.lex_state = 6},
  [187] = {.lex_state = 6},
  [188] = {.lex_state = 1},
  [189] = {.lex_state = 1},
  [190] = {.lex_state = 6},
  [191] = {.lex_state = 1},
  [192] = {.lex_state = 6},
  [193] = {.lex_state = 6},
  [194] = {.lex_state = 6},
  [195] = {.lex_state = 6},
  [196] = {.lex_state = 6},
  [197] = {.lex_state = 1},
  [198] = {.lex_state = 6},
  [199] = {.lex_state = 6},
  [200] = {.lex_state = 6},
  [201] = {.lex_state = 6},
  [202] = {.lex_state = 6},
  [203] = {.lex_state = 6},
  [204] = {.lex_state = 6},
  [205] = {.lex_state = 6},
  [206] = {.lex_state = 6},
  [207] = {.lex_state = 6},
  [208] = {.lex_state = 6},
  [209] = {.lex_state = 6},
  [210] = {.lex_state = 6},
  [211] = {.lex_state = 6},
  [212] = {.lex_state = 6},
  [213] = {.lex_state = 6},
  [214] = {.lex_state = 6},
  [215] = {.lex_state = 6},
  [216] = {.lex_state = 6},
  [217] = {.lex_state = 1},
  [218] = {.lex_state = 6},
  [219] = {.lex_state = 6},
  [220] = {.lex_state = 6},
  [221] = {.lex_state = 6},
  [222] = {.lex_state = 6},
  [223] = {.lex_state = 1},
  [224] = {.lex_state = 6},
  [225] = {.lex_state = 6},
  [226] = {.lex_state = 6},
  [227] = {.lex_state = 6},
  [228] = {.lex_state = 6},
  [229] = {.lex_state = 6},
  [230] = {.lex_state = 6},
  [231] = {.lex_state = 6},
  [232] = {.lex_state = 6},
  [233] = {.lex_state = 6},
  [234] = {.lex_state = 6},
  [235] = {.lex_state = 6},
  [236] = {.lex_state = 6},
  [237] = {.lex_state = 6},
  [238] = {.lex_state = 6},
  [239] = {.lex_state = 6},
  [240] = {.lex_state = 6},
  [241] = {.lex_state = 6},
  [242] = {.lex_state = 6},
  [243] = {.lex_state = 6},
  [244] = {.lex_state = 6},
  [245] = {.lex_state = 6},
  [246] = {.lex_state = 6},
  [247] = {.lex_state = 6},
  [248] = {.lex_state = 6},
  [249] = {.lex_state = 6},
  [250] = {.lex_state = 6},
  [251] = {.lex_state = 6},
  [252] = {.lex_state = 6},
  [253] = {.lex_state = 6},
  [254] = {.lex_state = 6},
  [255] = {.lex_state = 6},
  [256] = {.lex_state = 6},
  [257] = {.lex_state = 6},
  [258] = {.lex_state = 6},
  [259] = {.lex_state = 6},
  [260] = {.lex_state = 6},
  [261] = {.lex_state = 6},
  [262] = {.lex_state = 6},
  [263] = {.lex_state = 6},
  [264] = {.lex_state = 6},
  [265] = {.lex_state = 6},
  [266] = {.lex_state = 6},
  [267] = {.lex_state = 6},
  [268] = {.lex_state = 6},
  [269] = {.lex_state = 6},
  [270] = {.lex_state = 6},
  [271] = {.lex_state = 6},
  [272] = {.lex_state = 6},
  [273] = {.lex_state = 6},
  [274] = {.lex_state = 6},
  [275] = {.lex_state = 6},
  [276] = {.lex_state = 6},
  [277] = {.lex_state = 6},
  [278] = {.lex_state = 6},
  [279] = {.lex_state = 6},
  [280] = {.lex_state = 6},
  [281] = {.lex_state = 6},
  [282] = {.lex_state = 6},
  [283] = {.lex_state = 6},
  [284] = {.lex_state = 6},
  [285] = {.lex_state = 6},
  [286] = {.lex_state = 6},
  [287] = {.lex_state = 6},
  [288] = {.lex_state = 6},
  [289] = {.lex_state = 6},
  [290] = {.lex_state = 6},
  [291] = {.lex_state = 6},
  [292] = {.lex_state = 6},
  [293] = {.lex_state = 6},
  [294] = {.lex_state = 6},
  [295] = {.lex_state = 6},
  [296] = {.lex_state = 6},
  [297] = {.lex_state = 6},
  [298] = {.lex_state = 6},
  [299] = {.lex_state = 6},
  [300] = {.lex_state = 6},
  [301] = {.lex_state = 6},
  [302] = {.lex_state = 6},
  [303] = {.lex_state = 6},
  [304] = {.lex_state = 6},
  [305] = {.lex_state = 6},
  [306] = {.lex_state = 6},
  [307] = {.lex_state = 6},
  [308] = {.lex_state = 6},
  [309] = {.lex_state = 6},
  [310] = {.lex_state = 6},
  [311] = {.lex_state = 6},
  [312] = {.lex_state = 6},
  [313] = {.lex_state = 6},
  [314] = {.lex_state = 6},
  [315] = {.lex_state = 6},
  [316] = {.lex_state = 6},
  [317] = {.lex_state = 6},
  [318] = {.lex_state = 6},
  [319] = {.lex_state = 6},
  [320] = {.lex_state = 6},
  [321] = {.lex_state = 6},
  [322] = {.lex_state = 6},
  [323] = {.lex_state = 6},
  [324] = {.lex_state = 6},
  [325] = {.lex_state = 6},
  [326] = {.lex_state = 6},
  [327] = {.lex_state = 6},
  [328] = {.lex_state = 6},
  [329] = {.lex_state = 6},
  [330] = {.lex_state = 6},
  [331] = {.lex_state = 6},
  [332] = {.lex_state = 6},
  [333] = {.lex_state = 6},
  [334] = {.lex_state = 6},
  [335] = {.lex_state = 6},
  [336] = {.lex_state = 6},
  [337] = {.lex_state = 6},
  [338] = {.lex_state = 6},
  [339] = {.lex_state = 6},
  [340] = {.lex_state = 6},
  [341] = {.lex_state = 6},
  [342] = {.lex_state = 6},
  [343] = {.lex_state = 6},
  [344] = {.lex_state = 6},
  [345] = {.lex_state = 6},
  [346] = {.lex_state = 6},
  [347] = {.lex_state = 6},
  [348] = {.lex_state = 6},
  [349] = {.lex_state = 6},
  [350] = {.lex_state = 6},
  [351] = {.lex_state = 6},
  [352] = {.lex_state = 1},
  [353] = {.lex_state = 6},
  [354] = {.lex_state = 6},
  [355] = {.lex_state = 6},
  [356] = {.lex_state = 6},
  [357] = {.lex_state = 6},
  [358] = {.lex_state = 6},
  [359] = {.lex_state = 6},
  [360] = {.lex_state = 6},
  [361] = {.lex_state = 6},
  [362] = {.lex_state = 6},
  [363] = {.lex_state = 6},
  [364] = {.lex_state = 6},
  [365] = {.lex_state = 6},
  [366] = {.lex_state = 6},
  [367] = {.lex_state = 6},
  [368] = {.lex_state = 6},
  [369] = {.lex_state = 6},
  [370] = {.lex_state = 6},
  [371] = {.lex_state = 6},
  [372] = {.lex_state = 6},
  [373] = {.lex_state = 6},
  [374] = {.lex_state = 6},
  [375] = {.lex_state = 6},
  [376] = {.lex_state = 6},
  [377] = {.lex_state = 6},
  [378] = {.lex_state = 6},
  [379] = {.lex_state = 6},
  [380] = {.lex_state = 6},
  [381] = {.lex_state = 6},
  [382] = {.lex_state = 6},
  [383] = {.lex_state = 6},
  [384] = {.lex_state = 6},
  [385] = {.lex_state = 6},
  [386] = {.lex_state = 6},
  [387] = {.lex_state = 1},
  [388] = {.lex_state = 0},
  [389] = {.lex_state = 6},
  [390] = {.lex_state = 6},
  [391] = {.lex_state = 6},
  [392] = {.lex_state = 6},
  [393] = {.lex_state = 6},
  [394] = {.lex_state = 6},
  [395] = {.lex_state = 6},
  [396] = {.lex_state = 9},
  [397] = {.lex_state = 6},
  [398] = {.lex_state = 6},
  [399] = {.lex_state = 10},
  [400] = {.lex_state = 6},
  [401] = {.lex_state = 6},
  [402] = {.lex_state = 0},
  [403] = {.lex_state = 6},
  [404] = {.lex_state = 6},
  [405] = {.lex_state = 0},
  [406] = {.lex_state = 6},
  [407] = {.lex_state = 6},
  [408] = {.lex_state = 6},
  [409] = {.lex_state = 6},
  [410] = {.lex_state = 6},
  [411] = {.lex_state = 6},
  [412] = {.lex_state = 6},
  [413] = {.lex_state = 6},
  [414] = {.lex_state = 6},
  [415] = {.lex_state = 0},
  [416] = {.lex_state = 6},
  [417] = {.lex_state = 6},
  [418] = {.lex_state = 6},
  [419] = {.lex_state = 6},
  [420] = {.lex_state = 6},
  [421] = {.lex_state = 6},
  [422] = {.lex_state = 6},
  [423] = {.lex_state = 0},
  [424] = {.lex_state = 6},
  [425] = {.lex_state = 6},
  [426] = {.lex_state = 6},
  [427] = {.lex_state = 6},
  [428] = {.lex_state = 6},
  [429] = {.lex_state = 6},
  [430] = {.lex_state = 6},
  [431] = {.lex_state = 6},
  [432] = {.lex_state = 6},
  [433] = {.lex_state = 6},
  [434] = {.lex_state = 6},
  [435] = {.lex_state = 6},
  [436] = {.lex_state = 6},
  [437] = {.lex_state = 6},
  [438] = {.lex_state = 6},
  [439] = {.lex_state = 6},
  [440] = {.lex_state = 0},
  [441] = {.lex_state = 0},
  [442] = {.lex_state = 10},
  [443] = {.lex_state = 6},
  [444] = {.lex_state = 6},
  [445] = {.lex_state = 6},
  [446] = {.lex_state = 1},
  [447] = {.lex_state = 6},
  [448] = {.lex_state = 6},
  [449] = {.lex_state = 22},
  [450] = {.lex_state = 6},
  [451] = {.lex_state = 0},
  [452] = {.lex_state = 2},
  [453] = {.lex_state = 0},
  [454] = {.lex_state = 9},
  [455] = {.lex_state = 0},
  [456] = {.lex_state = 6},
  [457] = {.lex_state = 0},
  [458] = {.lex_state = 6},
  [459] = {.lex_state = 0},
  [460] = {.lex_state = 0},
  [461] = {.lex_state = 6},
  [462] = {.lex_state = 6},
  [463] = {.lex_state = 2},
  [464] = {.lex_state = 6},
  [465] = {.lex_state = 6},
  [466] = {.lex_state = 2},
  [467] = {.lex_state = 6},
  [468] = {.lex_state = 6},
  [469] = {.lex_state = 22},
  [470] = {.lex_state = 0},
  [471] = {.lex_state = 22},
  [472] = {.lex_state = 22},
  [473] = {.lex_state = 6},
  [474] = {.lex_state = 6},
  [475] = {.lex_state = 22},
  [476] = {.lex_state = 2},
  [477] = {.lex_state = 6},
  [478] = {.lex_state = 6},
  [479] = {.lex_state = 6},
  [480] = {.lex_state = 2},
  [481] = {.lex_state = 0},
  [482] = {.lex_state = 6},
  [483] = {.lex_state = 6},
  [484] = {.lex_state = 6},
  [485] = {.lex_state = 6},
  [486] = {.lex_state = 22},
  [487] = {.lex_state = 6},
  [488] = {.lex_state = 6},
  [489] = {.lex_state = 6},
  [490] = {.lex_state = 6},
  [491] = {.lex_state = 0},
  [492] = {.lex_state = 6},
  [493] = {.lex_state = 6},
  [494] = {.lex_state = 6},
  [495] = {.lex_state = 6},
  [496] = {.lex_state = 6},
  [497] = {.lex_state = 6},
  [498] = {.lex_state = 6},
  [499] = {.lex_state = 2},
  [500] = {.lex_state = 6},
  [501] = {.lex_state = 6},
  [502] = {.lex_state = 6},
  [503] = {.lex_state = 6},
  [504] = {.lex_state = 6},
  [505] = {.lex_state = 6},
  [506] = {.lex_state = 6},
  [507] = {.lex_state = 6},
  [508] = {.lex_state = 1},
  [509] = {.lex_state = 6},
  [510] = {.lex_state = 0},
  [511] = {.lex_state = 0},
  [512] = {.lex_state = 0},
  [513] = {.lex_state = 6},
  [514] = {.lex_state = 6},
  [515] = {.lex_state = 6},
  [516] = {.lex_state = 0},
  [517] = {.lex_state = 0},
  [518] = {.lex_state = 6},
  [519] = {.lex_state = 0},
  [520] = {.lex_state = 6},
  [521] = {.lex_state = 0},
  [522] = {.lex_state = 6},
  [523] = {.lex_state = 0},
  [524] = {.lex_state = 0},
  [525] = {.lex_state = 0},
  [526] = {.lex_state = 0},
  [527] = {.lex_state = 0},
  [528] = {.lex_state = 0},
  [529] = {.lex_state = 0},
  [530] = {.lex_state = 0},
  [531] = {.lex_state = 0},
  [532] = {.lex_state = 0},
  [533] = {.lex_state = 6},
  [534] = {.lex_state = 0},
  [535] = {.lex_state = 0},
  [536] = {.lex_state = 6},
  [537] = {.lex_state = 6},
  [538] = {.lex_state = 6},
  [539] = {.lex_state = 0},
  [540] = {.lex_state = 6},
  [541] = {.lex_state = 6},
  [542] = {.lex_state = 6},
  [543] = {.lex_state = 6},
  [544] = {.lex_state = 118},
  [545] = {.lex_state = 6},
  [546] = {.lex_state = 0},
  [547] = {.lex_state = 0},
  [548] = {.lex_state = 0},
  [549] = {.lex_state = 1},
  [550] = {.lex_state = 0},
  [551] = {.lex_state = 0},
  [552] = {.lex_state = 6},
  [553] = {.lex_state = 6},
  [554] = {.lex_state = 1},
  [555] = {.lex_state = 6},
  [556] = {.lex_state = 6},
  [557] = {.lex_state = 6},
  [558] = {.lex_state = 0},
  [559] = {.lex_state = 0},
  [560] = {.lex_state = 6},
  [561] = {.lex_state = 0},
  [562] = {.lex_state = 0},
  [563] = {.lex_state = 6},
  [564] = {.lex_state = 6},
  [565] = {.lex_state = 6},
  [566] = {.lex_state = 0},
  [567] = {.lex_state = 6},
  [568] = {.lex_state = 0},
  [569] = {.lex_state = 6},
  [570] = {.lex_state = 6},
  [571] = {.lex_state = 6},
  [572] = {.lex_state = 0},
  [573] = {.lex_state = 6},
  [574] = {.lex_state = 0},
  [575] = {.lex_state = 118},
  [576] = {.lex_state = 0},
  [577] = {.lex_state = 0},
  [578] = {.lex_state = 6},
  [579] = {.lex_state = 0},
  [580] = {.lex_state = 0},
  [581] = {.lex_state = 0},
  [582] = {.lex_state = 6},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_module] = ACTIONS(1),
    [anon_sym_version] = ACTIONS(1),
    [anon_sym_is] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_from] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_COLON_COLON2] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [sym_controlled_language_tag] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [sym_reserved_self] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_def] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [sym_quoted_string] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_POUND_LBRACK] = ACTIONS(1),
    [sym_hex_byte] = ACTIONS(1),
    [sym_double] = ACTIONS(1),
    [sym_decimal] = ACTIONS(1),
    [sym_integer] = ACTIONS(1),
    [sym_rational] = ACTIONS(1),
    [sym_unsigned] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_u22a4] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [anon_sym_u22a5] = ACTIONS(1),
    [anon_sym_Thing] = ACTIONS(1),
    [anon_sym_Nothing] = ACTIONS(1),
    [anon_sym_real] = ACTIONS(1),
    [anon_sym_rational] = ACTIONS(1),
    [anon_sym_anyURI] = ACTIONS(1),
    [anon_sym_iri] = ACTIONS(1),
    [anon_sym_base64Binary] = ACTIONS(1),
    [anon_sym_boolean] = ACTIONS(1),
    [anon_sym_date] = ACTIONS(1),
    [anon_sym_dateTime] = ACTIONS(1),
    [anon_sym_decimal] = ACTIONS(1),
    [anon_sym_double] = ACTIONS(1),
    [anon_sym_duration] = ACTIONS(1),
    [anon_sym_float] = ACTIONS(1),
    [anon_sym_gDay] = ACTIONS(1),
    [anon_sym_gMonth] = ACTIONS(1),
    [anon_sym_gMonthDay] = ACTIONS(1),
    [anon_sym_gYearMonth] = ACTIONS(1),
    [anon_sym_gYear] = ACTIONS(1),
    [anon_sym_hexBinary] = ACTIONS(1),
    [anon_sym_binary] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [anon_sym_time] = ACTIONS(1),
    [anon_sym_dateTimeStamp] = ACTIONS(1),
    [anon_sym_dayTimeDuration] = ACTIONS(1),
    [anon_sym_yearMonthDuration] = ACTIONS(1),
    [anon_sym_integer] = ACTIONS(1),
    [anon_sym_long] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_short] = ACTIONS(1),
    [anon_sym_byte] = ACTIONS(1),
    [anon_sym_nonNegativeInteger] = ACTIONS(1),
    [anon_sym_positiveInteger] = ACTIONS(1),
    [anon_sym_unsignedLong] = ACTIONS(1),
    [anon_sym_unsignedInt] = ACTIONS(1),
    [anon_sym_unsigned] = ACTIONS(1),
    [anon_sym_unsignedShort] = ACTIONS(1),
    [anon_sym_unsignedByte] = ACTIONS(1),
    [anon_sym_nonPositiveInteger] = ACTIONS(1),
    [anon_sym_negativeInteger] = ACTIONS(1),
    [anon_sym_normalizedString] = ACTIONS(1),
    [anon_sym_token] = ACTIONS(1),
    [anon_sym_language] = ACTIONS(1),
    [anon_sym_without] = ACTIONS(1),
    [anon_sym_datatype] = ACTIONS(1),
    [sym_opaque] = ACTIONS(1),
    [anon_sym_length] = ACTIONS(1),
    [anon_sym_maxLength] = ACTIONS(1),
    [anon_sym_minLength] = ACTIONS(1),
    [anon_sym_fractionDigits] = ACTIONS(1),
    [anon_sym_totalDigits] = ACTIONS(1),
    [anon_sym_maxExclusive] = ACTIONS(1),
    [anon_sym_maxInclusive] = ACTIONS(1),
    [anon_sym_minExclusive] = ACTIONS(1),
    [anon_sym_minInclusive] = ACTIONS(1),
    [anon_sym_explicitTimezone] = ACTIONS(1),
    [anon_sym_required] = ACTIONS(1),
    [anon_sym_prohibited] = ACTIONS(1),
    [anon_sym_optional] = ACTIONS(1),
    [anon_sym_pattern] = ACTIONS(1),
    [sym_kw_is_fixed] = ACTIONS(1),
    [anon_sym_dimension] = ACTIONS(1),
    [anon_sym_source] = ACTIONS(1),
    [anon_sym_parent] = ACTIONS(1),
    [anon_sym_entity] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_of] = ACTIONS(1),
    [anon_sym_event] = ACTIONS(1),
    [anon_sym_property] = ACTIONS(1),
    [anon_sym_rdf] = ACTIONS(1),
    [anon_sym_a] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_structure] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [sym_wildcard] = ACTIONS(1),
    [anon_sym_identity] = ACTIONS(1),
    [anon_sym_ref] = ACTIONS(1),
    [sym_unknown_type] = ACTIONS(1),
    [anon_sym_ordered] = ACTIONS(1),
    [anon_sym_unordered] = ACTIONS(1),
    [anon_sym_unique] = ACTIONS(1),
    [anon_sym_nonunique] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_u2260] = ACTIONS(1),
    [sym_op_less_than] = ACTIONS(1),
    [sym_op_greater_than] = ACTIONS(1),
    [anon_sym_u2264] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_u2265] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_u00ac] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_u2227] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_u2228] = ACTIONS(1),
    [anon_sym_xor] = ACTIONS(1),
    [anon_sym_u22bb] = ACTIONS(1),
    [anon_sym_implies] = ACTIONS(1),
    [anon_sym_EQ_EQ_GT] = ACTIONS(1),
    [anon_sym_u21d2] = ACTIONS(1),
    [anon_sym_iff] = ACTIONS(1),
    [anon_sym_u21d4] = ACTIONS(1),
    [anon_sym_forall] = ACTIONS(1),
    [anon_sym_u2200] = ACTIONS(1),
    [anon_sym_exists] = ACTIONS(1),
    [anon_sym_u2203] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_u2208] = ACTIONS(1),
    [sym_set_op_builder] = ACTIONS(1),
    [anon_sym_u00b7] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_u2254] = ACTIONS(1),
    [anon_sym_u2192] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_u2190] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_u2295] = ACTIONS(1),
    [anon_sym_u2205] = ACTIONS(1),
    [sym_line_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_module] = STATE(579),
    [anon_sym_module] = ACTIONS(5),
    [sym_line_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(7), 7,
      anon_sym_as,
      sym_identifier,
      anon_sym_EQ,
      anon_sym_with,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(9), 54,
      anon_sym_is,
      anon_sym_end,
      anon_sym_import,
      anon_sym_RBRACK,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_without,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_in,
      anon_sym_u2208,
      sym_set_op_builder,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_u2295,
  [69] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(11), 6,
      anon_sym_as,
      sym_identifier,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(13), 55,
      anon_sym_version,
      anon_sym_is,
      anon_sym_end,
      anon_sym_import,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_datatype,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [138] = 12,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(17), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(25), 1,
      sym_unknown_type,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(16), 1,
      sym_cardinality_expression,
    STATE(209), 1,
      sym_type_reference,
    STATE(172), 3,
      sym_identifier_reference,
      sym_builtin_simple_type,
      sym_mapping_type,
    STATE(126), 5,
      sym__owl_builtin_types,
      sym__builtin_primitive_datatypes,
      sym__derived_date_datetypes,
      sym__derived_numeric_datatypes,
      sym__derived_string_datatypes,
    ACTIONS(23), 6,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(21), 37,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [222] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(27), 6,
      sym_identifier,
      anon_sym_EQ,
      anon_sym_with,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(29), 52,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_without,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_in,
      anon_sym_u2208,
      sym_set_op_builder,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_u2295,
  [288] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(35), 1,
      sym_language_tag,
    ACTIONS(31), 6,
      sym_identifier,
      anon_sym_AT,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(33), 51,
      anon_sym_is,
      anon_sym_end,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_datatype,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [356] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(37), 5,
      sym_identifier,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(39), 52,
      anon_sym_is,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_datatype,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [421] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(41), 5,
      sym_identifier,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(43), 52,
      anon_sym_is,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_datatype,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [486] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(45), 5,
      sym_identifier,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(47), 52,
      anon_sym_is,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_datatype,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [551] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(49), 5,
      sym_identifier,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(51), 52,
      anon_sym_is,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_datatype,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [616] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(53), 5,
      sym_identifier,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(55), 52,
      anon_sym_is,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_datatype,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [681] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(57), 5,
      sym_identifier,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(59), 52,
      anon_sym_is,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_datatype,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [746] = 11,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(17), 1,
      anon_sym_LPAREN,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(18), 1,
      sym_cardinality_reference_expression,
    STATE(347), 1,
      sym_function_type_reference,
    STATE(346), 3,
      sym_identifier_reference,
      sym_builtin_simple_type,
      sym_mapping_type,
    STATE(126), 5,
      sym__owl_builtin_types,
      sym__builtin_primitive_datatypes,
      sym__derived_date_datetypes,
      sym__derived_numeric_datatypes,
      sym__derived_string_datatypes,
    ACTIONS(23), 6,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(21), 37,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [827] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(63), 5,
      sym_identifier,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(65), 52,
      anon_sym_is,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_datatype,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [892] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(17), 1,
      anon_sym_LPAREN,
    ACTIONS(25), 1,
      sym_unknown_type,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(453), 1,
      sym_type_reference,
    STATE(172), 3,
      sym_identifier_reference,
      sym_builtin_simple_type,
      sym_mapping_type,
    STATE(126), 5,
      sym__owl_builtin_types,
      sym__builtin_primitive_datatypes,
      sym__derived_date_datetypes,
      sym__derived_numeric_datatypes,
      sym__derived_string_datatypes,
    ACTIONS(23), 6,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(21), 37,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [970] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(17), 1,
      anon_sym_LPAREN,
    ACTIONS(25), 1,
      sym_unknown_type,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(221), 1,
      sym_type_reference,
    STATE(172), 3,
      sym_identifier_reference,
      sym_builtin_simple_type,
      sym_mapping_type,
    STATE(126), 5,
      sym__owl_builtin_types,
      sym__builtin_primitive_datatypes,
      sym__derived_date_datetypes,
      sym__derived_numeric_datatypes,
      sym__derived_string_datatypes,
    ACTIONS(23), 6,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(21), 37,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [1048] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(17), 1,
      anon_sym_LPAREN,
    ACTIONS(25), 1,
      sym_unknown_type,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(519), 1,
      sym_type_reference,
    STATE(172), 3,
      sym_identifier_reference,
      sym_builtin_simple_type,
      sym_mapping_type,
    STATE(126), 5,
      sym__owl_builtin_types,
      sym__builtin_primitive_datatypes,
      sym__derived_date_datetypes,
      sym__derived_numeric_datatypes,
      sym__derived_string_datatypes,
    ACTIONS(23), 6,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(21), 37,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [1126] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(17), 1,
      anon_sym_LPAREN,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(349), 1,
      sym_function_type_reference,
    STATE(346), 3,
      sym_identifier_reference,
      sym_builtin_simple_type,
      sym_mapping_type,
    STATE(126), 5,
      sym__owl_builtin_types,
      sym__builtin_primitive_datatypes,
      sym__derived_date_datetypes,
      sym__derived_numeric_datatypes,
      sym__derived_string_datatypes,
    ACTIONS(23), 6,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(21), 37,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [1201] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(29), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(141), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(226), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(577), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [1325] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(26), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(136), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(224), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(562), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [1449] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(26), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(134), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(224), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(562), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [1573] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(29), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(137), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(200), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(577), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [1697] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(26), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(162), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(224), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(562), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [1821] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(26), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(164), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(224), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(562), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [1945] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(99), 1,
      sym_opaque,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(222), 3,
      sym_identifier_reference,
      sym_builtin_simple_type,
      sym__datatype_base,
    STATE(126), 5,
      sym__owl_builtin_types,
      sym__builtin_primitive_datatypes,
      sym__derived_date_datetypes,
      sym__derived_numeric_datatypes,
      sym__derived_string_datatypes,
    ACTIONS(23), 6,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(21), 37,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [2017] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(26), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(139), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(224), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(562), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [2141] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(26), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(158), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(224), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(562), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [2265] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(29), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(137), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(199), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(577), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [2389] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(29), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(138), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(226), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(577), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [2513] = 34,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(71), 1,
      anon_sym_LPAREN,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(29), 1,
      sym_logical_op_negation,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(140), 1,
      sym_constraint_sentence,
    STATE(181), 1,
      sym_boolean_sentence,
    STATE(186), 1,
      sym_quantified_sentence,
    STATE(198), 1,
      sym_simple_sentence,
    STATE(226), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    STATE(577), 1,
      sym_quantified_variable_binding,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    ACTIONS(91), 2,
      anon_sym_not,
      anon_sym_u00ac,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    STATE(185), 2,
      sym_unary_boolean_sentence,
      sym_binary_boolean_sentence,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(182), 3,
      sym_atomic_sentence,
      sym_equation,
      sym_inequation,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [2637] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(216), 3,
      sym_identifier_reference,
      sym_builtin_simple_type,
      sym__datatype_base,
    STATE(126), 5,
      sym__owl_builtin_types,
      sym__builtin_primitive_datatypes,
      sym__derived_date_datetypes,
      sym__derived_numeric_datatypes,
      sym__derived_string_datatypes,
    ACTIONS(23), 6,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(21), 37,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [2706] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(101), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(103), 42,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_datatype,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_u2205,
  [2760] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(105), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(107), 39,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
      sym_unknown_type,
  [2814] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(109), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(111), 39,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
      sym_unknown_type,
  [2868] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(113), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(115), 39,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
      sym_unknown_type,
  [2922] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(117), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(119), 39,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
      sym_unknown_type,
  [2976] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(121), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(123), 38,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [3029] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(125), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(127), 38,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [3082] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(129), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(131), 38,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [3135] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(133), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(135), 38,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [3188] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(137), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(139), 38,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [3241] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(141), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(143), 38,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [3294] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(145), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(147), 38,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [3347] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(149), 7,
      sym_identifier,
      anon_sym_date,
      anon_sym_dateTime,
      anon_sym_gMonth,
      anon_sym_gYear,
      anon_sym_int,
      anon_sym_unsigned,
    ACTIONS(151), 38,
      anon_sym_LPAREN,
      anon_sym_Thing,
      anon_sym_Nothing,
      anon_sym_real,
      anon_sym_rational,
      anon_sym_anyURI,
      anon_sym_iri,
      anon_sym_base64Binary,
      anon_sym_boolean,
      anon_sym_decimal,
      anon_sym_double,
      anon_sym_duration,
      anon_sym_float,
      anon_sym_gDay,
      anon_sym_gMonthDay,
      anon_sym_gYearMonth,
      anon_sym_hexBinary,
      anon_sym_binary,
      anon_sym_string,
      anon_sym_time,
      anon_sym_dateTimeStamp,
      anon_sym_dayTimeDuration,
      anon_sym_yearMonthDuration,
      anon_sym_integer,
      anon_sym_long,
      anon_sym_short,
      anon_sym_byte,
      anon_sym_nonNegativeInteger,
      anon_sym_positiveInteger,
      anon_sym_unsignedLong,
      anon_sym_unsignedInt,
      anon_sym_unsignedShort,
      anon_sym_unsignedByte,
      anon_sym_nonPositiveInteger,
      anon_sym_negativeInteger,
      anon_sym_normalizedString,
      anon_sym_token,
      anon_sym_language,
  [3400] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(153), 1,
      anon_sym_COLON,
    ACTIONS(27), 2,
      sym_identifier,
      anon_sym_with,
    ACTIONS(29), 34,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_EQ,
      anon_sym_assert,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_LBRACE,
      anon_sym_without,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_in,
      anon_sym_u2208,
      sym_set_op_builder,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_PLUS,
      anon_sym_u2295,
  [3447] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(155), 1,
      sym_identifier,
    ACTIONS(158), 1,
      anon_sym_LBRACK,
    ACTIONS(161), 1,
      anon_sym_RPAREN,
    ACTIONS(163), 1,
      sym_reserved_self,
    ACTIONS(166), 1,
      anon_sym_LBRACE,
    ACTIONS(169), 1,
      sym_quoted_string,
    ACTIONS(172), 1,
      anon_sym_LT,
    ACTIONS(175), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(190), 1,
      anon_sym_u2205,
    STATE(46), 1,
      aux_sym__actual_arguments_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(144), 1,
      sym_term,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(178), 2,
      sym_double,
      sym_rational,
    ACTIONS(184), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(187), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(147), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    ACTIONS(181), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(159), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [3531] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(193), 1,
      sym_identifier,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(197), 1,
      anon_sym_RPAREN,
    ACTIONS(199), 1,
      sym_reserved_self,
    ACTIONS(201), 1,
      anon_sym_LBRACE,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    STATE(46), 1,
      aux_sym__actual_arguments_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(144), 1,
      sym_term,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(147), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(159), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [3615] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(193), 1,
      sym_identifier,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(199), 1,
      sym_reserved_self,
    ACTIONS(201), 1,
      anon_sym_LBRACE,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(219), 1,
      anon_sym_RPAREN,
    STATE(50), 1,
      aux_sym__actual_arguments_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(144), 1,
      sym_term,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(147), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(159), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [3699] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(193), 1,
      sym_identifier,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(199), 1,
      sym_reserved_self,
    ACTIONS(201), 1,
      anon_sym_LBRACE,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(221), 1,
      anon_sym_RPAREN,
    STATE(47), 1,
      aux_sym__actual_arguments_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(144), 1,
      sym_term,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(147), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(159), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [3783] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(193), 1,
      sym_identifier,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(199), 1,
      sym_reserved_self,
    ACTIONS(201), 1,
      anon_sym_LBRACE,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(223), 1,
      anon_sym_RPAREN,
    STATE(46), 1,
      aux_sym__actual_arguments_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(144), 1,
      sym_term,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(147), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(159), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [3867] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(229), 1,
      anon_sym_LPAREN,
    ACTIONS(225), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(227), 30,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_u2205,
  [3912] = 22,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(231), 1,
      anon_sym_end,
    ACTIONS(233), 1,
      anon_sym_import,
    ACTIONS(235), 1,
      anon_sym_from,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(241), 1,
      anon_sym_datatype,
    ACTIONS(243), 1,
      anon_sym_dimension,
    ACTIONS(245), 1,
      anon_sym_entity,
    ACTIONS(247), 1,
      anon_sym_enum,
    ACTIONS(249), 1,
      anon_sym_event,
    ACTIONS(251), 1,
      anon_sym_property,
    ACTIONS(253), 1,
      anon_sym_rdf,
    ACTIONS(255), 1,
      anon_sym_structure,
    ACTIONS(257), 1,
      anon_sym_union,
    ACTIONS(259), 1,
      anon_sym_class,
    STATE(570), 1,
      sym_from_clause,
    STATE(53), 2,
      sym_import_statement,
      aux_sym_module_body_repeat1,
    STATE(84), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(116), 2,
      sym_definition,
      aux_sym_module_body_repeat3,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(303), 10,
      sym_data_type_def,
      sym_dimension_def,
      sym_entity_def,
      sym_enum_def,
      sym_event_def,
      sym_property_def,
      sym_rdf_def,
      sym_structure_def,
      sym_union_def,
      sym_type_class_def,
  [3992] = 22,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(233), 1,
      anon_sym_import,
    ACTIONS(235), 1,
      anon_sym_from,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(241), 1,
      anon_sym_datatype,
    ACTIONS(243), 1,
      anon_sym_dimension,
    ACTIONS(245), 1,
      anon_sym_entity,
    ACTIONS(247), 1,
      anon_sym_enum,
    ACTIONS(249), 1,
      anon_sym_event,
    ACTIONS(251), 1,
      anon_sym_property,
    ACTIONS(253), 1,
      anon_sym_rdf,
    ACTIONS(255), 1,
      anon_sym_structure,
    ACTIONS(257), 1,
      anon_sym_union,
    ACTIONS(259), 1,
      anon_sym_class,
    ACTIONS(261), 1,
      anon_sym_end,
    STATE(570), 1,
      sym_from_clause,
    STATE(83), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(120), 2,
      sym_definition,
      aux_sym_module_body_repeat3,
    STATE(175), 2,
      sym_import_statement,
      aux_sym_module_body_repeat1,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(303), 10,
      sym_data_type_def,
      sym_dimension_def,
      sym_entity_def,
      sym_enum_def,
      sym_event_def,
      sym_property_def,
      sym_rdf_def,
      sym_structure_def,
      sym_union_def,
      sym_type_class_def,
  [4072] = 21,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(166), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [4150] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(225), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(227), 30,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_u2205,
  [4192] = 21,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(163), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [4270] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(263), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(265), 30,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_u2205,
  [4312] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(267), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(269), 30,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_u2205,
  [4354] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(271), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(273), 30,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_u2205,
  [4396] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(275), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(277), 30,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_u2205,
  [4438] = 21,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(67), 1,
      sym_identifier,
    ACTIONS(69), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      sym_reserved_self,
    ACTIONS(75), 1,
      anon_sym_LBRACE,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(97), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(95), 1,
      sym__value_empty_sequence,
    STATE(441), 1,
      sym_term,
    STATE(470), 1,
      sym__sequence_value_constraints,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(88), 2,
      sym_sequence_of_predicate_values,
      sym_simple_value,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
    STATE(89), 5,
      sym_identifier_reference,
      sym_functional_term,
      sym_function_composition,
      sym_predicate_value,
      sym_sequence_builder,
  [4516] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(279), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(281), 30,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_u2205,
  [4558] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(283), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(285), 30,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_u2205,
  [4600] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(287), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(289), 30,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
      anon_sym_u2205,
  [4642] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(293), 1,
      anon_sym_RBRACK,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    STATE(69), 1,
      aux_sym_sequence_of_predicate_values_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(145), 1,
      sym_simple_value,
    STATE(147), 1,
      sym_sequence_of_predicate_values,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(179), 1,
      sym_identifier_reference,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(197), 3,
      sym_predicate_value,
      sym_value_constructor,
      sym_mapping_value,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [4723] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    ACTIONS(297), 1,
      anon_sym_RBRACK,
    STATE(65), 1,
      aux_sym_sequence_of_predicate_values_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(145), 1,
      sym_simple_value,
    STATE(147), 1,
      sym_sequence_of_predicate_values,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(179), 1,
      sym_identifier_reference,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(197), 3,
      sym_predicate_value,
      sym_value_constructor,
      sym_mapping_value,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [4804] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(299), 1,
      anon_sym_COLON,
    STATE(77), 1,
      aux_sym_function_composition_repeat1,
    STATE(553), 1,
      sym__function_op_composition,
    ACTIONS(301), 2,
      anon_sym_u00b7,
      anon_sym_DOT,
    ACTIONS(27), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(29), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [4853] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    ACTIONS(303), 1,
      anon_sym_RBRACK,
    STATE(69), 1,
      aux_sym_sequence_of_predicate_values_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(145), 1,
      sym_simple_value,
    STATE(147), 1,
      sym_sequence_of_predicate_values,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(179), 1,
      sym_identifier_reference,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(197), 3,
      sym_predicate_value,
      sym_value_constructor,
      sym_mapping_value,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [4934] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(305), 1,
      sym_identifier,
    ACTIONS(308), 1,
      anon_sym_LBRACK,
    ACTIONS(311), 1,
      anon_sym_RBRACK,
    ACTIONS(313), 1,
      anon_sym_LBRACE,
    ACTIONS(316), 1,
      sym_quoted_string,
    ACTIONS(319), 1,
      anon_sym_LT,
    ACTIONS(322), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(337), 1,
      anon_sym_u2205,
    STATE(69), 1,
      aux_sym_sequence_of_predicate_values_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(145), 1,
      sym_simple_value,
    STATE(147), 1,
      sym_sequence_of_predicate_values,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(179), 1,
      sym_identifier_reference,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(325), 2,
      sym_double,
      sym_rational,
    ACTIONS(331), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(334), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(328), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(197), 3,
      sym_predicate_value,
      sym_value_constructor,
      sym_mapping_value,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [5015] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    ACTIONS(340), 1,
      anon_sym_RBRACK,
    STATE(68), 1,
      aux_sym_sequence_of_predicate_values_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(145), 1,
      sym_simple_value,
    STATE(147), 1,
      sym_sequence_of_predicate_values,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(179), 1,
      sym_identifier_reference,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(197), 3,
      sym_predicate_value,
      sym_value_constructor,
      sym_mapping_value,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [5096] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    ACTIONS(342), 1,
      anon_sym_RBRACK,
    STATE(69), 1,
      aux_sym_sequence_of_predicate_values_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(145), 1,
      sym_simple_value,
    STATE(147), 1,
      sym_sequence_of_predicate_values,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(179), 1,
      sym_identifier_reference,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(197), 3,
      sym_predicate_value,
      sym_value_constructor,
      sym_mapping_value,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [5177] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    ACTIONS(344), 1,
      anon_sym_RBRACK,
    STATE(71), 1,
      aux_sym_sequence_of_predicate_values_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(145), 1,
      sym_simple_value,
    STATE(147), 1,
      sym_sequence_of_predicate_values,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(179), 1,
      sym_identifier_reference,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(197), 3,
      sym_predicate_value,
      sym_value_constructor,
      sym_mapping_value,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [5258] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    ACTIONS(346), 1,
      anon_sym_RBRACK,
    STATE(74), 1,
      aux_sym_sequence_of_predicate_values_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(145), 1,
      sym_simple_value,
    STATE(147), 1,
      sym_sequence_of_predicate_values,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(179), 1,
      sym_identifier_reference,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(197), 3,
      sym_predicate_value,
      sym_value_constructor,
      sym_mapping_value,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [5339] = 23,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(195), 1,
      anon_sym_LBRACK,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(217), 1,
      anon_sym_u2205,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    ACTIONS(348), 1,
      anon_sym_RBRACK,
    STATE(69), 1,
      aux_sym_sequence_of_predicate_values_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(145), 1,
      sym_simple_value,
    STATE(147), 1,
      sym_sequence_of_predicate_values,
    STATE(148), 1,
      sym__value_empty_sequence,
    STATE(179), 1,
      sym_identifier_reference,
    STATE(455), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(197), 3,
      sym_predicate_value,
      sym_value_constructor,
      sym_mapping_value,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [5420] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(78), 1,
      aux_sym_function_composition_repeat1,
    STATE(553), 1,
      sym__function_op_composition,
    ACTIONS(301), 2,
      anon_sym_u00b7,
      anon_sym_DOT,
    ACTIONS(352), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(350), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [5466] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(76), 1,
      aux_sym_function_composition_repeat1,
    STATE(553), 1,
      sym__function_op_composition,
    ACTIONS(358), 2,
      anon_sym_u00b7,
      anon_sym_DOT,
    ACTIONS(356), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(354), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [5512] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(76), 1,
      aux_sym_function_composition_repeat1,
    STATE(553), 1,
      sym__function_op_composition,
    ACTIONS(301), 2,
      anon_sym_u00b7,
      anon_sym_DOT,
    ACTIONS(363), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(361), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [5558] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(76), 1,
      aux_sym_function_composition_repeat1,
    STATE(553), 1,
      sym__function_op_composition,
    ACTIONS(301), 2,
      anon_sym_u00b7,
      anon_sym_DOT,
    ACTIONS(363), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(361), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [5604] = 21,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    ACTIONS(365), 1,
      anon_sym_LBRACK,
    ACTIONS(367), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(51), 1,
      sym_identifier_reference,
    STATE(57), 1,
      sym__value_empty_sequence,
    STATE(59), 1,
      sym_value,
    STATE(143), 1,
      sym_simple_value,
    STATE(457), 1,
      sym__sequence_value_constraints,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(55), 3,
      sym_value_constructor,
      sym_mapping_value,
      sym_sequence_of_values,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [5679] = 21,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    ACTIONS(365), 1,
      anon_sym_LBRACK,
    ACTIONS(367), 1,
      anon_sym_u2205,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(51), 1,
      sym_identifier_reference,
    STATE(57), 1,
      sym__value_empty_sequence,
    STATE(143), 1,
      sym_simple_value,
    STATE(180), 1,
      sym_value,
    STATE(457), 1,
      sym__sequence_value_constraints,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(55), 3,
      sym_value_constructor,
      sym_mapping_value,
      sym_sequence_of_values,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [5754] = 21,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LBRACE,
    ACTIONS(365), 1,
      anon_sym_LBRACK,
    ACTIONS(367), 1,
      anon_sym_u2205,
    STATE(51), 1,
      sym_identifier_reference,
    STATE(57), 1,
      sym__value_empty_sequence,
    STATE(59), 1,
      sym_value,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(154), 1,
      sym_simple_value,
    STATE(451), 1,
      sym__sequence_value_constraints,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(55), 3,
      sym_value_constructor,
      sym_mapping_value,
      sym_sequence_of_values,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [5829] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(371), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(369), 26,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
      anon_sym_u00b7,
      anon_sym_DOT,
  [5867] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(241), 1,
      anon_sym_datatype,
    ACTIONS(243), 1,
      anon_sym_dimension,
    ACTIONS(245), 1,
      anon_sym_entity,
    ACTIONS(247), 1,
      anon_sym_enum,
    ACTIONS(249), 1,
      anon_sym_event,
    ACTIONS(251), 1,
      anon_sym_property,
    ACTIONS(253), 1,
      anon_sym_rdf,
    ACTIONS(255), 1,
      anon_sym_structure,
    ACTIONS(257), 1,
      anon_sym_union,
    ACTIONS(259), 1,
      anon_sym_class,
    ACTIONS(373), 1,
      anon_sym_end,
    STATE(123), 2,
      sym_definition,
      aux_sym_module_body_repeat3,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(303), 10,
      sym_data_type_def,
      sym_dimension_def,
      sym_entity_def,
      sym_enum_def,
      sym_event_def,
      sym_property_def,
      sym_rdf_def,
      sym_structure_def,
      sym_union_def,
      sym_type_class_def,
  [5934] = 18,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(241), 1,
      anon_sym_datatype,
    ACTIONS(243), 1,
      anon_sym_dimension,
    ACTIONS(245), 1,
      anon_sym_entity,
    ACTIONS(247), 1,
      anon_sym_enum,
    ACTIONS(249), 1,
      anon_sym_event,
    ACTIONS(251), 1,
      anon_sym_property,
    ACTIONS(253), 1,
      anon_sym_rdf,
    ACTIONS(255), 1,
      anon_sym_structure,
    ACTIONS(257), 1,
      anon_sym_union,
    ACTIONS(259), 1,
      anon_sym_class,
    ACTIONS(261), 1,
      anon_sym_end,
    STATE(120), 2,
      sym_definition,
      aux_sym_module_body_repeat3,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(303), 10,
      sym_data_type_def,
      sym_dimension_def,
      sym_entity_def,
      sym_enum_def,
      sym_event_def,
      sym_property_def,
      sym_rdf_def,
      sym_structure_def,
      sym_union_def,
      sym_type_class_def,
  [6001] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(377), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(375), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6037] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(381), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(379), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6073] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(385), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(383), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6109] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(389), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(387), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6145] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(352), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(350), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6181] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(393), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(391), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6217] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(397), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(395), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6253] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(401), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(399), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6289] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(405), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(403), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6325] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(409), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(407), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6361] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(413), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(411), 24,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6397] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(419), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(415), 8,
      anon_sym_is,
      anon_sym_LPAREN,
      anon_sym_def,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
    ACTIONS(417), 15,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6434] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(421), 1,
      anon_sym_RBRACK,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(102), 1,
      aux_sym_sequence_of_values_repeat1,
    STATE(191), 1,
      sym_simple_value,
    STATE(217), 1,
      sym_identifier_reference,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(223), 2,
      sym_value_constructor,
      sym_mapping_value,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [6496] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(423), 1,
      anon_sym_RBRACK,
    STATE(97), 1,
      aux_sym_sequence_of_values_repeat1,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(191), 1,
      sym_simple_value,
    STATE(217), 1,
      sym_identifier_reference,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(223), 2,
      sym_value_constructor,
      sym_mapping_value,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [6558] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(27), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(29), 22,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_with,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_parent,
      anon_sym_ref,
      anon_sym_u2205,
  [6592] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(425), 1,
      anon_sym_RBRACK,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(102), 1,
      aux_sym_sequence_of_values_repeat1,
    STATE(191), 1,
      sym_simple_value,
    STATE(217), 1,
      sym_identifier_reference,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(223), 2,
      sym_value_constructor,
      sym_mapping_value,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [6654] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(7), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(9), 22,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_with,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_parent,
      anon_sym_ref,
      anon_sym_u2205,
  [6688] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(427), 1,
      sym_identifier,
    ACTIONS(430), 1,
      anon_sym_RBRACK,
    ACTIONS(432), 1,
      sym_quoted_string,
    ACTIONS(435), 1,
      anon_sym_LT,
    ACTIONS(438), 1,
      anon_sym_POUND_LBRACK,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(102), 1,
      aux_sym_sequence_of_values_repeat1,
    STATE(191), 1,
      sym_simple_value,
    STATE(217), 1,
      sym_identifier_reference,
    ACTIONS(441), 2,
      sym_double,
      sym_rational,
    ACTIONS(447), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(450), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(223), 2,
      sym_value_constructor,
      sym_mapping_value,
    ACTIONS(444), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [6750] = 17,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(203), 1,
      sym_quoted_string,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(207), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(291), 1,
      sym_identifier,
    ACTIONS(453), 1,
      anon_sym_RBRACK,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(100), 1,
      aux_sym_sequence_of_values_repeat1,
    STATE(191), 1,
      sym_simple_value,
    STATE(217), 1,
      sym_identifier_reference,
    ACTIONS(209), 2,
      sym_double,
      sym_rational,
    ACTIONS(213), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(215), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(125), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(223), 2,
      sym_value_constructor,
      sym_mapping_value,
    ACTIONS(211), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(130), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [6812] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(419), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(415), 6,
      anon_sym_LPAREN,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
    ACTIONS(417), 15,
      anon_sym_is,
      anon_sym_end,
      anon_sym_def,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6847] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(419), 4,
      anon_sym_EQ,
      sym_op_less_than,
      sym_op_greater_than,
      anon_sym_LT_EQ,
    ACTIONS(415), 9,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_def,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
      anon_sym_u2264,
      anon_sym_GT_EQ,
      anon_sym_u2265,
    ACTIONS(417), 12,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [6882] = 16,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    ACTIONS(455), 1,
      sym_kw_is_fixed,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(256), 1,
      sym_restriction_value,
    STATE(559), 1,
      sym_identifier_reference,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(254), 2,
      sym_simple_value,
      sym_value_constructor,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [6941] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(457), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(459), 20,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_not,
      anon_sym_u00ac,
      anon_sym_forall,
      anon_sym_u2200,
      anon_sym_exists,
      anon_sym_u2203,
      anon_sym_u2205,
  [6973] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(461), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(463), 20,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_not,
      anon_sym_u00ac,
      anon_sym_forall,
      anon_sym_u2200,
      anon_sym_exists,
      anon_sym_u2203,
      anon_sym_u2205,
  [7005] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(465), 1,
      anon_sym_COLON,
    STATE(119), 1,
      aux_sym_function_composition_repeat1,
    STATE(563), 1,
      sym__function_op_composition,
    ACTIONS(467), 2,
      anon_sym_u00b7,
      anon_sym_DOT,
    ACTIONS(27), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(29), 15,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [7045] = 15,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(15), 1,
      sym_identifier,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(263), 1,
      sym_restriction_value,
    STATE(559), 1,
      sym_identifier_reference,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    STATE(254), 2,
      sym_simple_value,
      sym_value_constructor,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [7101] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(469), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(471), 20,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_not,
      anon_sym_u00ac,
      anon_sym_forall,
      anon_sym_u2200,
      anon_sym_exists,
      anon_sym_u2203,
      anon_sym_u2205,
  [7133] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(473), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(475), 20,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_not,
      anon_sym_u00ac,
      anon_sym_forall,
      anon_sym_u2200,
      anon_sym_exists,
      anon_sym_u2203,
      anon_sym_u2205,
  [7165] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(477), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(479), 20,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_not,
      anon_sym_u00ac,
      anon_sym_forall,
      anon_sym_u2200,
      anon_sym_exists,
      anon_sym_u2203,
      anon_sym_u2205,
  [7197] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(481), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(483), 20,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_not,
      anon_sym_u00ac,
      anon_sym_forall,
      anon_sym_u2200,
      anon_sym_exists,
      anon_sym_u2203,
      anon_sym_u2205,
  [7229] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(11), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(13), 19,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_u2205,
  [7260] = 14,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(241), 1,
      anon_sym_datatype,
    ACTIONS(243), 1,
      anon_sym_dimension,
    ACTIONS(245), 1,
      anon_sym_entity,
    ACTIONS(247), 1,
      anon_sym_enum,
    ACTIONS(249), 1,
      anon_sym_event,
    ACTIONS(251), 1,
      anon_sym_property,
    ACTIONS(253), 1,
      anon_sym_rdf,
    ACTIONS(255), 1,
      anon_sym_structure,
    ACTIONS(257), 1,
      anon_sym_union,
    ACTIONS(259), 1,
      anon_sym_class,
    ACTIONS(261), 1,
      anon_sym_end,
    STATE(124), 2,
      sym_definition,
      aux_sym_module_body_repeat3,
    STATE(303), 10,
      sym_data_type_def,
      sym_dimension_def,
      sym_entity_def,
      sym_enum_def,
      sym_event_def,
      sym_property_def,
      sym_rdf_def,
      sym_structure_def,
      sym_union_def,
      sym_type_class_def,
  [7313] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(485), 1,
      sym_language_tag,
    ACTIONS(31), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(33), 18,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_u2205,
  [7346] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(121), 1,
      aux_sym_function_composition_repeat1,
    STATE(563), 1,
      sym__function_op_composition,
    ACTIONS(467), 2,
      anon_sym_u00b7,
      anon_sym_DOT,
    ACTIONS(352), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(350), 15,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [7383] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(122), 1,
      aux_sym_function_composition_repeat1,
    STATE(563), 1,
      sym__function_op_composition,
    ACTIONS(467), 2,
      anon_sym_u00b7,
      anon_sym_DOT,
    ACTIONS(363), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(361), 15,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [7420] = 14,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(241), 1,
      anon_sym_datatype,
    ACTIONS(243), 1,
      anon_sym_dimension,
    ACTIONS(245), 1,
      anon_sym_entity,
    ACTIONS(247), 1,
      anon_sym_enum,
    ACTIONS(249), 1,
      anon_sym_event,
    ACTIONS(251), 1,
      anon_sym_property,
    ACTIONS(253), 1,
      anon_sym_rdf,
    ACTIONS(255), 1,
      anon_sym_structure,
    ACTIONS(257), 1,
      anon_sym_union,
    ACTIONS(259), 1,
      anon_sym_class,
    ACTIONS(373), 1,
      anon_sym_end,
    STATE(124), 2,
      sym_definition,
      aux_sym_module_body_repeat3,
    STATE(303), 10,
      sym_data_type_def,
      sym_dimension_def,
      sym_entity_def,
      sym_enum_def,
      sym_event_def,
      sym_property_def,
      sym_rdf_def,
      sym_structure_def,
      sym_union_def,
      sym_type_class_def,
  [7473] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(122), 1,
      aux_sym_function_composition_repeat1,
    STATE(563), 1,
      sym__function_op_composition,
    ACTIONS(467), 2,
      anon_sym_u00b7,
      anon_sym_DOT,
    ACTIONS(363), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(361), 15,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [7510] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(122), 1,
      aux_sym_function_composition_repeat1,
    STATE(563), 1,
      sym__function_op_composition,
    ACTIONS(487), 2,
      anon_sym_u00b7,
      anon_sym_DOT,
    ACTIONS(356), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(354), 15,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [7547] = 14,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(241), 1,
      anon_sym_datatype,
    ACTIONS(243), 1,
      anon_sym_dimension,
    ACTIONS(245), 1,
      anon_sym_entity,
    ACTIONS(247), 1,
      anon_sym_enum,
    ACTIONS(249), 1,
      anon_sym_event,
    ACTIONS(251), 1,
      anon_sym_property,
    ACTIONS(253), 1,
      anon_sym_rdf,
    ACTIONS(255), 1,
      anon_sym_structure,
    ACTIONS(257), 1,
      anon_sym_union,
    ACTIONS(259), 1,
      anon_sym_class,
    ACTIONS(490), 1,
      anon_sym_end,
    STATE(124), 2,
      sym_definition,
      aux_sym_module_body_repeat3,
    STATE(303), 10,
      sym_data_type_def,
      sym_dimension_def,
      sym_entity_def,
      sym_enum_def,
      sym_event_def,
      sym_property_def,
      sym_rdf_def,
      sym_structure_def,
      sym_union_def,
      sym_type_class_def,
  [7600] = 14,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(492), 1,
      anon_sym_end,
    ACTIONS(494), 1,
      anon_sym_datatype,
    ACTIONS(497), 1,
      anon_sym_dimension,
    ACTIONS(500), 1,
      anon_sym_entity,
    ACTIONS(503), 1,
      anon_sym_enum,
    ACTIONS(506), 1,
      anon_sym_event,
    ACTIONS(509), 1,
      anon_sym_property,
    ACTIONS(512), 1,
      anon_sym_rdf,
    ACTIONS(515), 1,
      anon_sym_structure,
    ACTIONS(518), 1,
      anon_sym_union,
    ACTIONS(521), 1,
      anon_sym_class,
    STATE(124), 2,
      sym_definition,
      aux_sym_module_body_repeat3,
    STATE(303), 10,
      sym_data_type_def,
      sym_dimension_def,
      sym_entity_def,
      sym_enum_def,
      sym_event_def,
      sym_property_def,
      sym_rdf_def,
      sym_structure_def,
      sym_union_def,
      sym_type_class_def,
  [7653] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(49), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(51), 18,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_u2205,
  [7683] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(524), 1,
      sym_identifier,
    ACTIONS(526), 21,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_LBRACE,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_ref,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [7713] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(57), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(59), 18,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_u2205,
  [7743] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(41), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(43), 18,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_u2205,
  [7773] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(45), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(47), 18,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_u2205,
  [7803] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(37), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(39), 18,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_u2205,
  [7833] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(53), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(55), 18,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_u2205,
  [7863] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(63), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(65), 18,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2192,
      anon_sym_DASH_GT,
      anon_sym_u2205,
  [7893] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(528), 1,
      sym_identifier,
    ACTIONS(532), 1,
      anon_sym_AT,
    ACTIONS(535), 1,
      anon_sym_assert,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    ACTIONS(530), 15,
      anon_sym_end,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
  [7931] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(540), 2,
      anon_sym_and,
      anon_sym_u2227,
    ACTIONS(542), 2,
      anon_sym_or,
      anon_sym_u2228,
    ACTIONS(544), 2,
      anon_sym_xor,
      anon_sym_u22bb,
    ACTIONS(538), 3,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(546), 3,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
    ACTIONS(548), 3,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
    STATE(20), 6,
      sym__logical_connective,
      sym_logical_op_conjunction,
      sym_logical_op_disjunction,
      sym_logical_op_exclusive_disjunction,
      sym_logical_op_implication,
      sym_logical_op_biconditional,
  [7970] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(371), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(369), 17,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u00b7,
      anon_sym_DOT,
      anon_sym_u2205,
  [7999] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(20), 6,
      sym__logical_connective,
      sym_logical_op_conjunction,
      sym_logical_op_disjunction,
      sym_logical_op_exclusive_disjunction,
      sym_logical_op_implication,
      sym_logical_op_biconditional,
    ACTIONS(550), 15,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [8028] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(540), 2,
      anon_sym_and,
      anon_sym_u2227,
    ACTIONS(542), 2,
      anon_sym_or,
      anon_sym_u2228,
    ACTIONS(544), 2,
      anon_sym_xor,
      anon_sym_u22bb,
    ACTIONS(546), 3,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
    ACTIONS(548), 3,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
    ACTIONS(552), 3,
      anon_sym_is,
      anon_sym_end,
      anon_sym_def,
    STATE(30), 6,
      sym__logical_connective,
      sym_logical_op_conjunction,
      sym_logical_op_disjunction,
      sym_logical_op_exclusive_disjunction,
      sym_logical_op_implication,
      sym_logical_op_biconditional,
  [8067] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(30), 6,
      sym__logical_connective,
      sym_logical_op_conjunction,
      sym_logical_op_disjunction,
      sym_logical_op_exclusive_disjunction,
      sym_logical_op_implication,
      sym_logical_op_biconditional,
    ACTIONS(554), 15,
      anon_sym_is,
      anon_sym_end,
      anon_sym_def,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [8096] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(20), 6,
      sym__logical_connective,
      sym_logical_op_conjunction,
      sym_logical_op_disjunction,
      sym_logical_op_exclusive_disjunction,
      sym_logical_op_implication,
      sym_logical_op_biconditional,
    ACTIONS(554), 15,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [8125] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(30), 6,
      sym__logical_connective,
      sym_logical_op_conjunction,
      sym_logical_op_disjunction,
      sym_logical_op_exclusive_disjunction,
      sym_logical_op_implication,
      sym_logical_op_biconditional,
    ACTIONS(550), 15,
      anon_sym_is,
      anon_sym_end,
      anon_sym_def,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [8154] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(540), 2,
      anon_sym_and,
      anon_sym_u2227,
    ACTIONS(542), 2,
      anon_sym_or,
      anon_sym_u2228,
    ACTIONS(544), 2,
      anon_sym_xor,
      anon_sym_u22bb,
    ACTIONS(538), 3,
      anon_sym_is,
      anon_sym_end,
      anon_sym_def,
    ACTIONS(546), 3,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
    ACTIONS(548), 3,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
    STATE(30), 6,
      sym__logical_connective,
      sym_logical_op_conjunction,
      sym_logical_op_disjunction,
      sym_logical_op_exclusive_disjunction,
      sym_logical_op_implication,
      sym_logical_op_biconditional,
  [8193] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(556), 1,
      sym_identifier,
    ACTIONS(558), 20,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_ref,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [8222] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(225), 1,
      sym_identifier,
    STATE(79), 1,
      sym__type_op_has_type,
    ACTIONS(560), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
    ACTIONS(227), 17,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
  [8255] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(566), 1,
      anon_sym_LPAREN,
    STATE(167), 1,
      sym__actual_arguments,
    ACTIONS(562), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(564), 14,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8287] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(81), 1,
      sym__type_op_has_type,
    ACTIONS(568), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
    ACTIONS(389), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(387), 13,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8319] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(299), 1,
      anon_sym_COLON,
    ACTIONS(572), 1,
      anon_sym_as,
    STATE(193), 1,
      sym__rename_import,
    STATE(194), 1,
      sym_iri,
    ACTIONS(570), 15,
      anon_sym_end,
      anon_sym_import,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [8355] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(389), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(387), 16,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8383] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(413), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(411), 16,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8411] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(405), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(403), 16,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8439] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(409), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(407), 16,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8467] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(385), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(383), 16,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8495] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(381), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(379), 16,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8523] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(397), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(395), 16,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8551] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(81), 1,
      sym__type_op_has_type,
    ACTIONS(568), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
    ACTIONS(225), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(227), 13,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8583] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(578), 1,
      sym_controlled_language_tag,
    ACTIONS(574), 2,
      sym_identifier,
      anon_sym_AT,
    ACTIONS(576), 16,
      anon_sym_end,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
  [8612] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(580), 1,
      anon_sym_RBRACE,
    ACTIONS(588), 1,
      anon_sym_explicitTimezone,
    ACTIONS(590), 1,
      anon_sym_pattern,
    ACTIONS(584), 2,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
    ACTIONS(582), 3,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
    ACTIONS(586), 4,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
    STATE(161), 7,
      sym__restriction_facet,
      sym_length_restriction_facet,
      sym_digit_restriction_facet,
      sym_value_restriction_facet,
      sym_tz_restriction_facet,
      sym_pattern_restriction_facet,
      aux_sym_datatype_def_restriction_repeat1,
  [8649] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(465), 1,
      anon_sym_COLON,
    ACTIONS(27), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(29), 14,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8678] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(592), 1,
      anon_sym_RPAREN,
    ACTIONS(540), 2,
      anon_sym_and,
      anon_sym_u2227,
    ACTIONS(542), 2,
      anon_sym_or,
      anon_sym_u2228,
    ACTIONS(544), 2,
      anon_sym_xor,
      anon_sym_u22bb,
    ACTIONS(546), 3,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
    ACTIONS(548), 3,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
    STATE(20), 6,
      sym__logical_connective,
      sym_logical_op_conjunction,
      sym_logical_op_disjunction,
      sym_logical_op_exclusive_disjunction,
      sym_logical_op_implication,
      sym_logical_op_biconditional,
  [8715] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(352), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(350), 15,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8742] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(415), 19,
      anon_sym_is,
      anon_sym_end,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [8767] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(594), 1,
      anon_sym_RBRACE,
    ACTIONS(605), 1,
      anon_sym_explicitTimezone,
    ACTIONS(608), 1,
      anon_sym_pattern,
    ACTIONS(599), 2,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
    ACTIONS(596), 3,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
    ACTIONS(602), 4,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
    STATE(161), 7,
      sym__restriction_facet,
      sym_length_restriction_facet,
      sym_digit_restriction_facet,
      sym_value_restriction_facet,
      sym_tz_restriction_facet,
      sym_pattern_restriction_facet,
      aux_sym_datatype_def_restriction_repeat1,
  [8804] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(611), 1,
      anon_sym_end,
    ACTIONS(540), 2,
      anon_sym_and,
      anon_sym_u2227,
    ACTIONS(542), 2,
      anon_sym_or,
      anon_sym_u2228,
    ACTIONS(544), 2,
      anon_sym_xor,
      anon_sym_u22bb,
    ACTIONS(546), 3,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
    ACTIONS(548), 3,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
    STATE(20), 6,
      sym__logical_connective,
      sym_logical_op_conjunction,
      sym_logical_op_disjunction,
      sym_logical_op_exclusive_disjunction,
      sym_logical_op_implication,
      sym_logical_op_biconditional,
  [8841] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(615), 1,
      anon_sym_LPAREN,
    STATE(160), 1,
      sym__actual_arguments,
    ACTIONS(613), 17,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [8870] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(617), 1,
      anon_sym_end,
    ACTIONS(540), 2,
      anon_sym_and,
      anon_sym_u2227,
    ACTIONS(542), 2,
      anon_sym_or,
      anon_sym_u2228,
    ACTIONS(544), 2,
      anon_sym_xor,
      anon_sym_u22bb,
    ACTIONS(546), 3,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
    ACTIONS(548), 3,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
    STATE(20), 6,
      sym__logical_connective,
      sym_logical_op_conjunction,
      sym_logical_op_disjunction,
      sym_logical_op_exclusive_disjunction,
      sym_logical_op_implication,
      sym_logical_op_biconditional,
  [8907] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(377), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(375), 15,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8934] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(615), 1,
      anon_sym_LPAREN,
    STATE(160), 1,
      sym__actual_arguments,
    ACTIONS(619), 17,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [8963] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(419), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(415), 15,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [8990] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(393), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(391), 15,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [9017] = 11,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(77), 1,
      sym_quoted_string,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(81), 1,
      anon_sym_POUND_LBRACK,
    STATE(572), 1,
      sym_simple_value,
    ACTIONS(83), 2,
      sym_double,
      sym_rational,
    ACTIONS(87), 2,
      anon_sym_true,
      anon_sym_u22a4,
    ACTIONS(89), 2,
      anon_sym_false,
      anon_sym_u22a5,
    STATE(10), 2,
      sym_boolean_truth,
      sym_boolean_falsity,
    ACTIONS(85), 3,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    STATE(7), 4,
      sym_string,
      sym_iri,
      sym_binary,
      sym_boolean,
  [9060] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(401), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(399), 15,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [9087] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(621), 1,
      sym_identifier,
    ACTIONS(623), 17,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
  [9113] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(625), 1,
      sym_identifier,
    ACTIONS(627), 17,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_ref,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [9139] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(629), 1,
      sym_identifier,
    ACTIONS(631), 17,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
  [9165] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(588), 1,
      anon_sym_explicitTimezone,
    ACTIONS(590), 1,
      anon_sym_pattern,
    ACTIONS(584), 2,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
    ACTIONS(582), 3,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
    ACTIONS(586), 4,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
    STATE(156), 7,
      sym__restriction_facet,
      sym_length_restriction_facet,
      sym_digit_restriction_facet,
      sym_value_restriction_facet,
      sym_tz_restriction_facet,
      sym_pattern_restriction_facet,
      aux_sym_datatype_def_restriction_repeat1,
  [9199] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(635), 1,
      anon_sym_import,
    ACTIONS(638), 1,
      anon_sym_from,
    STATE(570), 1,
      sym_from_clause,
    STATE(175), 2,
      sym_import_statement,
      aux_sym_module_body_repeat1,
    ACTIONS(633), 13,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [9231] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(641), 1,
      sym_identifier,
    ACTIONS(643), 17,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
  [9257] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(645), 1,
      sym_identifier,
    ACTIONS(647), 17,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
  [9283] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(649), 1,
      sym_identifier,
    ACTIONS(651), 17,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
  [9309] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(229), 1,
      anon_sym_LPAREN,
    ACTIONS(653), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(655), 13,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [9337] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(657), 1,
      sym_identifier,
    ACTIONS(659), 17,
      anon_sym_end,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_source,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_identity,
      anon_sym_ref,
  [9363] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(661), 17,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [9386] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(663), 17,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [9409] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(665), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(667), 13,
      anon_sym_LBRACK,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [9434] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(669), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(671), 13,
      anon_sym_LBRACK,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [9459] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(673), 17,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [9482] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(661), 17,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [9505] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(675), 1,
      sym_identifier,
    ACTIONS(677), 16,
      anon_sym_end,
      anon_sym_import,
      anon_sym_RBRACK,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [9530] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(679), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(681), 13,
      anon_sym_LBRACK,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [9555] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(683), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(685), 13,
      anon_sym_LBRACK,
      sym_reserved_self,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [9580] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(572), 1,
      anon_sym_as,
    STATE(195), 1,
      sym__rename_import,
    ACTIONS(687), 15,
      anon_sym_end,
      anon_sym_import,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [9607] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(81), 1,
      sym__type_op_has_type,
    ACTIONS(568), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
    ACTIONS(689), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(691), 10,
      anon_sym_RBRACK,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
  [9636] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(693), 1,
      sym_identifier,
    ACTIONS(695), 16,
      anon_sym_end,
      anon_sym_import,
      anon_sym_RBRACK,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [9661] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(697), 1,
      sym_identifier,
    ACTIONS(699), 16,
      anon_sym_end,
      anon_sym_import,
      anon_sym_RBRACK,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [9686] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(572), 1,
      anon_sym_as,
    STATE(192), 1,
      sym__rename_import,
    ACTIONS(701), 15,
      anon_sym_end,
      anon_sym_import,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [9713] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(703), 1,
      sym_identifier,
    ACTIONS(705), 16,
      anon_sym_end,
      anon_sym_import,
      anon_sym_RBRACK,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [9738] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(707), 17,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [9761] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(653), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(655), 13,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
      anon_sym_u2205,
  [9786] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(661), 17,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_u2227,
      anon_sym_or,
      anon_sym_u2228,
      anon_sym_xor,
      anon_sym_u22bb,
      anon_sym_implies,
      anon_sym_EQ_EQ_GT,
      anon_sym_u21d2,
      anon_sym_iff,
      anon_sym_LT_EQ_EQ_GT,
      anon_sym_u21d4,
  [9809] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(615), 1,
      anon_sym_LPAREN,
    ACTIONS(709), 1,
      anon_sym_EQ,
    STATE(105), 1,
      sym__actual_arguments,
    ACTIONS(711), 2,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
    ACTIONS(713), 2,
      sym_op_less_than,
      sym_op_greater_than,
    ACTIONS(715), 2,
      anon_sym_LT_EQ,
      anon_sym_u2264,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_u2265,
    ACTIONS(552), 3,
      anon_sym_is,
      anon_sym_end,
      anon_sym_def,
    STATE(56), 3,
      sym_op_inequality,
      sym_op_less_than_or_equal,
      sym_op_greater_than_or_equal,
  [9848] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(615), 1,
      anon_sym_LPAREN,
    ACTIONS(709), 1,
      anon_sym_EQ,
    STATE(96), 1,
      sym__actual_arguments,
    ACTIONS(552), 2,
      anon_sym_is,
      anon_sym_def,
    ACTIONS(711), 2,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
    ACTIONS(713), 2,
      sym_op_less_than,
      sym_op_greater_than,
    ACTIONS(715), 2,
      anon_sym_LT_EQ,
      anon_sym_u2264,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_u2265,
    STATE(56), 3,
      sym_op_inequality,
      sym_op_less_than_or_equal,
      sym_op_greater_than_or_equal,
  [9886] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(719), 1,
      sym_identifier,
    ACTIONS(721), 15,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_of,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_ref,
  [9910] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(723), 1,
      sym_identifier,
    ACTIONS(725), 15,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_of,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_ref,
  [9934] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    STATE(227), 1,
      sym_rdf_types,
    STATE(308), 1,
      sym_annotation_only_body,
    ACTIONS(731), 2,
      anon_sym_a,
      anon_sym_type,
    ACTIONS(729), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [9964] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    ACTIONS(733), 1,
      sym_identifier,
    STATE(225), 1,
      sym_annotation_only_body,
    ACTIONS(735), 13,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_ref,
  [9992] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(737), 1,
      anon_sym_is,
    ACTIONS(741), 1,
      anon_sym_from,
    ACTIONS(743), 1,
      anon_sym_LPAREN,
    STATE(233), 1,
      sym_from_definition_clause,
    STATE(277), 1,
      sym_type_class_body,
    ACTIONS(739), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10024] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(745), 15,
      anon_sym_end,
      anon_sym_import,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10045] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(747), 1,
      sym_identifier,
    ACTIONS(749), 14,
      anon_sym_end,
      anon_sym_def,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_ref,
  [10068] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(751), 15,
      anon_sym_end,
      anon_sym_import,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10089] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(753), 1,
      sym_identifier,
    ACTIONS(755), 14,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_ref,
  [10112] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(741), 1,
      anon_sym_from,
    ACTIONS(757), 1,
      anon_sym_is,
    STATE(232), 1,
      sym_from_definition_clause,
    STATE(272), 1,
      sym_entity_body,
    ACTIONS(759), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10141] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(737), 1,
      anon_sym_is,
    ACTIONS(741), 1,
      anon_sym_from,
    STATE(229), 1,
      sym_from_definition_clause,
    STATE(310), 1,
      sym_type_class_body,
    ACTIONS(761), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10170] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(741), 1,
      anon_sym_from,
    ACTIONS(763), 1,
      anon_sym_is,
    STATE(230), 1,
      sym_from_definition_clause,
    STATE(311), 1,
      sym_dimension_body,
    ACTIONS(765), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10199] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(741), 1,
      anon_sym_from,
    ACTIONS(767), 1,
      anon_sym_is,
    STATE(245), 1,
      sym_from_definition_clause,
    STATE(315), 1,
      sym_structure_body,
    ACTIONS(769), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10228] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(741), 1,
      anon_sym_from,
    ACTIONS(771), 1,
      anon_sym_is,
    STATE(240), 1,
      sym_from_definition_clause,
    STATE(305), 1,
      sym_event_body,
    ACTIONS(773), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10257] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(741), 1,
      anon_sym_from,
    ACTIONS(777), 1,
      anon_sym_of,
    STATE(237), 1,
      sym_from_definition_clause,
    STATE(296), 1,
      sym_union_body,
    ACTIONS(775), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10286] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    ACTIONS(781), 1,
      anon_sym_LBRACE,
    STATE(239), 1,
      sym_datatype_def_restriction,
    STATE(301), 1,
      sym_annotation_only_body,
    ACTIONS(779), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10315] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(229), 1,
      anon_sym_LPAREN,
    ACTIONS(689), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(691), 10,
      anon_sym_RBRACK,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
  [10340] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(741), 1,
      anon_sym_from,
    ACTIONS(785), 1,
      anon_sym_of,
    STATE(235), 1,
      sym_from_definition_clause,
    STATE(292), 1,
      sym_enum_body,
    ACTIONS(783), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10369] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(787), 15,
      anon_sym_end,
      anon_sym_import,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10390] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(789), 15,
      anon_sym_end,
      anon_sym_import,
      anon_sym_from,
      anon_sym_AT,
      anon_sym_assert,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10411] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(791), 1,
      sym_identifier,
    ACTIONS(793), 14,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_ref,
  [10434] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    ACTIONS(781), 1,
      anon_sym_LBRACE,
    STATE(238), 1,
      sym_datatype_def_restriction,
    STATE(298), 1,
      sym_annotation_only_body,
    ACTIONS(795), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10463] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(689), 4,
      sym_identifier,
      sym_decimal,
      sym_integer,
      sym_unsigned,
    ACTIONS(691), 10,
      anon_sym_RBRACK,
      sym_quoted_string,
      anon_sym_LT,
      anon_sym_POUND_LBRACK,
      sym_double,
      sym_rational,
      anon_sym_true,
      anon_sym_u22a4,
      anon_sym_false,
      anon_sym_u22a5,
  [10485] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(615), 1,
      anon_sym_LPAREN,
    ACTIONS(709), 1,
      anon_sym_EQ,
    STATE(96), 1,
      sym__actual_arguments,
    ACTIONS(711), 2,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
    ACTIONS(713), 2,
      sym_op_less_than,
      sym_op_greater_than,
    ACTIONS(715), 2,
      anon_sym_LT_EQ,
      anon_sym_u2264,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_u2265,
    STATE(56), 3,
      sym_op_inequality,
      sym_op_less_than_or_equal,
      sym_op_greater_than_or_equal,
  [10519] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(797), 1,
      sym_identifier,
    ACTIONS(799), 13,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_parent,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
      anon_sym_ref,
  [10541] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(615), 1,
      anon_sym_LPAREN,
    ACTIONS(709), 1,
      anon_sym_EQ,
    STATE(104), 1,
      sym__actual_arguments,
    ACTIONS(711), 2,
      anon_sym_SLASH_EQ,
      anon_sym_u2260,
    ACTIONS(713), 2,
      sym_op_less_than,
      sym_op_greater_than,
    ACTIONS(715), 2,
      anon_sym_LT_EQ,
      anon_sym_u2264,
    ACTIONS(717), 2,
      anon_sym_GT_EQ,
      anon_sym_u2265,
    STATE(56), 3,
      sym_op_inequality,
      sym_op_less_than_or_equal,
      sym_op_greater_than_or_equal,
  [10575] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    STATE(280), 1,
      sym_annotation_only_body,
    ACTIONS(801), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10598] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(805), 1,
      anon_sym_end,
    ACTIONS(807), 1,
      anon_sym_ref,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(236), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(359), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [10633] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(737), 1,
      anon_sym_is,
    STATE(302), 1,
      sym_type_class_body,
    ACTIONS(809), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10656] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(763), 1,
      anon_sym_is,
    STATE(299), 1,
      sym_dimension_body,
    ACTIONS(811), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10679] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(813), 13,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_of,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10698] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(757), 1,
      anon_sym_is,
    STATE(309), 1,
      sym_entity_body,
    ACTIONS(815), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10721] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(737), 1,
      anon_sym_is,
    STATE(291), 1,
      sym_type_class_body,
    ACTIONS(817), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10744] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(819), 13,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_of,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10763] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(785), 1,
      anon_sym_of,
    STATE(269), 1,
      sym_enum_body,
    ACTIONS(821), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10786] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(823), 1,
      anon_sym_end,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(357), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [10821] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(777), 1,
      anon_sym_of,
    STATE(286), 1,
      sym_union_body,
    ACTIONS(825), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10844] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    STATE(304), 1,
      sym_annotation_only_body,
    ACTIONS(827), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10867] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    STATE(273), 1,
      sym_annotation_only_body,
    ACTIONS(829), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10890] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(771), 1,
      anon_sym_is,
    STATE(270), 1,
      sym_event_body,
    ACTIONS(831), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10913] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(833), 13,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_of,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10932] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(835), 13,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_of,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10951] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(837), 13,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_of,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10970] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(839), 13,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_of,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [10989] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(767), 1,
      anon_sym_is,
    STATE(283), 1,
      sym_structure_body,
    ACTIONS(841), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11012] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(843), 12,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11030] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(845), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11048] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(847), 1,
      sym_identifier,
    ACTIONS(849), 1,
      anon_sym_end,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(380), 1,
      sym_identifier_reference,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(253), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(362), 2,
      sym_type_variant,
      aux_sym_union_body_repeat1,
  [11082] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(851), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11100] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(853), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11118] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(855), 12,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11136] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(857), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11154] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(847), 1,
      sym_identifier,
    ACTIONS(859), 1,
      anon_sym_end,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(380), 1,
      sym_identifier_reference,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(361), 2,
      sym_type_variant,
      aux_sym_union_body_repeat1,
  [11188] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(861), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11206] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(863), 12,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11224] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(865), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11242] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(867), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11260] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(869), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11278] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(871), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11296] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(873), 12,
      anon_sym_is,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11314] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(875), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11332] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(877), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11350] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(879), 12,
      anon_sym_RBRACE,
      anon_sym_length,
      anon_sym_maxLength,
      anon_sym_minLength,
      anon_sym_fractionDigits,
      anon_sym_totalDigits,
      anon_sym_maxExclusive,
      anon_sym_maxInclusive,
      anon_sym_minExclusive,
      anon_sym_minInclusive,
      anon_sym_explicitTimezone,
      anon_sym_pattern,
  [11368] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(881), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11385] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(883), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11402] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(885), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11419] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(887), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11436] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(889), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11453] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(891), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11470] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(893), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11487] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(895), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11504] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(897), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11521] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(899), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11538] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(901), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11555] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(903), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11572] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(905), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11589] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(907), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11606] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(909), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11623] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(911), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11640] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(913), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11657] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(915), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11674] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(917), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11691] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(919), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11708] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(921), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11725] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(923), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11742] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(925), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11759] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(927), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11776] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(929), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11793] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(931), 1,
      anon_sym_end,
    ACTIONS(933), 1,
      anon_sym_def,
    STATE(334), 1,
      sym_function_signature,
    STATE(393), 1,
      aux_sym_type_class_body_repeat1,
    STATE(492), 1,
      sym_method_def,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
  [11826] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(935), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11843] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(937), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11860] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(939), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11877] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(941), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11894] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(943), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11911] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(945), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11928] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(947), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11945] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(933), 1,
      anon_sym_def,
    ACTIONS(949), 1,
      anon_sym_end,
    STATE(334), 1,
      sym_function_signature,
    STATE(381), 1,
      aux_sym_type_class_body_repeat1,
    STATE(492), 1,
      sym_method_def,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(289), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
  [11978] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(951), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [11995] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(953), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12012] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(955), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12029] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(957), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12046] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(959), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12063] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(961), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12080] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(963), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12097] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(965), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12114] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(967), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12131] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(969), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12148] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(971), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12165] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(973), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12182] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(975), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12199] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(977), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12216] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(979), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12233] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(981), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12250] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(983), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12267] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(985), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12284] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(987), 11,
      anon_sym_end,
      anon_sym_datatype,
      anon_sym_dimension,
      anon_sym_entity,
      anon_sym_enum,
      anon_sym_event,
      anon_sym_property,
      anon_sym_rdf,
      anon_sym_structure,
      anon_sym_union,
      anon_sym_class,
  [12301] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(989), 1,
      anon_sym_end,
    ACTIONS(991), 1,
      anon_sym_parent,
    STATE(322), 2,
      sym_dimension_parent,
      aux_sym_dimension_body_repeat1,
    STATE(350), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [12329] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(993), 1,
      sym_identifier,
    ACTIONS(995), 1,
      anon_sym_end,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(427), 2,
      sym_value_variant,
      aux_sym_enum_body_repeat1,
  [12357] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(991), 1,
      anon_sym_parent,
    ACTIONS(997), 1,
      anon_sym_end,
    STATE(348), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(363), 2,
      sym_dimension_parent,
      aux_sym_dimension_body_repeat1,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [12385] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(991), 1,
      anon_sym_parent,
    ACTIONS(999), 1,
      anon_sym_end,
    STATE(319), 2,
      sym_dimension_parent,
      aux_sym_dimension_body_repeat1,
    STATE(342), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [12413] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(1001), 1,
      anon_sym_source,
    ACTIONS(1003), 1,
      anon_sym_identity,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(320), 2,
      sym_source_entity,
      sym_entity_identity,
  [12441] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(991), 1,
      anon_sym_parent,
    ACTIONS(1005), 1,
      anon_sym_end,
    STATE(341), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(363), 2,
      sym_dimension_parent,
      aux_sym_dimension_body_repeat1,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [12469] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(993), 1,
      sym_identifier,
    ACTIONS(1007), 1,
      anon_sym_end,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(318), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(431), 2,
      sym_value_variant,
      aux_sym_enum_body_repeat1,
  [12497] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(1001), 1,
      anon_sym_source,
    ACTIONS(1003), 1,
      anon_sym_identity,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(317), 2,
      sym_source_entity,
      sym_entity_identity,
    STATE(321), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
  [12525] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1009), 1,
      anon_sym_RBRACE,
    ACTIONS(1011), 1,
      sym_unsigned,
    STATE(368), 1,
      sym_sequence_ordering,
    STATE(477), 1,
      sym_sequence_uniqueness,
    STATE(529), 1,
      sym__cardinality_inner,
    ACTIONS(1013), 2,
      anon_sym_ordered,
      anon_sym_unordered,
    ACTIONS(1015), 2,
      anon_sym_unique,
      anon_sym_nonunique,
  [12552] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1017), 1,
      sym_identifier,
    STATE(413), 1,
      aux_sym_sequence_builder_repeat1,
    STATE(434), 1,
      sym_sequence_ordering,
    STATE(482), 1,
      sym_variable,
    STATE(527), 1,
      sym_sequence_uniqueness,
    ACTIONS(1013), 2,
      anon_sym_ordered,
      anon_sym_unordered,
    ACTIONS(1015), 2,
      anon_sym_unique,
      anon_sym_nonunique,
  [12579] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(562), 1,
      sym_quantified_variable_binding,
    STATE(574), 1,
      sym_sequence_builder_body,
    STATE(581), 1,
      sym_quantified_sentence,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
  [12604] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(551), 1,
      sym_sequence_builder_body,
    STATE(562), 1,
      sym_quantified_variable_binding,
    STATE(581), 1,
      sym_quantified_sentence,
    ACTIONS(93), 2,
      anon_sym_forall,
      anon_sym_u2200,
    ACTIONS(95), 2,
      anon_sym_exists,
      anon_sym_u2203,
    STATE(474), 2,
      sym_logical_quantifier_universal,
      sym_logical_quantifier_existential,
  [12629] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1017), 1,
      sym_identifier,
    STATE(401), 1,
      aux_sym_sequence_builder_repeat1,
    STATE(434), 1,
      sym_sequence_ordering,
    STATE(482), 1,
      sym_variable,
    STATE(527), 1,
      sym_sequence_uniqueness,
    ACTIONS(1013), 2,
      anon_sym_ordered,
      anon_sym_unordered,
    ACTIONS(1015), 2,
      anon_sym_unique,
      anon_sym_nonunique,
  [12656] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(1003), 1,
      anon_sym_identity,
    STATE(351), 1,
      sym_entity_identity,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(332), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
  [12680] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(1001), 1,
      anon_sym_source,
    STATE(355), 1,
      sym_source_entity,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
  [12704] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(1003), 1,
      anon_sym_identity,
    STATE(337), 1,
      sym_entity_identity,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
  [12728] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(1001), 1,
      anon_sym_source,
    STATE(356), 1,
      sym_source_entity,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(331), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
  [12752] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    STATE(28), 1,
      sym__function_op_by_definition,
    STATE(435), 1,
      sym_function_body,
    STATE(509), 1,
      sym_annotation_only_body,
    ACTIONS(1019), 2,
      anon_sym_end,
      anon_sym_def,
    ACTIONS(1021), 2,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
  [12776] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(27), 1,
      sym_identifier,
    ACTIONS(465), 1,
      anon_sym_COLON,
    ACTIONS(29), 6,
      anon_sym_is,
      anon_sym_end,
      anon_sym_as,
      anon_sym_with,
      anon_sym_parent,
      anon_sym_ref,
  [12794] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1011), 1,
      sym_unsigned,
    STATE(385), 1,
      sym_sequence_ordering,
    STATE(502), 1,
      sym_sequence_uniqueness,
    STATE(532), 1,
      sym__cardinality_inner,
    ACTIONS(1013), 2,
      anon_sym_ordered,
      anon_sym_unordered,
    ACTIONS(1015), 2,
      anon_sym_unique,
      anon_sym_nonunique,
  [12818] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1023), 1,
      anon_sym_end,
    STATE(343), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [12839] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1025), 1,
      sym_identifier,
    ACTIONS(1028), 1,
      anon_sym_RBRACK,
    STATE(424), 1,
      sym_qualified_identifier,
    STATE(338), 4,
      sym__import,
      sym_member_import,
      sym_module_import,
      aux_sym_import_statement_repeat1,
  [12858] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1030), 1,
      sym_identifier,
    ACTIONS(1032), 1,
      anon_sym_RBRACK,
    STATE(424), 1,
      sym_qualified_identifier,
    STATE(338), 4,
      sym__import,
      sym_member_import,
      sym_module_import,
      aux_sym_import_statement_repeat1,
  [12877] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1030), 1,
      sym_identifier,
    ACTIONS(1034), 1,
      anon_sym_RBRACK,
    STATE(424), 1,
      sym_qualified_identifier,
    STATE(338), 4,
      sym__import,
      sym_member_import,
      sym_module_import,
      aux_sym_import_statement_repeat1,
  [12896] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1036), 1,
      anon_sym_end,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [12917] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(997), 1,
      anon_sym_end,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [12938] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1038), 1,
      anon_sym_end,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [12959] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1040), 1,
      anon_sym_end,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [12980] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1042), 1,
      sym_identifier,
    STATE(468), 1,
      sym__type_op_has_type,
    ACTIONS(1046), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
    ACTIONS(1044), 3,
      anon_sym_in,
      anon_sym_u2208,
      sym_set_op_builder,
  [12999] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1048), 1,
      sym_identifier,
    ACTIONS(1050), 6,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
  [13014] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1052), 1,
      sym_identifier,
    ACTIONS(1054), 6,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
  [13029] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1056), 1,
      anon_sym_end,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13050] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1058), 1,
      sym_identifier,
    ACTIONS(1060), 6,
      anon_sym_is,
      anon_sym_end,
      anon_sym_RPAREN,
      anon_sym_def,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
  [13065] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1005), 1,
      anon_sym_end,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13086] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1062), 1,
      anon_sym_end,
    STATE(353), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13107] = 8,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(205), 1,
      anon_sym_LT,
    ACTIONS(465), 1,
      anon_sym_COLON,
    ACTIONS(570), 1,
      anon_sym_RBRACK,
    ACTIONS(1064), 1,
      sym_identifier,
    ACTIONS(1066), 1,
      anon_sym_as,
    STATE(193), 1,
      sym__rename_import,
    STATE(426), 1,
      sym_iri,
  [13132] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1068), 1,
      anon_sym_end,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13153] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1070), 1,
      anon_sym_end,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13174] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1072), 1,
      anon_sym_end,
    STATE(344), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13195] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1074), 1,
      anon_sym_end,
    STATE(354), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13216] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(1076), 1,
      anon_sym_end,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13237] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1078), 1,
      sym_identifier,
    ACTIONS(1081), 1,
      anon_sym_end,
    ACTIONS(1083), 1,
      anon_sym_ref,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13258] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    ACTIONS(823), 1,
      anon_sym_end,
    STATE(358), 2,
      sym_member,
      aux_sym_dimension_body_repeat2,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13279] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    ACTIONS(1086), 1,
      anon_sym_end,
    STATE(133), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
  [13300] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(847), 1,
      sym_identifier,
    ACTIONS(1088), 1,
      anon_sym_end,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(380), 1,
      sym_identifier_reference,
    STATE(374), 2,
      sym_type_variant,
      aux_sym_union_body_repeat1,
  [13320] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(847), 1,
      sym_identifier,
    ACTIONS(859), 1,
      anon_sym_end,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(380), 1,
      sym_identifier_reference,
    STATE(374), 2,
      sym_type_variant,
      aux_sym_union_body_repeat1,
  [13340] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1090), 1,
      sym_identifier,
    ACTIONS(1094), 1,
      anon_sym_parent,
    ACTIONS(1092), 2,
      anon_sym_end,
      anon_sym_ref,
    STATE(363), 2,
      sym_dimension_parent,
      aux_sym_dimension_body_repeat1,
  [13358] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1030), 1,
      sym_identifier,
    STATE(424), 1,
      sym_qualified_identifier,
    STATE(339), 4,
      sym__import,
      sym_member_import,
      sym_module_import,
      aux_sym_import_statement_repeat1,
  [13374] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1099), 1,
      anon_sym_LBRACK,
    STATE(190), 1,
      sym_qualified_identifier,
    STATE(220), 3,
      sym__import,
      sym_member_import,
      sym_module_import,
  [13392] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(370), 1,
      sym_type_op_combiner,
    STATE(371), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(1101), 2,
      sym_identifier,
      anon_sym_RPAREN,
    ACTIONS(1103), 2,
      anon_sym_PLUS,
      anon_sym_u2295,
  [13410] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1105), 1,
      anon_sym_is,
    ACTIONS(1107), 1,
      anon_sym_EQ,
    ACTIONS(1109), 1,
      anon_sym_with,
    STATE(541), 1,
      sym_constraint_environment,
    STATE(176), 2,
      sym_informal_constraint,
      sym_formal_constraint,
  [13430] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1011), 1,
      sym_unsigned,
    ACTIONS(1111), 1,
      anon_sym_RBRACE,
    STATE(458), 1,
      sym_sequence_uniqueness,
    STATE(526), 1,
      sym__cardinality_inner,
    ACTIONS(1015), 2,
      anon_sym_unique,
      anon_sym_nonunique,
  [13450] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1113), 1,
      anon_sym_LBRACK,
    STATE(190), 1,
      sym_qualified_identifier,
    STATE(206), 3,
      sym__import,
      sym_member_import,
      sym_module_import,
  [13468] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(1115), 1,
      sym_identifier,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(391), 1,
      sym_identifier_reference,
    STATE(411), 1,
      sym_type_parameter_restriction,
    STATE(478), 1,
      sym_cardinality_reference_expression,
  [13490] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(370), 1,
      sym_type_op_combiner,
    STATE(378), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(1103), 2,
      anon_sym_PLUS,
      anon_sym_u2295,
    ACTIONS(1117), 2,
      sym_identifier,
      anon_sym_RPAREN,
  [13508] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(434), 1,
      sym_sequence_ordering,
    STATE(527), 1,
      sym_sequence_uniqueness,
    ACTIONS(1013), 2,
      anon_sym_ordered,
      anon_sym_unordered,
    ACTIONS(1015), 2,
      anon_sym_unique,
      anon_sym_nonunique,
  [13526] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    ACTIONS(1119), 1,
      sym_identifier,
    STATE(417), 1,
      sym_annotation_only_body,
    ACTIONS(1121), 3,
      anon_sym_end,
      anon_sym_parent,
      anon_sym_ref,
  [13544] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1123), 1,
      sym_identifier,
    ACTIONS(1126), 1,
      anon_sym_end,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(380), 1,
      sym_identifier_reference,
    STATE(374), 2,
      sym_type_variant,
      aux_sym_union_body_repeat1,
  [13564] = 7,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(61), 1,
      anon_sym_LBRACE,
    ACTIONS(1115), 1,
      sym_identifier,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(366), 1,
      sym_type_parameter_restriction,
    STATE(391), 1,
      sym_identifier_reference,
    STATE(478), 1,
      sym_cardinality_reference_expression,
  [13586] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1030), 1,
      sym_identifier,
    STATE(424), 1,
      sym_qualified_identifier,
    STATE(340), 4,
      sym__import,
      sym_member_import,
      sym_module_import,
      aux_sym_import_statement_repeat1,
  [13602] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(237), 1,
      anon_sym_AT,
    ACTIONS(239), 1,
      anon_sym_assert,
    STATE(177), 2,
      sym_annotation_property,
      sym_constraint,
    STATE(360), 2,
      sym_annotation,
      aux_sym_module_body_repeat2,
  [13620] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(370), 1,
      sym_type_op_combiner,
    STATE(378), 1,
      aux_sym_type_parameter_repeat1,
    ACTIONS(1128), 2,
      sym_identifier,
      anon_sym_RPAREN,
    ACTIONS(1130), 2,
      anon_sym_PLUS,
      anon_sym_u2295,
  [13638] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1133), 1,
      anon_sym_RBRACK,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(382), 1,
      aux_sym_rdf_types_repeat1,
    STATE(503), 1,
      sym_identifier_reference,
  [13657] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    ACTIONS(1135), 1,
      sym_identifier,
    ACTIONS(1137), 1,
      anon_sym_end,
    ACTIONS(1139), 1,
      anon_sym_as,
    STATE(506), 1,
      sym_annotation_only_body,
  [13676] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(933), 1,
      anon_sym_def,
    ACTIONS(1141), 1,
      anon_sym_end,
    STATE(334), 1,
      sym_function_signature,
    STATE(394), 1,
      aux_sym_type_class_body_repeat1,
    STATE(492), 1,
      sym_method_def,
  [13695] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1143), 1,
      sym_identifier,
    ACTIONS(1146), 1,
      anon_sym_RBRACK,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(382), 1,
      aux_sym_rdf_types_repeat1,
    STATE(503), 1,
      sym_identifier_reference,
  [13714] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1150), 1,
      anon_sym_LPAREN,
    ACTIONS(1148), 4,
      sym_identifier,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_u2295,
  [13727] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1154), 1,
      sym_kw_is_fixed,
    STATE(258), 1,
      sym_tz_restriction_value,
    ACTIONS(1152), 3,
      anon_sym_required,
      anon_sym_prohibited,
      anon_sym_optional,
  [13742] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1011), 1,
      sym_unsigned,
    STATE(514), 1,
      sym_sequence_uniqueness,
    STATE(524), 1,
      sym__cardinality_inner,
    ACTIONS(1015), 2,
      anon_sym_unique,
      anon_sym_nonunique,
  [13759] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(933), 1,
      anon_sym_def,
    ACTIONS(1156), 1,
      anon_sym_is,
    STATE(405), 1,
      sym_function_signature,
    STATE(390), 2,
      sym_function_def,
      aux_sym_constraint_environment_repeat1,
  [13776] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(1158), 1,
      anon_sym_is,
    STATE(487), 1,
      sym_iri,
    STATE(507), 1,
      sym__module_locations,
    STATE(558), 1,
      sym_module_body,
  [13795] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1160), 1,
      anon_sym_LPAREN,
    STATE(13), 1,
      sym__type_op_has_type,
    STATE(389), 1,
      sym__function_type,
    ACTIONS(1162), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [13812] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1164), 5,
      anon_sym_is,
      anon_sym_end,
      anon_sym_def,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
  [13823] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1166), 1,
      anon_sym_is,
    ACTIONS(1168), 1,
      anon_sym_def,
    STATE(405), 1,
      sym_function_signature,
    STATE(390), 2,
      sym_function_def,
      aux_sym_constraint_environment_repeat1,
  [13840] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1173), 1,
      anon_sym_LPAREN,
    ACTIONS(1171), 4,
      sym_identifier,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_u2295,
  [13853] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(803), 1,
      sym_identifier,
    ACTIONS(807), 1,
      anon_sym_ref,
    STATE(414), 1,
      sym_member,
    STATE(400), 2,
      sym_member_def,
      sym_property_ref,
  [13870] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(933), 1,
      anon_sym_def,
    ACTIONS(1175), 1,
      anon_sym_end,
    STATE(334), 1,
      sym_function_signature,
    STATE(394), 1,
      aux_sym_type_class_body_repeat1,
    STATE(492), 1,
      sym_method_def,
  [13889] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1177), 1,
      anon_sym_end,
    ACTIONS(1179), 1,
      anon_sym_def,
    STATE(334), 1,
      sym_function_signature,
    STATE(394), 1,
      aux_sym_type_class_body_repeat1,
    STATE(492), 1,
      sym_method_def,
  [13908] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1182), 1,
      sym_identifier,
    ACTIONS(1186), 1,
      anon_sym_with,
    ACTIONS(1184), 3,
      anon_sym_end,
      anon_sym_parent,
      anon_sym_ref,
  [13923] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1188), 1,
      sym_identifier,
    ACTIONS(1190), 1,
      anon_sym_COLON_COLON,
    STATE(540), 3,
      sym_module_path_root_only,
      sym_module_path_absolute,
      sym_module_path_relative,
  [13938] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1192), 5,
      anon_sym_is,
      anon_sym_end,
      anon_sym_def,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
  [13949] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1194), 1,
      anon_sym_RBRACK,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(379), 1,
      aux_sym_rdf_types_repeat1,
    STATE(503), 1,
      sym_identifier_reference,
  [13968] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(375), 1,
      sym__type_op_type_restriction,
    ACTIONS(1196), 2,
      sym_identifier,
      anon_sym_RPAREN,
    ACTIONS(1198), 2,
      anon_sym_u2190,
      anon_sym_LT_DASH,
  [13983] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1200), 1,
      sym_identifier,
    ACTIONS(1202), 3,
      anon_sym_end,
      anon_sym_parent,
      anon_sym_ref,
  [13995] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1204), 1,
      sym_identifier,
    ACTIONS(1206), 1,
      sym_set_op_builder,
    STATE(412), 1,
      aux_sym_sequence_builder_repeat1,
    STATE(482), 1,
      sym_variable,
  [14011] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(13), 1,
      sym__type_op_has_type,
    STATE(397), 1,
      sym__function_type,
    ACTIONS(1162), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [14025] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1208), 1,
      sym_identifier,
    ACTIONS(1211), 1,
      anon_sym_RPAREN,
    STATE(403), 1,
      aux_sym_function_signature_repeat1,
    STATE(485), 1,
      sym_function_parameter,
  [14041] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(933), 1,
      anon_sym_def,
    STATE(405), 1,
      sym_function_signature,
    STATE(386), 2,
      sym_function_def,
      aux_sym_constraint_environment_repeat1,
  [14055] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(22), 1,
      sym__function_op_by_definition,
    STATE(497), 1,
      sym_function_body,
    ACTIONS(1213), 2,
      anon_sym_COLON_EQ,
      anon_sym_u2254,
  [14069] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    ACTIONS(1215), 1,
      sym_identifier,
    ACTIONS(1217), 1,
      anon_sym_end,
    STATE(498), 1,
      sym_annotation_only_body,
  [14085] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(247), 1,
      sym_tz_restriction_value,
    ACTIONS(1152), 3,
      anon_sym_required,
      anon_sym_prohibited,
      anon_sym_optional,
  [14097] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1219), 1,
      anon_sym_LBRACK,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(251), 1,
      sym_identifier_reference,
  [14113] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1221), 1,
      sym_identifier,
    ACTIONS(1223), 3,
      anon_sym_in,
      anon_sym_u2208,
      sym_set_op_builder,
  [14125] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1227), 1,
      anon_sym_RPAREN,
    STATE(420), 1,
      aux_sym_type_parameter_restriction_repeat1,
    ACTIONS(1225), 2,
      sym_identifier,
      sym_wildcard,
  [14139] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1128), 4,
      sym_identifier,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_u2295,
  [14149] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1229), 1,
      sym_identifier,
    ACTIONS(1232), 1,
      sym_set_op_builder,
    STATE(412), 1,
      aux_sym_sequence_builder_repeat1,
    STATE(482), 1,
      sym_variable,
  [14165] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1204), 1,
      sym_identifier,
    ACTIONS(1234), 1,
      sym_set_op_builder,
    STATE(412), 1,
      aux_sym_sequence_builder_repeat1,
    STATE(482), 1,
      sym_variable,
  [14181] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1236), 1,
      sym_identifier,
    ACTIONS(1238), 3,
      anon_sym_end,
      anon_sym_parent,
      anon_sym_ref,
  [14193] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(4), 1,
      sym__type_op_has_type,
    STATE(204), 1,
      sym__type_expression_to,
    ACTIONS(1240), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [14207] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1242), 1,
      anon_sym_with,
    ACTIONS(1244), 1,
      anon_sym_without,
    STATE(231), 2,
      sym_from_definition_with,
      sym_from_definition_without,
  [14221] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1246), 1,
      sym_identifier,
    ACTIONS(1248), 3,
      anon_sym_end,
      anon_sym_parent,
      anon_sym_ref,
  [14233] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1250), 1,
      sym_identifier,
    ACTIONS(1252), 1,
      anon_sym_LBRACK,
    ACTIONS(1254), 1,
      sym_wildcard,
    STATE(243), 1,
      sym__wildcard_or_identifier_or_sequence,
  [14249] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1256), 4,
      sym_identifier,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_u2295,
  [14259] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1261), 1,
      anon_sym_RPAREN,
    STATE(420), 1,
      aux_sym_type_parameter_restriction_repeat1,
    ACTIONS(1258), 2,
      sym_identifier,
      sym_wildcard,
  [14273] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1263), 1,
      anon_sym_RPAREN,
    STATE(420), 1,
      aux_sym_type_parameter_restriction_repeat1,
    ACTIONS(1225), 2,
      sym_identifier,
      sym_wildcard,
  [14287] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1265), 4,
      sym_identifier,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_u2295,
  [14297] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(13), 1,
      sym__type_op_has_type,
    STATE(505), 1,
      sym__function_type,
    ACTIONS(1162), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [14311] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(687), 1,
      anon_sym_RBRACK,
    ACTIONS(1066), 1,
      anon_sym_as,
    ACTIONS(1267), 1,
      sym_identifier,
    STATE(195), 1,
      sym__rename_import,
  [14327] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1269), 1,
      sym_identifier,
    ACTIONS(1271), 1,
      anon_sym_RPAREN,
    STATE(403), 1,
      aux_sym_function_signature_repeat1,
    STATE(485), 1,
      sym_function_parameter,
  [14343] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(701), 1,
      anon_sym_RBRACK,
    ACTIONS(1066), 1,
      anon_sym_as,
    ACTIONS(1273), 1,
      sym_identifier,
    STATE(192), 1,
      sym__rename_import,
  [14359] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(993), 1,
      sym_identifier,
    ACTIONS(1275), 1,
      anon_sym_end,
    STATE(428), 2,
      sym_value_variant,
      aux_sym_enum_body_repeat1,
  [14373] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1277), 1,
      sym_identifier,
    ACTIONS(1280), 1,
      anon_sym_end,
    STATE(428), 2,
      sym_value_variant,
      aux_sym_enum_body_repeat1,
  [14387] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    ACTIONS(1282), 1,
      sym_identifier,
    ACTIONS(1284), 1,
      anon_sym_end,
    STATE(495), 1,
      sym_annotation_only_body,
  [14403] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1286), 4,
      anon_sym_RBRACE,
      sym_unsigned,
      anon_sym_unique,
      anon_sym_nonunique,
  [14413] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(993), 1,
      sym_identifier,
    ACTIONS(995), 1,
      anon_sym_end,
    STATE(428), 2,
      sym_value_variant,
      aux_sym_enum_body_repeat1,
  [14427] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1288), 1,
      sym_identifier,
    ACTIONS(1290), 3,
      anon_sym_end,
      anon_sym_parent,
      anon_sym_ref,
  [14439] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1292), 1,
      sym_identifier,
    ACTIONS(1294), 3,
      anon_sym_end,
      anon_sym_parent,
      anon_sym_ref,
  [14451] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1296), 1,
      anon_sym_RBRACE,
    STATE(568), 1,
      sym_sequence_uniqueness,
    ACTIONS(1015), 2,
      anon_sym_unique,
      anon_sym_nonunique,
  [14465] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(727), 1,
      anon_sym_is,
    STATE(504), 1,
      sym_annotation_only_body,
    ACTIONS(1298), 2,
      anon_sym_end,
      anon_sym_def,
  [14479] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1300), 1,
      sym_identifier,
    ACTIONS(1303), 1,
      anon_sym_RPAREN,
    STATE(436), 1,
      aux_sym_type_class_def_repeat1,
    STATE(500), 1,
      sym_type_parameter,
  [14495] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1305), 1,
      sym_identifier,
    ACTIONS(1307), 1,
      anon_sym_RPAREN,
    STATE(436), 1,
      aux_sym_type_class_def_repeat1,
    STATE(500), 1,
      sym_type_parameter,
  [14511] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1309), 1,
      sym_identifier,
    ACTIONS(1312), 1,
      anon_sym_RBRACK,
    STATE(438), 1,
      aux_sym__wildcard_or_identifier_or_sequence_repeat1,
  [14524] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1314), 1,
      sym_identifier,
    ACTIONS(1316), 1,
      anon_sym_LBRACK,
    STATE(244), 1,
      sym__identifier_or_sequence,
  [14537] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1318), 1,
      anon_sym_RBRACK,
    ACTIONS(1320), 1,
      sym_quoted_string,
    STATE(440), 1,
      aux_sym_pattern_restriction_facet_repeat1,
  [14550] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(615), 1,
      anon_sym_LPAREN,
    ACTIONS(1323), 1,
      anon_sym_COMMA,
    STATE(160), 1,
      sym__actual_arguments,
  [14563] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(25), 1,
      sym__type_op_type_restriction,
    ACTIONS(1325), 2,
      anon_sym_u2190,
      anon_sym_LT_DASH,
  [14574] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1327), 3,
      sym_identifier,
      anon_sym_RPAREN,
      sym_wildcard,
  [14583] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(61), 1,
      sym_set_op_membership,
    ACTIONS(1329), 2,
      anon_sym_in,
      anon_sym_u2208,
  [14594] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1115), 1,
      sym_identifier,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(517), 1,
      sym_identifier_reference,
  [14607] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(79), 1,
      anon_sym_LT,
    ACTIONS(1331), 1,
      sym_quoted_string,
    STATE(538), 1,
      sym_iri,
  [14620] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(421), 1,
      aux_sym_type_parameter_restriction_repeat1,
    ACTIONS(1225), 2,
      sym_identifier,
      sym_wildcard,
  [14631] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1115), 1,
      sym_identifier,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(433), 1,
      sym_identifier_reference,
  [14644] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1333), 1,
      anon_sym_RBRACK,
    ACTIONS(1335), 1,
      sym_hex_byte,
    STATE(471), 1,
      aux_sym_binary_repeat1,
  [14657] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1269), 1,
      sym_identifier,
    STATE(425), 1,
      aux_sym_function_signature_repeat1,
    STATE(485), 1,
      sym_function_parameter,
  [14670] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1337), 1,
      anon_sym_LBRACK,
    ACTIONS(1339), 1,
      anon_sym_u2205,
    STATE(64), 1,
      sym__value_empty_sequence,
  [14683] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1341), 1,
      anon_sym_import,
    ACTIONS(1343), 1,
      anon_sym_COLON_COLON2,
    STATE(452), 1,
      aux_sym_module_path_absolute_repeat1,
  [14696] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(17), 1,
      sym__type_op_has_type,
    ACTIONS(1346), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [14707] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1348), 1,
      anon_sym_RBRACE,
    ACTIONS(1350), 1,
      anon_sym_DOT_DOT,
    STATE(580), 1,
      sym_cardinality_range,
  [14720] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1352), 1,
      anon_sym_LBRACK,
    ACTIONS(1354), 1,
      anon_sym_u2205,
    STATE(150), 1,
      sym__value_empty_sequence,
  [14733] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1314), 1,
      sym_identifier,
    ACTIONS(1316), 1,
      anon_sym_LBRACK,
    STATE(432), 1,
      sym__identifier_or_sequence,
  [14746] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1337), 1,
      anon_sym_LBRACK,
    ACTIONS(1339), 1,
      anon_sym_u2205,
    STATE(64), 1,
      sym__value_empty_sequence,
  [14759] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1011), 1,
      sym_unsigned,
    ACTIONS(1356), 1,
      anon_sym_RBRACE,
    STATE(546), 1,
      sym__cardinality_inner,
  [14772] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1358), 1,
      anon_sym_RBRACK,
    ACTIONS(1360), 1,
      sym_quoted_string,
    STATE(440), 1,
      aux_sym_pattern_restriction_facet_repeat1,
  [14785] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(461), 1,
      sym__type_op_has_type,
    ACTIONS(1362), 2,
      anon_sym_u2192,
      anon_sym_DASH_GT,
  [14796] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1115), 1,
      sym_identifier,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(373), 1,
      sym_identifier_reference,
  [14809] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1115), 1,
      sym_identifier,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(416), 1,
      sym_identifier_reference,
  [14822] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1364), 1,
      anon_sym_import,
    ACTIONS(1366), 1,
      anon_sym_COLON_COLON2,
    STATE(466), 1,
      aux_sym_module_path_absolute_repeat1,
  [14835] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1368), 1,
      sym_identifier,
    ACTIONS(1370), 1,
      anon_sym_RBRACK,
    STATE(438), 1,
      aux_sym__wildcard_or_identifier_or_sequence_repeat1,
  [14848] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1368), 1,
      sym_identifier,
    ACTIONS(1372), 1,
      anon_sym_RBRACK,
    STATE(438), 1,
      aux_sym__wildcard_or_identifier_or_sequence_repeat1,
  [14861] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1366), 1,
      anon_sym_COLON_COLON2,
    ACTIONS(1374), 1,
      anon_sym_import,
    STATE(452), 1,
      aux_sym_module_path_absolute_repeat1,
  [14874] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1305), 1,
      sym_identifier,
    STATE(437), 1,
      aux_sym_type_class_def_repeat1,
    STATE(500), 1,
      sym_type_parameter,
  [14887] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1115), 1,
      sym_identifier,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(409), 1,
      sym_identifier_reference,
  [14900] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1335), 1,
      sym_hex_byte,
    ACTIONS(1376), 1,
      anon_sym_RBRACK,
    STATE(472), 1,
      aux_sym_binary_repeat1,
  [14913] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1378), 1,
      anon_sym_LBRACK,
    ACTIONS(1380), 1,
      anon_sym_u2205,
    STATE(94), 1,
      sym__value_empty_sequence,
  [14926] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1335), 1,
      sym_hex_byte,
    ACTIONS(1382), 1,
      anon_sym_RBRACK,
    STATE(475), 1,
      aux_sym_binary_repeat1,
  [14939] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1335), 1,
      sym_hex_byte,
    ACTIONS(1384), 1,
      anon_sym_RBRACK,
    STATE(475), 1,
      aux_sym_binary_repeat1,
  [14952] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1386), 1,
      sym_identifier,
    STATE(99), 1,
      sym_qualified_identifier,
    STATE(395), 1,
      sym_identifier_reference,
  [14965] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1204), 1,
      sym_identifier,
    STATE(444), 1,
      sym_variable,
    STATE(561), 1,
      sym_quantified_variable,
  [14978] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1388), 1,
      anon_sym_RBRACK,
    ACTIONS(1390), 1,
      sym_hex_byte,
    STATE(475), 1,
      aux_sym_binary_repeat1,
  [14991] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1366), 1,
      anon_sym_COLON_COLON2,
    ACTIONS(1393), 1,
      anon_sym_import,
    STATE(452), 1,
      aux_sym_module_path_absolute_repeat1,
  [15004] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1011), 1,
      sym_unsigned,
    ACTIONS(1395), 1,
      anon_sym_RBRACE,
    STATE(535), 1,
      sym__cardinality_inner,
  [15017] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1115), 1,
      sym_identifier,
    STATE(5), 1,
      sym_qualified_identifier,
    STATE(383), 1,
      sym_identifier_reference,
  [15030] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    STATE(410), 1,
      aux_sym_type_parameter_restriction_repeat1,
    ACTIONS(1225), 2,
      sym_identifier,
      sym_wildcard,
  [15041] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1366), 1,
      anon_sym_COLON_COLON2,
    ACTIONS(1397), 1,
      anon_sym_import,
    STATE(476), 1,
      aux_sym_module_path_absolute_repeat1,
  [15054] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1399), 1,
      sym_quoted_string,
    STATE(459), 1,
      aux_sym_pattern_restriction_facet_repeat1,
  [15064] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1401), 2,
      sym_identifier,
      sym_set_op_builder,
  [15072] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1403), 2,
      anon_sym_RBRACE,
      sym_unsigned,
  [15080] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1368), 1,
      sym_identifier,
    STATE(465), 1,
      aux_sym__wildcard_or_identifier_or_sequence_repeat1,
  [15090] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1405), 2,
      sym_identifier,
      anon_sym_RPAREN,
  [15098] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1407), 2,
      anon_sym_RBRACK,
      sym_hex_byte,
  [15106] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1409), 1,
      anon_sym_version,
    ACTIONS(1411), 1,
      anon_sym_is,
  [15116] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1413), 1,
      sym_unsigned,
    ACTIONS(1415), 1,
      sym_kw_is_fixed,
  [15126] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1417), 1,
      sym_unsigned,
    ACTIONS(1419), 1,
      sym_kw_is_fixed,
  [15136] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1421), 1,
      sym_identifier,
    ACTIONS(1423), 1,
      anon_sym_import,
  [15146] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1425), 1,
      anon_sym_LBRACK,
    ACTIONS(1427), 1,
      sym_quoted_string,
  [15156] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1429), 2,
      anon_sym_end,
      anon_sym_def,
  [15164] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1431), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [15172] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1433), 1,
      anon_sym_RBRACE,
    ACTIONS(1435), 1,
      sym_unsigned,
  [15182] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1437), 1,
      sym_identifier,
    ACTIONS(1439), 1,
      anon_sym_end,
  [15192] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1441), 1,
      sym_identifier,
    STATE(295), 1,
      sym_member_def,
  [15202] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1443), 2,
      anon_sym_is,
      anon_sym_def,
  [15210] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1445), 1,
      sym_identifier,
    ACTIONS(1447), 1,
      anon_sym_end,
  [15220] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1449), 2,
      anon_sym_import,
      anon_sym_COLON_COLON2,
  [15228] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1451), 2,
      sym_identifier,
      anon_sym_RPAREN,
  [15236] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1453), 2,
      sym_identifier,
      anon_sym_LBRACE,
  [15244] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1011), 1,
      sym_unsigned,
    STATE(528), 1,
      sym__cardinality_inner,
  [15254] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1455), 2,
      anon_sym_RBRACK,
      sym_identifier,
  [15262] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1457), 2,
      anon_sym_end,
      anon_sym_def,
  [15270] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1459), 2,
      sym_identifier,
      anon_sym_RPAREN,
  [15278] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1461), 1,
      sym_identifier,
    ACTIONS(1463), 1,
      anon_sym_end,
  [15288] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1158), 1,
      anon_sym_is,
    STATE(516), 1,
      sym_module_body,
  [15298] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(79), 1,
      anon_sym_LT,
    STATE(578), 1,
      sym_iri,
  [15308] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1465), 2,
      anon_sym_end,
      anon_sym_def,
  [15316] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1467), 2,
      anon_sym_LBRACK,
      anon_sym_u2205,
  [15324] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1469), 2,
      anon_sym_LBRACK,
      anon_sym_u2205,
  [15332] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1471), 2,
      anon_sym_LBRACK,
      anon_sym_u2205,
  [15340] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1368), 1,
      sym_identifier,
    STATE(464), 1,
      aux_sym__wildcard_or_identifier_or_sequence_repeat1,
  [15350] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1011), 1,
      sym_unsigned,
    STATE(525), 1,
      sym__cardinality_inner,
  [15360] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1473), 1,
      sym_identifier,
  [15367] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1475), 1,
      ts_builtin_sym_end,
  [15374] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1477), 1,
      anon_sym_EQ,
  [15381] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1479), 1,
      sym_identifier,
  [15388] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1481), 1,
      anon_sym_RPAREN,
  [15395] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1483), 1,
      sym_identifier,
  [15402] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1485), 1,
      anon_sym_RBRACE,
  [15409] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1487), 1,
      sym_identifier,
  [15416] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1489), 1,
      ts_builtin_sym_end,
  [15423] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1491), 1,
      anon_sym_RBRACE,
  [15430] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1493), 1,
      anon_sym_RBRACE,
  [15437] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1495), 1,
      anon_sym_RBRACE,
  [15444] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1497), 1,
      anon_sym_RBRACE,
  [15451] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1499), 1,
      anon_sym_RBRACE,
  [15458] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1501), 1,
      anon_sym_RBRACE,
  [15465] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1503), 1,
      sym_quoted_string,
  [15472] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1505), 1,
      anon_sym_EQ,
  [15479] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1507), 1,
      anon_sym_RBRACE,
  [15486] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1509), 1,
      sym_identifier,
  [15493] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1511), 1,
      anon_sym_EQ,
  [15500] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1513), 1,
      anon_sym_RBRACE,
  [15507] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1515), 1,
      sym_identifier,
  [15514] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1517), 1,
      sym_identifier,
  [15521] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1519), 1,
      anon_sym_is,
  [15528] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1521), 1,
      anon_sym_EQ,
  [15535] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1523), 1,
      anon_sym_import,
  [15542] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1525), 1,
      anon_sym_is,
  [15549] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1527), 1,
      sym_identifier,
  [15556] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1529), 1,
      sym_identifier,
  [15563] = 2,
    ACTIONS(1531), 1,
      aux_sym_iri_token1,
    ACTIONS(1533), 1,
      sym_line_comment,
  [15570] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1535), 1,
      sym_identifier,
  [15577] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1537), 1,
      anon_sym_RBRACE,
  [15584] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1539), 1,
      ts_builtin_sym_end,
  [15591] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1541), 1,
      anon_sym_EQ,
  [15598] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1543), 1,
      anon_sym_GT,
  [15605] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1545), 1,
      anon_sym_EQ,
  [15612] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1547), 1,
      anon_sym_RBRACE,
  [15619] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1549), 1,
      sym_unsigned,
  [15626] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1551), 1,
      sym_identifier,
  [15633] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1553), 1,
      anon_sym_GT,
  [15640] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1555), 1,
      sym_identifier,
  [15647] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1557), 1,
      sym_unsigned,
  [15654] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1559), 1,
      sym_identifier,
  [15661] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1561), 1,
      ts_builtin_sym_end,
  [15668] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(229), 1,
      anon_sym_LPAREN,
  [15675] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1563), 1,
      sym_identifier,
  [15682] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1565), 1,
      anon_sym_COMMA,
  [15689] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1567), 1,
      anon_sym_COMMA,
  [15696] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1569), 1,
      sym_identifier,
  [15703] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1571), 1,
      sym_identifier,
  [15710] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1573), 1,
      sym_identifier,
  [15717] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1575), 1,
      ts_builtin_sym_end,
  [15724] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1577), 1,
      sym_identifier,
  [15731] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1579), 1,
      anon_sym_RBRACE,
  [15738] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1581), 1,
      sym_identifier,
  [15745] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1583), 1,
      anon_sym_import,
  [15752] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1585), 1,
      sym_identifier,
  [15759] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1587), 1,
      anon_sym_RPAREN,
  [15766] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1589), 1,
      sym_identifier,
  [15773] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1591), 1,
      anon_sym_RBRACE,
  [15780] = 2,
    ACTIONS(1533), 1,
      sym_line_comment,
    ACTIONS(1593), 1,
      aux_sym_iri_token1,
  [15787] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1595), 1,
      ts_builtin_sym_end,
  [15794] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1597), 1,
      anon_sym_COMMA,
  [15801] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1599), 1,
      anon_sym_is,
  [15808] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1601), 1,
      ts_builtin_sym_end,
  [15815] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1603), 1,
      anon_sym_RBRACE,
  [15822] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1605), 1,
      anon_sym_RBRACE,
  [15829] = 2,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(1607), 1,
      sym_identifier,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 69,
  [SMALL_STATE(4)] = 138,
  [SMALL_STATE(5)] = 222,
  [SMALL_STATE(6)] = 288,
  [SMALL_STATE(7)] = 356,
  [SMALL_STATE(8)] = 421,
  [SMALL_STATE(9)] = 486,
  [SMALL_STATE(10)] = 551,
  [SMALL_STATE(11)] = 616,
  [SMALL_STATE(12)] = 681,
  [SMALL_STATE(13)] = 746,
  [SMALL_STATE(14)] = 827,
  [SMALL_STATE(15)] = 892,
  [SMALL_STATE(16)] = 970,
  [SMALL_STATE(17)] = 1048,
  [SMALL_STATE(18)] = 1126,
  [SMALL_STATE(19)] = 1201,
  [SMALL_STATE(20)] = 1325,
  [SMALL_STATE(21)] = 1449,
  [SMALL_STATE(22)] = 1573,
  [SMALL_STATE(23)] = 1697,
  [SMALL_STATE(24)] = 1821,
  [SMALL_STATE(25)] = 1945,
  [SMALL_STATE(26)] = 2017,
  [SMALL_STATE(27)] = 2141,
  [SMALL_STATE(28)] = 2265,
  [SMALL_STATE(29)] = 2389,
  [SMALL_STATE(30)] = 2513,
  [SMALL_STATE(31)] = 2637,
  [SMALL_STATE(32)] = 2706,
  [SMALL_STATE(33)] = 2760,
  [SMALL_STATE(34)] = 2814,
  [SMALL_STATE(35)] = 2868,
  [SMALL_STATE(36)] = 2922,
  [SMALL_STATE(37)] = 2976,
  [SMALL_STATE(38)] = 3029,
  [SMALL_STATE(39)] = 3082,
  [SMALL_STATE(40)] = 3135,
  [SMALL_STATE(41)] = 3188,
  [SMALL_STATE(42)] = 3241,
  [SMALL_STATE(43)] = 3294,
  [SMALL_STATE(44)] = 3347,
  [SMALL_STATE(45)] = 3400,
  [SMALL_STATE(46)] = 3447,
  [SMALL_STATE(47)] = 3531,
  [SMALL_STATE(48)] = 3615,
  [SMALL_STATE(49)] = 3699,
  [SMALL_STATE(50)] = 3783,
  [SMALL_STATE(51)] = 3867,
  [SMALL_STATE(52)] = 3912,
  [SMALL_STATE(53)] = 3992,
  [SMALL_STATE(54)] = 4072,
  [SMALL_STATE(55)] = 4150,
  [SMALL_STATE(56)] = 4192,
  [SMALL_STATE(57)] = 4270,
  [SMALL_STATE(58)] = 4312,
  [SMALL_STATE(59)] = 4354,
  [SMALL_STATE(60)] = 4396,
  [SMALL_STATE(61)] = 4438,
  [SMALL_STATE(62)] = 4516,
  [SMALL_STATE(63)] = 4558,
  [SMALL_STATE(64)] = 4600,
  [SMALL_STATE(65)] = 4642,
  [SMALL_STATE(66)] = 4723,
  [SMALL_STATE(67)] = 4804,
  [SMALL_STATE(68)] = 4853,
  [SMALL_STATE(69)] = 4934,
  [SMALL_STATE(70)] = 5015,
  [SMALL_STATE(71)] = 5096,
  [SMALL_STATE(72)] = 5177,
  [SMALL_STATE(73)] = 5258,
  [SMALL_STATE(74)] = 5339,
  [SMALL_STATE(75)] = 5420,
  [SMALL_STATE(76)] = 5466,
  [SMALL_STATE(77)] = 5512,
  [SMALL_STATE(78)] = 5558,
  [SMALL_STATE(79)] = 5604,
  [SMALL_STATE(80)] = 5679,
  [SMALL_STATE(81)] = 5754,
  [SMALL_STATE(82)] = 5829,
  [SMALL_STATE(83)] = 5867,
  [SMALL_STATE(84)] = 5934,
  [SMALL_STATE(85)] = 6001,
  [SMALL_STATE(86)] = 6037,
  [SMALL_STATE(87)] = 6073,
  [SMALL_STATE(88)] = 6109,
  [SMALL_STATE(89)] = 6145,
  [SMALL_STATE(90)] = 6181,
  [SMALL_STATE(91)] = 6217,
  [SMALL_STATE(92)] = 6253,
  [SMALL_STATE(93)] = 6289,
  [SMALL_STATE(94)] = 6325,
  [SMALL_STATE(95)] = 6361,
  [SMALL_STATE(96)] = 6397,
  [SMALL_STATE(97)] = 6434,
  [SMALL_STATE(98)] = 6496,
  [SMALL_STATE(99)] = 6558,
  [SMALL_STATE(100)] = 6592,
  [SMALL_STATE(101)] = 6654,
  [SMALL_STATE(102)] = 6688,
  [SMALL_STATE(103)] = 6750,
  [SMALL_STATE(104)] = 6812,
  [SMALL_STATE(105)] = 6847,
  [SMALL_STATE(106)] = 6882,
  [SMALL_STATE(107)] = 6941,
  [SMALL_STATE(108)] = 6973,
  [SMALL_STATE(109)] = 7005,
  [SMALL_STATE(110)] = 7045,
  [SMALL_STATE(111)] = 7101,
  [SMALL_STATE(112)] = 7133,
  [SMALL_STATE(113)] = 7165,
  [SMALL_STATE(114)] = 7197,
  [SMALL_STATE(115)] = 7229,
  [SMALL_STATE(116)] = 7260,
  [SMALL_STATE(117)] = 7313,
  [SMALL_STATE(118)] = 7346,
  [SMALL_STATE(119)] = 7383,
  [SMALL_STATE(120)] = 7420,
  [SMALL_STATE(121)] = 7473,
  [SMALL_STATE(122)] = 7510,
  [SMALL_STATE(123)] = 7547,
  [SMALL_STATE(124)] = 7600,
  [SMALL_STATE(125)] = 7653,
  [SMALL_STATE(126)] = 7683,
  [SMALL_STATE(127)] = 7713,
  [SMALL_STATE(128)] = 7743,
  [SMALL_STATE(129)] = 7773,
  [SMALL_STATE(130)] = 7803,
  [SMALL_STATE(131)] = 7833,
  [SMALL_STATE(132)] = 7863,
  [SMALL_STATE(133)] = 7893,
  [SMALL_STATE(134)] = 7931,
  [SMALL_STATE(135)] = 7970,
  [SMALL_STATE(136)] = 7999,
  [SMALL_STATE(137)] = 8028,
  [SMALL_STATE(138)] = 8067,
  [SMALL_STATE(139)] = 8096,
  [SMALL_STATE(140)] = 8125,
  [SMALL_STATE(141)] = 8154,
  [SMALL_STATE(142)] = 8193,
  [SMALL_STATE(143)] = 8222,
  [SMALL_STATE(144)] = 8255,
  [SMALL_STATE(145)] = 8287,
  [SMALL_STATE(146)] = 8319,
  [SMALL_STATE(147)] = 8355,
  [SMALL_STATE(148)] = 8383,
  [SMALL_STATE(149)] = 8411,
  [SMALL_STATE(150)] = 8439,
  [SMALL_STATE(151)] = 8467,
  [SMALL_STATE(152)] = 8495,
  [SMALL_STATE(153)] = 8523,
  [SMALL_STATE(154)] = 8551,
  [SMALL_STATE(155)] = 8583,
  [SMALL_STATE(156)] = 8612,
  [SMALL_STATE(157)] = 8649,
  [SMALL_STATE(158)] = 8678,
  [SMALL_STATE(159)] = 8715,
  [SMALL_STATE(160)] = 8742,
  [SMALL_STATE(161)] = 8767,
  [SMALL_STATE(162)] = 8804,
  [SMALL_STATE(163)] = 8841,
  [SMALL_STATE(164)] = 8870,
  [SMALL_STATE(165)] = 8907,
  [SMALL_STATE(166)] = 8934,
  [SMALL_STATE(167)] = 8963,
  [SMALL_STATE(168)] = 8990,
  [SMALL_STATE(169)] = 9017,
  [SMALL_STATE(170)] = 9060,
  [SMALL_STATE(171)] = 9087,
  [SMALL_STATE(172)] = 9113,
  [SMALL_STATE(173)] = 9139,
  [SMALL_STATE(174)] = 9165,
  [SMALL_STATE(175)] = 9199,
  [SMALL_STATE(176)] = 9231,
  [SMALL_STATE(177)] = 9257,
  [SMALL_STATE(178)] = 9283,
  [SMALL_STATE(179)] = 9309,
  [SMALL_STATE(180)] = 9337,
  [SMALL_STATE(181)] = 9363,
  [SMALL_STATE(182)] = 9386,
  [SMALL_STATE(183)] = 9409,
  [SMALL_STATE(184)] = 9434,
  [SMALL_STATE(185)] = 9459,
  [SMALL_STATE(186)] = 9482,
  [SMALL_STATE(187)] = 9505,
  [SMALL_STATE(188)] = 9530,
  [SMALL_STATE(189)] = 9555,
  [SMALL_STATE(190)] = 9580,
  [SMALL_STATE(191)] = 9607,
  [SMALL_STATE(192)] = 9636,
  [SMALL_STATE(193)] = 9661,
  [SMALL_STATE(194)] = 9686,
  [SMALL_STATE(195)] = 9713,
  [SMALL_STATE(196)] = 9738,
  [SMALL_STATE(197)] = 9761,
  [SMALL_STATE(198)] = 9786,
  [SMALL_STATE(199)] = 9809,
  [SMALL_STATE(200)] = 9848,
  [SMALL_STATE(201)] = 9886,
  [SMALL_STATE(202)] = 9910,
  [SMALL_STATE(203)] = 9934,
  [SMALL_STATE(204)] = 9964,
  [SMALL_STATE(205)] = 9992,
  [SMALL_STATE(206)] = 10024,
  [SMALL_STATE(207)] = 10045,
  [SMALL_STATE(208)] = 10068,
  [SMALL_STATE(209)] = 10089,
  [SMALL_STATE(210)] = 10112,
  [SMALL_STATE(211)] = 10141,
  [SMALL_STATE(212)] = 10170,
  [SMALL_STATE(213)] = 10199,
  [SMALL_STATE(214)] = 10228,
  [SMALL_STATE(215)] = 10257,
  [SMALL_STATE(216)] = 10286,
  [SMALL_STATE(217)] = 10315,
  [SMALL_STATE(218)] = 10340,
  [SMALL_STATE(219)] = 10369,
  [SMALL_STATE(220)] = 10390,
  [SMALL_STATE(221)] = 10411,
  [SMALL_STATE(222)] = 10434,
  [SMALL_STATE(223)] = 10463,
  [SMALL_STATE(224)] = 10485,
  [SMALL_STATE(225)] = 10519,
  [SMALL_STATE(226)] = 10541,
  [SMALL_STATE(227)] = 10575,
  [SMALL_STATE(228)] = 10598,
  [SMALL_STATE(229)] = 10633,
  [SMALL_STATE(230)] = 10656,
  [SMALL_STATE(231)] = 10679,
  [SMALL_STATE(232)] = 10698,
  [SMALL_STATE(233)] = 10721,
  [SMALL_STATE(234)] = 10744,
  [SMALL_STATE(235)] = 10763,
  [SMALL_STATE(236)] = 10786,
  [SMALL_STATE(237)] = 10821,
  [SMALL_STATE(238)] = 10844,
  [SMALL_STATE(239)] = 10867,
  [SMALL_STATE(240)] = 10890,
  [SMALL_STATE(241)] = 10913,
  [SMALL_STATE(242)] = 10932,
  [SMALL_STATE(243)] = 10951,
  [SMALL_STATE(244)] = 10970,
  [SMALL_STATE(245)] = 10989,
  [SMALL_STATE(246)] = 11012,
  [SMALL_STATE(247)] = 11030,
  [SMALL_STATE(248)] = 11048,
  [SMALL_STATE(249)] = 11082,
  [SMALL_STATE(250)] = 11100,
  [SMALL_STATE(251)] = 11118,
  [SMALL_STATE(252)] = 11136,
  [SMALL_STATE(253)] = 11154,
  [SMALL_STATE(254)] = 11188,
  [SMALL_STATE(255)] = 11206,
  [SMALL_STATE(256)] = 11224,
  [SMALL_STATE(257)] = 11242,
  [SMALL_STATE(258)] = 11260,
  [SMALL_STATE(259)] = 11278,
  [SMALL_STATE(260)] = 11296,
  [SMALL_STATE(261)] = 11314,
  [SMALL_STATE(262)] = 11332,
  [SMALL_STATE(263)] = 11350,
  [SMALL_STATE(264)] = 11368,
  [SMALL_STATE(265)] = 11385,
  [SMALL_STATE(266)] = 11402,
  [SMALL_STATE(267)] = 11419,
  [SMALL_STATE(268)] = 11436,
  [SMALL_STATE(269)] = 11453,
  [SMALL_STATE(270)] = 11470,
  [SMALL_STATE(271)] = 11487,
  [SMALL_STATE(272)] = 11504,
  [SMALL_STATE(273)] = 11521,
  [SMALL_STATE(274)] = 11538,
  [SMALL_STATE(275)] = 11555,
  [SMALL_STATE(276)] = 11572,
  [SMALL_STATE(277)] = 11589,
  [SMALL_STATE(278)] = 11606,
  [SMALL_STATE(279)] = 11623,
  [SMALL_STATE(280)] = 11640,
  [SMALL_STATE(281)] = 11657,
  [SMALL_STATE(282)] = 11674,
  [SMALL_STATE(283)] = 11691,
  [SMALL_STATE(284)] = 11708,
  [SMALL_STATE(285)] = 11725,
  [SMALL_STATE(286)] = 11742,
  [SMALL_STATE(287)] = 11759,
  [SMALL_STATE(288)] = 11776,
  [SMALL_STATE(289)] = 11793,
  [SMALL_STATE(290)] = 11826,
  [SMALL_STATE(291)] = 11843,
  [SMALL_STATE(292)] = 11860,
  [SMALL_STATE(293)] = 11877,
  [SMALL_STATE(294)] = 11894,
  [SMALL_STATE(295)] = 11911,
  [SMALL_STATE(296)] = 11928,
  [SMALL_STATE(297)] = 11945,
  [SMALL_STATE(298)] = 11978,
  [SMALL_STATE(299)] = 11995,
  [SMALL_STATE(300)] = 12012,
  [SMALL_STATE(301)] = 12029,
  [SMALL_STATE(302)] = 12046,
  [SMALL_STATE(303)] = 12063,
  [SMALL_STATE(304)] = 12080,
  [SMALL_STATE(305)] = 12097,
  [SMALL_STATE(306)] = 12114,
  [SMALL_STATE(307)] = 12131,
  [SMALL_STATE(308)] = 12148,
  [SMALL_STATE(309)] = 12165,
  [SMALL_STATE(310)] = 12182,
  [SMALL_STATE(311)] = 12199,
  [SMALL_STATE(312)] = 12216,
  [SMALL_STATE(313)] = 12233,
  [SMALL_STATE(314)] = 12250,
  [SMALL_STATE(315)] = 12267,
  [SMALL_STATE(316)] = 12284,
  [SMALL_STATE(317)] = 12301,
  [SMALL_STATE(318)] = 12329,
  [SMALL_STATE(319)] = 12357,
  [SMALL_STATE(320)] = 12385,
  [SMALL_STATE(321)] = 12413,
  [SMALL_STATE(322)] = 12441,
  [SMALL_STATE(323)] = 12469,
  [SMALL_STATE(324)] = 12497,
  [SMALL_STATE(325)] = 12525,
  [SMALL_STATE(326)] = 12552,
  [SMALL_STATE(327)] = 12579,
  [SMALL_STATE(328)] = 12604,
  [SMALL_STATE(329)] = 12629,
  [SMALL_STATE(330)] = 12656,
  [SMALL_STATE(331)] = 12680,
  [SMALL_STATE(332)] = 12704,
  [SMALL_STATE(333)] = 12728,
  [SMALL_STATE(334)] = 12752,
  [SMALL_STATE(335)] = 12776,
  [SMALL_STATE(336)] = 12794,
  [SMALL_STATE(337)] = 12818,
  [SMALL_STATE(338)] = 12839,
  [SMALL_STATE(339)] = 12858,
  [SMALL_STATE(340)] = 12877,
  [SMALL_STATE(341)] = 12896,
  [SMALL_STATE(342)] = 12917,
  [SMALL_STATE(343)] = 12938,
  [SMALL_STATE(344)] = 12959,
  [SMALL_STATE(345)] = 12980,
  [SMALL_STATE(346)] = 12999,
  [SMALL_STATE(347)] = 13014,
  [SMALL_STATE(348)] = 13029,
  [SMALL_STATE(349)] = 13050,
  [SMALL_STATE(350)] = 13065,
  [SMALL_STATE(351)] = 13086,
  [SMALL_STATE(352)] = 13107,
  [SMALL_STATE(353)] = 13132,
  [SMALL_STATE(354)] = 13153,
  [SMALL_STATE(355)] = 13174,
  [SMALL_STATE(356)] = 13195,
  [SMALL_STATE(357)] = 13216,
  [SMALL_STATE(358)] = 13237,
  [SMALL_STATE(359)] = 13258,
  [SMALL_STATE(360)] = 13279,
  [SMALL_STATE(361)] = 13300,
  [SMALL_STATE(362)] = 13320,
  [SMALL_STATE(363)] = 13340,
  [SMALL_STATE(364)] = 13358,
  [SMALL_STATE(365)] = 13374,
  [SMALL_STATE(366)] = 13392,
  [SMALL_STATE(367)] = 13410,
  [SMALL_STATE(368)] = 13430,
  [SMALL_STATE(369)] = 13450,
  [SMALL_STATE(370)] = 13468,
  [SMALL_STATE(371)] = 13490,
  [SMALL_STATE(372)] = 13508,
  [SMALL_STATE(373)] = 13526,
  [SMALL_STATE(374)] = 13544,
  [SMALL_STATE(375)] = 13564,
  [SMALL_STATE(376)] = 13586,
  [SMALL_STATE(377)] = 13602,
  [SMALL_STATE(378)] = 13620,
  [SMALL_STATE(379)] = 13638,
  [SMALL_STATE(380)] = 13657,
  [SMALL_STATE(381)] = 13676,
  [SMALL_STATE(382)] = 13695,
  [SMALL_STATE(383)] = 13714,
  [SMALL_STATE(384)] = 13727,
  [SMALL_STATE(385)] = 13742,
  [SMALL_STATE(386)] = 13759,
  [SMALL_STATE(387)] = 13776,
  [SMALL_STATE(388)] = 13795,
  [SMALL_STATE(389)] = 13812,
  [SMALL_STATE(390)] = 13823,
  [SMALL_STATE(391)] = 13840,
  [SMALL_STATE(392)] = 13853,
  [SMALL_STATE(393)] = 13870,
  [SMALL_STATE(394)] = 13889,
  [SMALL_STATE(395)] = 13908,
  [SMALL_STATE(396)] = 13923,
  [SMALL_STATE(397)] = 13938,
  [SMALL_STATE(398)] = 13949,
  [SMALL_STATE(399)] = 13968,
  [SMALL_STATE(400)] = 13983,
  [SMALL_STATE(401)] = 13995,
  [SMALL_STATE(402)] = 14011,
  [SMALL_STATE(403)] = 14025,
  [SMALL_STATE(404)] = 14041,
  [SMALL_STATE(405)] = 14055,
  [SMALL_STATE(406)] = 14069,
  [SMALL_STATE(407)] = 14085,
  [SMALL_STATE(408)] = 14097,
  [SMALL_STATE(409)] = 14113,
  [SMALL_STATE(410)] = 14125,
  [SMALL_STATE(411)] = 14139,
  [SMALL_STATE(412)] = 14149,
  [SMALL_STATE(413)] = 14165,
  [SMALL_STATE(414)] = 14181,
  [SMALL_STATE(415)] = 14193,
  [SMALL_STATE(416)] = 14207,
  [SMALL_STATE(417)] = 14221,
  [SMALL_STATE(418)] = 14233,
  [SMALL_STATE(419)] = 14249,
  [SMALL_STATE(420)] = 14259,
  [SMALL_STATE(421)] = 14273,
  [SMALL_STATE(422)] = 14287,
  [SMALL_STATE(423)] = 14297,
  [SMALL_STATE(424)] = 14311,
  [SMALL_STATE(425)] = 14327,
  [SMALL_STATE(426)] = 14343,
  [SMALL_STATE(427)] = 14359,
  [SMALL_STATE(428)] = 14373,
  [SMALL_STATE(429)] = 14387,
  [SMALL_STATE(430)] = 14403,
  [SMALL_STATE(431)] = 14413,
  [SMALL_STATE(432)] = 14427,
  [SMALL_STATE(433)] = 14439,
  [SMALL_STATE(434)] = 14451,
  [SMALL_STATE(435)] = 14465,
  [SMALL_STATE(436)] = 14479,
  [SMALL_STATE(437)] = 14495,
  [SMALL_STATE(438)] = 14511,
  [SMALL_STATE(439)] = 14524,
  [SMALL_STATE(440)] = 14537,
  [SMALL_STATE(441)] = 14550,
  [SMALL_STATE(442)] = 14563,
  [SMALL_STATE(443)] = 14574,
  [SMALL_STATE(444)] = 14583,
  [SMALL_STATE(445)] = 14594,
  [SMALL_STATE(446)] = 14607,
  [SMALL_STATE(447)] = 14620,
  [SMALL_STATE(448)] = 14631,
  [SMALL_STATE(449)] = 14644,
  [SMALL_STATE(450)] = 14657,
  [SMALL_STATE(451)] = 14670,
  [SMALL_STATE(452)] = 14683,
  [SMALL_STATE(453)] = 14696,
  [SMALL_STATE(454)] = 14707,
  [SMALL_STATE(455)] = 14720,
  [SMALL_STATE(456)] = 14733,
  [SMALL_STATE(457)] = 14746,
  [SMALL_STATE(458)] = 14759,
  [SMALL_STATE(459)] = 14772,
  [SMALL_STATE(460)] = 14785,
  [SMALL_STATE(461)] = 14796,
  [SMALL_STATE(462)] = 14809,
  [SMALL_STATE(463)] = 14822,
  [SMALL_STATE(464)] = 14835,
  [SMALL_STATE(465)] = 14848,
  [SMALL_STATE(466)] = 14861,
  [SMALL_STATE(467)] = 14874,
  [SMALL_STATE(468)] = 14887,
  [SMALL_STATE(469)] = 14900,
  [SMALL_STATE(470)] = 14913,
  [SMALL_STATE(471)] = 14926,
  [SMALL_STATE(472)] = 14939,
  [SMALL_STATE(473)] = 14952,
  [SMALL_STATE(474)] = 14965,
  [SMALL_STATE(475)] = 14978,
  [SMALL_STATE(476)] = 14991,
  [SMALL_STATE(477)] = 15004,
  [SMALL_STATE(478)] = 15017,
  [SMALL_STATE(479)] = 15030,
  [SMALL_STATE(480)] = 15041,
  [SMALL_STATE(481)] = 15054,
  [SMALL_STATE(482)] = 15064,
  [SMALL_STATE(483)] = 15072,
  [SMALL_STATE(484)] = 15080,
  [SMALL_STATE(485)] = 15090,
  [SMALL_STATE(486)] = 15098,
  [SMALL_STATE(487)] = 15106,
  [SMALL_STATE(488)] = 15116,
  [SMALL_STATE(489)] = 15126,
  [SMALL_STATE(490)] = 15136,
  [SMALL_STATE(491)] = 15146,
  [SMALL_STATE(492)] = 15156,
  [SMALL_STATE(493)] = 15164,
  [SMALL_STATE(494)] = 15172,
  [SMALL_STATE(495)] = 15182,
  [SMALL_STATE(496)] = 15192,
  [SMALL_STATE(497)] = 15202,
  [SMALL_STATE(498)] = 15210,
  [SMALL_STATE(499)] = 15220,
  [SMALL_STATE(500)] = 15228,
  [SMALL_STATE(501)] = 15236,
  [SMALL_STATE(502)] = 15244,
  [SMALL_STATE(503)] = 15254,
  [SMALL_STATE(504)] = 15262,
  [SMALL_STATE(505)] = 15270,
  [SMALL_STATE(506)] = 15278,
  [SMALL_STATE(507)] = 15288,
  [SMALL_STATE(508)] = 15298,
  [SMALL_STATE(509)] = 15308,
  [SMALL_STATE(510)] = 15316,
  [SMALL_STATE(511)] = 15324,
  [SMALL_STATE(512)] = 15332,
  [SMALL_STATE(513)] = 15340,
  [SMALL_STATE(514)] = 15350,
  [SMALL_STATE(515)] = 15360,
  [SMALL_STATE(516)] = 15367,
  [SMALL_STATE(517)] = 15374,
  [SMALL_STATE(518)] = 15381,
  [SMALL_STATE(519)] = 15388,
  [SMALL_STATE(520)] = 15395,
  [SMALL_STATE(521)] = 15402,
  [SMALL_STATE(522)] = 15409,
  [SMALL_STATE(523)] = 15416,
  [SMALL_STATE(524)] = 15423,
  [SMALL_STATE(525)] = 15430,
  [SMALL_STATE(526)] = 15437,
  [SMALL_STATE(527)] = 15444,
  [SMALL_STATE(528)] = 15451,
  [SMALL_STATE(529)] = 15458,
  [SMALL_STATE(530)] = 15465,
  [SMALL_STATE(531)] = 15472,
  [SMALL_STATE(532)] = 15479,
  [SMALL_STATE(533)] = 15486,
  [SMALL_STATE(534)] = 15493,
  [SMALL_STATE(535)] = 15500,
  [SMALL_STATE(536)] = 15507,
  [SMALL_STATE(537)] = 15514,
  [SMALL_STATE(538)] = 15521,
  [SMALL_STATE(539)] = 15528,
  [SMALL_STATE(540)] = 15535,
  [SMALL_STATE(541)] = 15542,
  [SMALL_STATE(542)] = 15549,
  [SMALL_STATE(543)] = 15556,
  [SMALL_STATE(544)] = 15563,
  [SMALL_STATE(545)] = 15570,
  [SMALL_STATE(546)] = 15577,
  [SMALL_STATE(547)] = 15584,
  [SMALL_STATE(548)] = 15591,
  [SMALL_STATE(549)] = 15598,
  [SMALL_STATE(550)] = 15605,
  [SMALL_STATE(551)] = 15612,
  [SMALL_STATE(552)] = 15619,
  [SMALL_STATE(553)] = 15626,
  [SMALL_STATE(554)] = 15633,
  [SMALL_STATE(555)] = 15640,
  [SMALL_STATE(556)] = 15647,
  [SMALL_STATE(557)] = 15654,
  [SMALL_STATE(558)] = 15661,
  [SMALL_STATE(559)] = 15668,
  [SMALL_STATE(560)] = 15675,
  [SMALL_STATE(561)] = 15682,
  [SMALL_STATE(562)] = 15689,
  [SMALL_STATE(563)] = 15696,
  [SMALL_STATE(564)] = 15703,
  [SMALL_STATE(565)] = 15710,
  [SMALL_STATE(566)] = 15717,
  [SMALL_STATE(567)] = 15724,
  [SMALL_STATE(568)] = 15731,
  [SMALL_STATE(569)] = 15738,
  [SMALL_STATE(570)] = 15745,
  [SMALL_STATE(571)] = 15752,
  [SMALL_STATE(572)] = 15759,
  [SMALL_STATE(573)] = 15766,
  [SMALL_STATE(574)] = 15773,
  [SMALL_STATE(575)] = 15780,
  [SMALL_STATE(576)] = 15787,
  [SMALL_STATE(577)] = 15794,
  [SMALL_STATE(578)] = 15801,
  [SMALL_STATE(579)] = 15808,
  [SMALL_STATE(580)] = 15815,
  [SMALL_STATE(581)] = 15822,
  [SMALL_STATE(582)] = 15829,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [7] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 18),
  [9] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_identifier, 3, 0, 18),
  [11] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_iri, 3, 0, 0),
  [13] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_iri, 3, 0, 0),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(45),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(126),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [27] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier_reference, 1, 0, 0),
  [29] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier_reference, 1, 0, 0),
  [31] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 1, 0, 0),
  [33] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 1, 0, 0),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [37] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_simple_value, 1, 0, 0),
  [39] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_value, 1, 0, 0),
  [41] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_truth, 1, 0, 0),
  [43] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_truth, 1, 0, 0),
  [45] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_falsity, 1, 0, 0),
  [47] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_falsity, 1, 0, 0),
  [49] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [51] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [53] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary, 2, 0, 0),
  [55] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary, 2, 0, 0),
  [57] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary, 3, 0, 66),
  [59] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary, 3, 0, 66),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [63] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 35),
  [65] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 35),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(67),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [93] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_constructor, 4, 0, 97),
  [103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_constructor, 4, 0, 97),
  [105] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_expression, 3, 0, 88),
  [107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_expression, 3, 0, 88),
  [109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_expression, 4, 0, 106),
  [111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_expression, 4, 0, 106),
  [113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_expression, 4, 0, 107),
  [115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_expression, 4, 0, 107),
  [117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_expression, 5, 0, 117),
  [119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_expression, 5, 0, 117),
  [121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_reference_expression, 3, 0, 65),
  [123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_reference_expression, 3, 0, 65),
  [125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_reference_expression, 2, 0, 0),
  [127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_reference_expression, 2, 0, 0),
  [129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_reference_expression, 4, 0, 96),
  [131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_reference_expression, 4, 0, 96),
  [133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_reference_expression, 3, 0, 88),
  [135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_reference_expression, 3, 0, 88),
  [137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_reference_expression, 3, 0, 64),
  [139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_reference_expression, 3, 0, 64),
  [141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_reference_expression, 4, 0, 107),
  [143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_reference_expression, 4, 0, 107),
  [145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_reference_expression, 4, 0, 106),
  [147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_reference_expression, 4, 0, 106),
  [149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cardinality_reference_expression, 5, 0, 117),
  [151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_reference_expression, 5, 0, 117),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(567),
  [155] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(109),
  [158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(72),
  [161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101),
  [163] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(118),
  [166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(329),
  [169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(117),
  [172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(575),
  [175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(469),
  [178] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(130),
  [181] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(130),
  [184] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(128),
  [187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(129),
  [190] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 2, 0, 101), SHIFT_REPEAT(148),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(130),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value, 1, 0, 0),
  [227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value, 1, 0, 0),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [263] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_values, 1, 0, 23),
  [265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_values, 1, 0, 23),
  [267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_values, 3, 0, 62),
  [269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_values, 3, 0, 62),
  [271] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mapping_value, 3, 0, 68),
  [273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mapping_value, 3, 0, 68),
  [275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_values, 3, 0, 69),
  [277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_values, 3, 0, 69),
  [279] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_values, 4, 0, 98),
  [281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_values, 4, 0, 98),
  [283] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_values, 2, 0, 0),
  [285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_values, 2, 0, 0),
  [287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_values, 2, 0, 37),
  [289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_values, 2, 0, 37),
  [291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(157),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(157),
  [308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(72),
  [311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63),
  [313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(372),
  [316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(117),
  [319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(575),
  [322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(469),
  [325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(130),
  [328] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(130),
  [331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(128),
  [334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(129),
  [337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 2, 0, 63), SHIFT_REPEAT(148),
  [340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_term, 1, 0, 0),
  [352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_term, 1, 0, 0),
  [354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_composition_repeat1, 2, 0, 70),
  [356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_composition_repeat1, 2, 0, 70),
  [358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_composition_repeat1, 2, 0, 70), SHIFT_REPEAT(553),
  [361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_composition, 2, 0, 38),
  [363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_composition, 2, 0, 38),
  [365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_composition_repeat1, 2, 0, 6),
  [371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_composition_repeat1, 2, 0, 6),
  [373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__actual_arguments, 2, 0, 0),
  [377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__actual_arguments, 2, 0, 0),
  [379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_predicate_values, 3, 0, 69),
  [381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_predicate_values, 3, 0, 69),
  [383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_predicate_values, 3, 0, 62),
  [385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_predicate_values, 3, 0, 62),
  [387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_predicate_value, 1, 0, 0),
  [389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_predicate_value, 1, 0, 0),
  [391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__actual_arguments, 3, 0, 100),
  [393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__actual_arguments, 3, 0, 100),
  [395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_predicate_values, 4, 0, 98),
  [397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_predicate_values, 4, 0, 98),
  [399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_builder, 5, 0, 111),
  [401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_builder, 5, 0, 111),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_predicate_values, 2, 0, 0),
  [405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_predicate_values, 2, 0, 0),
  [407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_predicate_values, 2, 0, 37),
  [409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_predicate_values, 2, 0, 37),
  [411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_of_predicate_values, 1, 0, 23),
  [413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sequence_of_predicate_values, 1, 0, 23),
  [415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_functional_term, 2, 0, 42),
  [417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_atomic_sentence, 2, 0, 41),
  [419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_functional_term, 2, 0, 42),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [427] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sequence_of_values_repeat1, 2, 0, 63), SHIFT_REPEAT(157),
  [430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sequence_of_values_repeat1, 2, 0, 63),
  [432] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_values_repeat1, 2, 0, 63), SHIFT_REPEAT(117),
  [435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_values_repeat1, 2, 0, 63), SHIFT_REPEAT(575),
  [438] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_values_repeat1, 2, 0, 63), SHIFT_REPEAT(469),
  [441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_values_repeat1, 2, 0, 63), SHIFT_REPEAT(130),
  [444] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sequence_of_values_repeat1, 2, 0, 63), SHIFT_REPEAT(130),
  [447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_values_repeat1, 2, 0, 63), SHIFT_REPEAT(128),
  [450] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_of_values_repeat1, 2, 0, 63), SHIFT_REPEAT(129),
  [453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_logical_op_negation, 1, 0, 0),
  [459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_logical_op_negation, 1, 0, 0),
  [461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_logical_op_biconditional, 1, 0, 0),
  [463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_logical_op_biconditional, 1, 0, 0),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_logical_op_exclusive_disjunction, 1, 0, 0),
  [471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_logical_op_exclusive_disjunction, 1, 0, 0),
  [473] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_logical_op_implication, 1, 0, 0),
  [475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_logical_op_implication, 1, 0, 0),
  [477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_logical_op_conjunction, 1, 0, 0),
  [479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_logical_op_conjunction, 1, 0, 0),
  [481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_logical_op_disjunction, 1, 0, 0),
  [483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_logical_op_disjunction, 1, 0, 0),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [487] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_composition_repeat1, 2, 0, 70), SHIFT_REPEAT(563),
  [490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0),
  [494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0), SHIFT_REPEAT(536),
  [497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0), SHIFT_REPEAT(522),
  [500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0), SHIFT_REPEAT(543),
  [503] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0), SHIFT_REPEAT(518),
  [506] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0), SHIFT_REPEAT(520),
  [509] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0), SHIFT_REPEAT(496),
  [512] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0), SHIFT_REPEAT(515),
  [515] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0), SHIFT_REPEAT(557),
  [518] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0), SHIFT_REPEAT(560),
  [521] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat3, 2, 0, 0), SHIFT_REPEAT(565),
  [524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_builtin_simple_type, 1, 0, 0),
  [526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_builtin_simple_type, 1, 0, 0),
  [528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_module_body_repeat2, 2, 0, 0),
  [530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_body_repeat2, 2, 0, 0),
  [532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat2, 2, 0, 0), SHIFT_REPEAT(445),
  [535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat2, 2, 0, 0), SHIFT_REPEAT(564),
  [538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quantified_sentence, 3, 0, 73),
  [540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_boolean_sentence, 3, 0, 72),
  [552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_body, 2, 0, 40),
  [554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_boolean_sentence, 2, 0, 43),
  [556] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_mapping_type, 5, 0, 116),
  [558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mapping_type, 5, 0, 116),
  [560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [562] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__actual_arguments_repeat1, 1, 0, 75),
  [564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__actual_arguments_repeat1, 1, 0, 75),
  [566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_import, 1, 0, 4),
  [572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(542),
  [574] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_informal_constraint, 2, 0, 24),
  [576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_informal_constraint, 2, 0, 24),
  [578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_datatype_def_restriction_repeat1, 2, 0, 0),
  [596] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_datatype_def_restriction_repeat1, 2, 0, 0), SHIFT_REPEAT(531),
  [599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_datatype_def_restriction_repeat1, 2, 0, 0), SHIFT_REPEAT(550),
  [602] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_datatype_def_restriction_repeat1, 2, 0, 0), SHIFT_REPEAT(534),
  [605] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_datatype_def_restriction_repeat1, 2, 0, 0), SHIFT_REPEAT(539),
  [608] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_datatype_def_restriction_repeat1, 2, 0, 0), SHIFT_REPEAT(548),
  [611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inequation, 3, 0, 76),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_equation, 3, 0, 74),
  [621] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_formal_constraint, 4, 0, 78),
  [623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_constraint, 4, 0, 78),
  [625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_reference, 1, 0, 0),
  [627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_reference, 1, 0, 0),
  [629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_informal_constraint, 3, 0, 45),
  [631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_informal_constraint, 3, 0, 45),
  [633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_body_repeat1, 2, 0, 0),
  [635] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat1, 2, 0, 0), SHIFT_REPEAT(365),
  [638] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_body_repeat1, 2, 0, 0), SHIFT_REPEAT(396),
  [641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constraint, 3, 0, 1),
  [643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint, 3, 0, 1),
  [645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation, 1, 0, 0),
  [647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation, 1, 0, 0),
  [649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_formal_constraint, 3, 0, 40),
  [651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_constraint, 3, 0, 40),
  [653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 1, 0, 34),
  [655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sequence_of_predicate_values_repeat1, 1, 0, 34),
  [657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_property, 4, 0, 22),
  [659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_property, 4, 0, 22),
  [661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint_sentence, 1, 0, 0),
  [663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_sentence, 1, 0, 0),
  [665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_set_op_membership, 1, 0, 0),
  [667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_op_membership, 1, 0, 0),
  [669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_op_inequality, 1, 0, 0),
  [671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_op_inequality, 1, 0, 0),
  [673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_sentence, 1, 0, 0),
  [675] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__rename_import, 2, 0, 17),
  [677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__rename_import, 2, 0, 17),
  [679] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_op_less_than_or_equal, 1, 0, 0),
  [681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_op_less_than_or_equal, 1, 0, 0),
  [683] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_op_greater_than_or_equal, 1, 0, 0),
  [685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_op_greater_than_or_equal, 1, 0, 0),
  [687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_import, 1, 0, 4),
  [689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_sequence_of_values_repeat1, 1, 0, 34),
  [691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sequence_of_values_repeat1, 1, 0, 34),
  [693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_import, 3, 0, 19),
  [695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_import, 3, 0, 19),
  [697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_import, 2, 0, 9),
  [699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_import, 2, 0, 9),
  [701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_import, 2, 0, 10),
  [703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_import, 2, 0, 9),
  [705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_import, 2, 0, 9),
  [707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint_sentence, 3, 0, 0),
  [709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__identifier_or_sequence, 1, 0, 83),
  [721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__identifier_or_sequence, 1, 0, 83),
  [723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__identifier_or_sequence, 3, 0, 86),
  [725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__identifier_or_sequence, 3, 0, 86),
  [727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rdf_def, 2, 0, 6),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_def, 2, 0, 14),
  [735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_def, 2, 0, 14),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_def, 2, 0, 6),
  [741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 3, 0, 0),
  [747] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotation_only_body, 3, 0, 0),
  [749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotation_only_body, 3, 0, 0),
  [751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 5, 0, 0),
  [753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_expression_to, 2, 0, 28),
  [755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_expression_to, 2, 0, 28),
  [757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entity_def, 2, 0, 6),
  [761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_def, 5, 0, 60),
  [763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_def, 2, 0, 6),
  [767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure_def, 2, 0, 6),
  [771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_def, 2, 0, 6),
  [775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_def, 2, 0, 6),
  [777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_data_type_def, 5, 0, 47),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_def, 2, 0, 6),
  [785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 4, 0, 0),
  [789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_statement, 2, 0, 0),
  [791] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_expression_to, 3, 0, 55),
  [793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_expression_to, 3, 0, 55),
  [795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_data_type_def, 4, 0, 25),
  [797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_def, 3, 0, 27),
  [799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_def, 3, 0, 27),
  [801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rdf_def, 3, 0, 15),
  [803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(415),
  [805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_def, 6, 0, 94),
  [811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_def, 3, 0, 13),
  [813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_definition_clause, 3, 0, 52),
  [815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entity_def, 3, 0, 13),
  [817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_def, 3, 0, 13),
  [819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__wildcard_or_identifier_or_sequence, 3, 0, 86),
  [821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_def, 3, 0, 13),
  [823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_def, 3, 0, 13),
  [827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_data_type_def, 5, 0, 49),
  [829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_data_type_def, 6, 0, 80),
  [831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_def, 3, 0, 13),
  [833] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__wildcard_or_identifier_or_sequence, 1, 0, 83),
  [835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__wildcard_or_identifier_or_sequence, 1, 0, 84),
  [837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_definition_with, 2, 0, 85),
  [839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_definition_without, 2, 0, 86),
  [841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure_def, 3, 0, 13),
  [843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rdf_types, 4, 0, 89),
  [845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tz_restriction_facet, 4, 0, 120),
  [847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(335),
  [849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_restriction_facet, 5, 0, 123),
  [853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_length_restriction_facet, 3, 0, 112),
  [855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rdf_types, 2, 0, 29),
  [857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_digit_restriction_facet, 3, 0, 112),
  [859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_restriction_value, 1, 0, 0),
  [863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rdf_types, 3, 0, 0),
  [865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_restriction_facet, 3, 0, 112),
  [867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tz_restriction_value, 1, 0, 0),
  [869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tz_restriction_facet, 3, 0, 113),
  [871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_restriction_facet, 3, 0, 113),
  [873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_datatype_def_restriction, 3, 0, 0),
  [875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_length_restriction_facet, 4, 0, 119),
  [877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_digit_restriction_facet, 4, 0, 119),
  [879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_restriction_facet, 4, 0, 119),
  [881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_body, 3, 0, 51),
  [883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_body, 4, 0, 82),
  [885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entity_body, 3, 0, 51),
  [887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_body, 6, 0, 82),
  [889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 2, 0, 0),
  [891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_def, 4, 0, 26),
  [893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_def, 4, 0, 26),
  [895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure_body, 4, 0, 0),
  [897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entity_def, 3, 0, 1),
  [899] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_data_type_def, 7, 0, 103),
  [901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_body, 4, 0, 0),
  [903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_body, 4, 0, 92),
  [905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 3, 0, 0),
  [907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_def, 3, 0, 1),
  [909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_body, 5, 0, 51),
  [911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_body, 5, 0, 82),
  [913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rdf_def, 4, 0, 30),
  [915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure_body, 2, 0, 0),
  [917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entity_body, 5, 0, 82),
  [919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure_def, 4, 0, 26),
  [921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_body, 2, 0, 0),
  [923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_body, 5, 0, 82),
  [925] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_def, 4, 0, 26),
  [927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure_body, 3, 0, 0),
  [929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_body, 2, 0, 0),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_body, 3, 0, 0),
  [937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_def, 4, 0, 26),
  [939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_def, 3, 0, 1),
  [941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_body, 4, 0, 51),
  [943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_body, 3, 0, 58),
  [945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_def, 2, 0, 7),
  [947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_def, 3, 0, 1),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_data_type_def, 5, 0, 48),
  [953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_def, 4, 0, 26),
  [955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_body, 3, 0, 51),
  [957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_data_type_def, 6, 0, 79),
  [959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_def, 7, 0, 110),
  [961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_definition, 1, 0, 0),
  [963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_data_type_def, 6, 0, 81),
  [965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_def, 3, 0, 1),
  [967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_body, 4, 0, 51),
  [969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_body, 4, 0, 82),
  [971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rdf_def, 3, 0, 1),
  [973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entity_def, 4, 0, 26),
  [975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_def, 6, 0, 95),
  [977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_def, 3, 0, 1),
  [979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entity_body, 4, 0, 51),
  [981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entity_body, 4, 0, 82),
  [983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 4, 0, 0),
  [985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structure_def, 3, 0, 1),
  [987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_class_body, 3, 0, 0),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(429),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [1003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [1011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [1013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [1015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [1017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [1019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_def, 1, 0, 31),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [1023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [1025] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(352),
  [1028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_statement_repeat1, 2, 0, 0),
  [1030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [1038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1042] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable, 1, 0, 4),
  [1044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable, 1, 0, 4),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [1048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type_reference, 1, 0, 0),
  [1050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type_reference, 1, 0, 0),
  [1052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_type, 2, 0, 28),
  [1054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_type, 2, 0, 28),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1058] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_type, 3, 0, 55),
  [1060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_type, 3, 0, 55),
  [1062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [1064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_import, 1, 0, 4),
  [1066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [1068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [1078] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_dimension_body_repeat2, 2, 0, 0), SHIFT_REPEAT(415),
  [1081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dimension_body_repeat2, 2, 0, 0),
  [1083] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimension_body_repeat2, 2, 0, 0), SHIFT_REPEAT(448),
  [1086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [1088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [1090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_dimension_body_repeat1, 2, 0, 0),
  [1092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dimension_body_repeat1, 2, 0, 0),
  [1094] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimension_body_repeat1, 2, 0, 0), SHIFT_REPEAT(533),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [1101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 3, 0, 4),
  [1103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [1117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 4, 0, 4),
  [1119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimension_parent, 4, 0, 114),
  [1121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_parent, 4, 0, 114),
  [1123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_body_repeat1, 2, 0, 0), SHIFT_REPEAT(335),
  [1126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_union_body_repeat1, 2, 0, 0),
  [1128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameter_repeat1, 2, 0, 0),
  [1130] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameter_repeat1, 2, 0, 0), SHIFT_REPEAT(501),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_variant, 1, 0, 4),
  [1137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_variant, 1, 0, 4),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [1141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [1143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_rdf_types_repeat1, 2, 0, 90), SHIFT_REPEAT(45),
  [1146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rdf_types_repeat1, 2, 0, 90),
  [1148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_restriction, 2, 0, 109),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint_environment, 2, 0, 0),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [1164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 3, 0, 77),
  [1166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constraint_environment_repeat1, 2, 0, 0),
  [1168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_constraint_environment_repeat1, 2, 0, 0), SHIFT_REPEAT(582),
  [1171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_restriction, 1, 0, 93),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [1175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_class_body_repeat1, 2, 0, 59),
  [1179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_class_body_repeat1, 2, 0, 59), SHIFT_REPEAT(582),
  [1182] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_source_entity, 2, 0, 50),
  [1184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_entity, 2, 0, 50),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [1188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 6, 0, 118),
  [1194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [1196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 1, 0, 4),
  [1198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [1200] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member, 1, 0, 0),
  [1202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member, 1, 0, 0),
  [1204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [1208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_signature_repeat1, 2, 0, 61), SHIFT_REPEAT(423),
  [1211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_signature_repeat1, 2, 0, 61),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [1215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_variant, 3, 0, 91),
  [1217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_variant, 3, 0, 91),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [1221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable, 3, 0, 99),
  [1223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable, 3, 0, 99),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [1229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_sequence_builder_repeat1, 2, 0, 71), SHIFT_REPEAT(345),
  [1232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sequence_builder_repeat1, 2, 0, 71),
  [1234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_entity_identity, 2, 0, 51),
  [1238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_entity_identity, 2, 0, 51),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [1242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(418),
  [1244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [1246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimension_parent, 5, 0, 121),
  [1248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dimension_parent, 5, 0, 121),
  [1250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [1254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [1256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_restriction, 4, 0, 122),
  [1258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameter_restriction_repeat1, 2, 0, 101), SHIFT_REPEAT(443),
  [1261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameter_restriction_repeat1, 2, 0, 101),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [1265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_restriction, 5, 0, 124),
  [1267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_import, 1, 0, 4),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [1273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_import, 2, 0, 10),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [1277] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enum_body_repeat1, 2, 0, 0), SHIFT_REPEAT(429),
  [1280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2, 0, 0),
  [1282] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_variant, 1, 0, 4),
  [1284] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_variant, 1, 0, 4),
  [1286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_ordering, 1, 0, 0),
  [1288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_source_entity, 4, 0, 104),
  [1290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_entity, 4, 0, 104),
  [1292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_ref, 2, 0, 57),
  [1294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_ref, 2, 0, 57),
  [1296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_def, 2, 0, 46),
  [1300] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_class_def_repeat1, 2, 0, 61), SHIFT_REPEAT(399),
  [1303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_class_def_repeat1, 2, 0, 61),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [1309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__wildcard_or_identifier_or_sequence_repeat1, 2, 0, 115), SHIFT_REPEAT(493),
  [1312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__wildcard_or_identifier_or_sequence_repeat1, 2, 0, 115),
  [1314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [1316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [1318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_pattern_restriction_facet_repeat1, 2, 0, 0),
  [1320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_restriction_facet_repeat1, 2, 0, 0), SHIFT_REPEAT(440),
  [1323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quantified_variable, 3, 0, 102),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [1327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameter_restriction_repeat1, 1, 0, 75),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [1341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_path_absolute_repeat1, 2, 0, 21),
  [1343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_module_path_absolute_repeat1, 2, 0, 21), SHIFT_REPEAT(569),
  [1346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [1348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__cardinality_inner, 1, 0, 54),
  [1350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [1352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [1356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [1358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [1362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_path_absolute, 2, 0, 11),
  [1366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [1368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [1370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [1374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_path_absolute, 3, 0, 20),
  [1376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [1378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [1380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [1382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [1384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_binary_repeat1, 2, 0, 67),
  [1390] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_binary_repeat1, 2, 0, 67), SHIFT_REPEAT(486),
  [1393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_path_relative, 2, 0, 12),
  [1395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [1397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_path_relative, 1, 0, 5),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [1401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sequence_builder_repeat1, 1, 0, 39),
  [1403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_uniqueness, 1, 0, 0),
  [1405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_signature_repeat1, 1, 0, 33),
  [1407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_binary_repeat1, 1, 0, 36),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [1411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module_locations, 1, 0, 2),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [1415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [1417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [1421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [1423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_path_root_only, 1, 0, 0),
  [1425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_class_body_repeat1, 1, 0, 32),
  [1431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__wildcard_or_identifier_or_sequence_repeat1, 1, 0, 83),
  [1433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_range, 1, 0, 0),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [1437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value_variant, 2, 0, 53),
  [1439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_variant, 2, 0, 53),
  [1441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [1443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_def, 2, 0, 46),
  [1445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_variant, 4, 0, 108),
  [1447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_variant, 4, 0, 108),
  [1449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_module_path_absolute_repeat1, 2, 0, 11),
  [1451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_class_def_repeat1, 1, 0, 33),
  [1453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_op_combiner, 1, 0, 0),
  [1455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_rdf_types_repeat1, 1, 0, 56),
  [1457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_def, 3, 0, 46),
  [1459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_parameter, 2, 0, 14),
  [1461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_variant, 2, 0, 53),
  [1463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_variant, 2, 0, 53),
  [1465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_def, 2, 0, 31),
  [1467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sequence_value_constraints, 4, 0, 96),
  [1469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sequence_value_constraints, 3, 0, 64),
  [1471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__sequence_value_constraints, 3, 0, 65),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [1475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 4, 0, 3),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [1485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cardinality_range, 2, 0, 105),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_body, 2, 0, 0),
  [1491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [1493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [1511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [1517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module_locations, 3, 0, 8),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 2, 0, 0),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [1527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [1531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(549),
  [1533] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [1535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [1539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_body, 3, 0, 0),
  [1541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [1543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [1545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [1547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [1549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [1551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [1555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module, 3, 0, 1),
  [1563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quantified_variable_binding, 2, 0, 44),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [1575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_body, 4, 0, 0),
  [1577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [1579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [1581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [1585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_logical_quantifier_universal, 1, 0, 0),
  [1587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [1589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_logical_quantifier_existential, 1, 0, 0),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(554),
  [1595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_body, 5, 0, 0),
  [1597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__module_locations, 4, 0, 16),
  [1601] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__cardinality_inner, 2, 0, 87),
  [1605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sequence_builder_body, 1, 0, 0),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_sdml(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
